-- ============================================================================
-- == HTConfig - Provides functions for creating, reading, updating and      ==
-- ==            deleting the configuration data used to configure the       ==
-- ==            HalonaTools addon.                                          ==
-- ============================================================================

HTConfig       = LibStub("AceAddon-3.0"):NewAddon("HTConfig", "AceConsole-3.0", "AceEvent-3.0")
local L        = LibStub("AceLocale-3.0"):GetLocale("HalonaTools")

local db       = {} -- Reference variable used to persist data between sessions.
local defaults = {} -- Reference variable used to persist data between sessions.
local options  = {}                -- Used to provide Ace3/Blizzard GUI options.

-- ============================================================================
-- == OnInitialize()                                                         ==
-- ==                                                                        ==
-- == This function is called when the addon is initialised.                 ==
-- ============================================================================

function HTConfig:OnInitialize()

  HTConfig:BuildDBTable()
  HTConfig:BuildOptionsTable()
  HTConfig:RegisterOptionsTable()
  HTConfig:SetDefaultPropertyValues()

end

-- ============================================================================
-- == OnEnable()                                                             ==
-- ==                                                                        ==
-- == This function is called when the addon is enabled.                     ==
-- ============================================================================

function HTConfig:OnEnable()

  -- This function called once per version release, provides smooth update.
  HTConfig:DoOncePerVersion()

  -- This is reset upon each OnEnable to ensure that errors cannot creep in if
  -- new versions with higher version numbers than are available via standard
  -- releases have been tested on the live servers with other players.
  self.db.profile.maxAddonVersionSeen = L["addon-version-number"]

end

-- ============================================================================
-- == OnEnable()                                                             ==
-- ==                                                                        ==
-- == This function is called when the addon is disabled.                    ==
-- ============================================================================

function HTConfig:OnDisable()
end

-- ============================================================================
-- == BuildDBTable()                                                         ==
-- ==                                                                        ==
-- == This function builds the default db table. This table is persisted     ==
-- == between sessions by the AceDB library.                                 ==
-- ============================================================================

function HTConfig:BuildDBTable()

  defaults = {
    profile =  {
      -- General status flags and data values.
      addonName                                = L["addon-name"],
      rankTags01                               = L["cfg-ranktags-default-gm"],
      rankTags02                               = L["cfg-ranktags-default-officer"],
      rankTags03                               = L["cfg-ranktags-default-raid-master"],
      rankTags04                               = L["cfg-ranktags-default-member"],
      rankTags05                               = L["cfg-ranktags-default-trial-member"],
      rankTags06                               = L["cfg-ranktags-default-social-star"],
      rankTags07                               = L["cfg-ranktags-default-social-officer"],
      rankTags08                               = L["cfg-ranktags-default-alt-officer"],
      rankTags09                               = L["cfg-ranktags-default-alt"],
      rankTags10                               = L["cfg-ranktags-default-free-bus-pass"],

      isEnabledAutoInvitations                 = true,
      isEnabledAutoInvitationsGuildOnly        = true,
      isEnabledAutoRaidPromotions              = true,
      isEnabledAutoRIAResponse                 = true,
      isEnabledAutoRQAResponse                 = true,
      isEnabledAlertNewAddonVersion            = true,
      isEnabledDebugMode                       = false,
      isEnabledDebugFilter                     = false,
      debugFilter                              = L["cfg-default-debug-filter"],
      heartbeatInterval                        = 300,
      chatWindowTextMaxWidth                   = 45,
      myLastVersion                            = 0.00,
      maxAddonVersionSeen                      = L["addon-version-number"],

      -- BrokerSupport, Text Label Options.
      brokerSupportHeartbeatResting            = 5,
      isEnabledTextLabelContentBRMessageNum    = true,
      isEnabledTextLabelContentGStatsMembers   = true,
      isEnabledTextLabelContentGStatsRaiders   = false,
      isEnabledTextLabelContentGStatsOfficers  = true,
      isEnabledTextLabelContentGStatsCharacters= false,
      isEnabledTextLabelContentGuildPlayMode   = true,
      isEnabledTextLabelContentCombatStatus    = true,
      isEnabledTextLabelContentShowMinimised   = false,

      -- BrokerSupport, Tooltip Options.
      isEnabledTooltipContentGuildInformation  = true,
      isEnabledTooltipContentGuildStatistics   = true,
      isEnabledTooltipContentGMOTD             = true,
      isEnabledTooltipContentOfficerList       = true,
      isEnabledTooltipContentToolStatusInfo    = true,
      isEnabledTooltipContentButtonActions     = true,

      -- BuffMonitor - Reporting Options.
      isEnabledBuffMonitor                     = true,
      isEnabledBuffMonitorCheckOnReadyCheck    = false,
      isEnabledBuffMonitorCheckOnCombatStart   = false,
      isEnabledBuffMonitorCheckOnHeartbeat     = false,

      isEnabledBuffMonitorMistsBuffs           = true,
      isEnabledBuffMonitorCataBuffs            = true,
      isEnabledBuffMonitorWrathBuffs           = true,

      isEnabledBuffMonitorExpiryTimeCheck      = true,
      buffMonitorExpiryTimeLimit               = 5,

      isEnabledBuffMonitorReportDead           = true,
      isEnabledBuffMonitorReportOffline        = true,

      isEnabledBuffMonitorCheckFlasks          = true,
      isEnabledBuffMonitorCheckBattleElixirs   = true,
      isEnabledBuffMonitorCheckGuardianElixirs = true,
      isEnabledBuffMonitorCheckFood            = true,
      isEnabledBuffMonitorCheckPoisons         = false,

      -- BuffMonitor - Mists Data Items.
      isEnabledBuffMonitorMistsFlasks          = true,
      isEnabledBuffMonitorMistsBattleElixirs   = true,
      isEnabledBuffMonitorMistsGuardianElixirs = true,
      isEnabledBuffMonitorMistsFood            = true,
      isEnabledBuffMonitorMistsPoisons         = true,

      -- BuffMonitor - Cataclysm Data Items.
      isEnabledBuffMonitorCataFlasks           = true,
      isEnabledBuffMonitorCataBattleElixirs    = true,
      isEnabledBuffMonitorCataGuardianElixirs  = true,
      isEnabledBuffMonitorCataFood             = true,
      isEnabledBuffMonitorCataPoisons          = true,

      -- BuffMonitor - Wrath Data Items.
      isEnabledBuffMonitorWrathFlasks          = true,
      isEnabledBuffMonitorWrathBattleElixirs   = true,
      isEnabledBuffMonitorWrathGuardianElixirs = true,
      isEnabledBuffMonitorWrathFood            = true,
      isEnabledBuffMonitorWrathPoisons         = true,

      -- BuffMonitor - Player Flags.
      isPlayerInCombat                         = false,

      -- Raid Management.
      defaultOfftimeGMOTD                      = L["ht-raid-session-end-gmotd-01"],

      -- Recruitment Message Sender.
      isEnabledRecruitmentMessageSender        = true,
      isEnabledRMSBroadcastOnZoneChanged       = false,
      isEnabledRMSGroupLock                    = true,
      isEnabledRMSGuildLocked                  = true,
      preferredRMSGuild                        = L["cfg-default-guild-name"],
      recruitmentMessage                       = L["cfg-default-recruitment-msg"],
      recruitmentInterval                      = 900,
      recruitmentZoneName                      = L["all-data-unset"],

      -- BusyResponder.
      isEnabledBusyResponder                   = false,
      isGuildMemberAllowed                     = false,
      isGuildOfficerAllowed                    = false,
      isRaidMemberAllowed                      = false,
      isPartyMemberAllowed                     = false,
      isFriendAllowed                          = false,
      isRealIDFriendAllowed                    = false,
      brMessageOutgoing                        = L["con-busy-responder-out-msg-busy-01"],
      brMessageCustom                          = L["con-busy-responder-out-msg-custom-01"],
      isEnabledBRAutoProfileSelect             = false,
      brProfileName                            = L["con-busy-responder-profile-name-busy"],
      brProfileBusy                            = "000000",
      brProfileRaiding                         = "011110",
      brProfileAway                            = "000000",
      brProfileRecruiting                      = "000000",
      brProfileCustom                          = "000000",

      -- BuffAnnouncer.
      isEnabledBuffAnnouncer                   = false,
      isEnabledBuffAnnouncerFood               = true,
      isEnabledBuffAnnouncerCauldron           = true,
      isEnabledBuffAnnouncerHealthStones       = true,
      isEnabledBuffAnnouncerFoodTable          = true,
      isEnabledBuffAnnouncerRepairBot          = true,
      buffAnnouncerFoodMessage                 = "",
      buffAnnouncerCauldronMessage             = "",
      buffAnnouncerHealthStonesMessage         = "",

      isEnabledAutoConvertRaidInvitesToSession = true,
      isEnabledAutoSetMasterLoot               = true,
      isEnabledAutoSelectMasterLooter          = true,
      isEnabledASMLRaidLeaderTest              = true,
      isEnabledASMLRaidAssistantTest           = true,
      isEnabledASMLGuildMasterTest             = true,
      isEnabledASMLGuildOfficerTest            = true,
      isEnabledASMLRaidMasterTest              = true,
      isEnabledASMLDesignatedMasterLooterTest  = true,

      voipType                                 = L["all-data-unset"],
      voipHostname                             = L["all-data-unset"],
      voipPortNumber                           = L["all-data-unset"],
      voipUsername                             = L["all-data-unset"],
      voipPassword                             = L["all-data-unset"],

      -- AutoInfoResponse
      airInfoMessage                           = L["con-autoinforesponse-info-msg-02"],
      airGuildMessage                          = L["con-autoinforesponse-guild-msg-02"],
      airOfficerListMessage                    = L["con-autoinforesponse-officerlist-msg-02"],
      airRaidTimesMessage                      = L["con-autoinforesponse-raidtimes-msg-02"],
      airRecruitmentMessage                    = L["con-autoinforesponse-recruitment-msg-02"],
      airContactUsMessage                      = L["con-autoinforesponse-contactus-msg-02"],
      airZatMessage                            = L["con-autoinforesponse-zat-msg-02"],
    },
  }

  self.db = LibStub("AceDB-3.0"):New("HalonaToolsDB", defaults, "Default")

end

-- ============================================================================
-- == BuildOptionsTable()                                                    ==
-- ==                                                                        ==
-- == This function builds the default options table. This table is          ==
-- == used to generate both the command-line options and the configuration   ==
-- == options available through the Blizzard Addons UI by the AceConfig lib. ==
-- ============================================================================

function HTConfig:BuildOptionsTable()

  options = {
    name = L["addon-name"],
    handler = HTConfig,
    type = 'group',
    args = {
      isEnabledAutoInvitations = {
        type = "toggle",
        name = L["cfg-feature-name-autoinvitations"],
        desc = L["cfg-feature-desc-autoinvitations"],
        get = "GetIsEnabledAutoInvitations",
        set = "SetIsEnabledAutoInvitations",
      },
      isEnabledDebugMode = {
        type = "toggle",
        name = L["cfg-feature-name-debugmode"],
        desc = L["cfg-feature-desc-debugmode"],
        get = "GetIsEnabledDebugMode",
        set = "SetIsEnabledDebugMode",
      },
    },
  }

end

-- ============================================================================
-- == RegisterOptionsTable()                                                 ==
-- ==                                                                        ==
-- == This function registers the default options table.                     ==
-- ============================================================================

function HTConfig:RegisterOptionsTable()

    LibStub("AceConfig-3.0"):RegisterOptionsTable("HalonaTools", options)
    self.optionsFrame = LibStub("AceConfigDialog-3.0"):AddToBlizOptions(L["addon-name"], L["addon-name"])
    self:RegisterChatCommand(L["cfg-console-command-long"],  "ChatCommand")
    self:RegisterChatCommand(L["cfg-console-command-short"], "ChatCommand")

end

-- ============================================================================
-- == SetDefaultPropertyValues()                                             ==
-- ==                                                                        ==
-- == This function sets internal properties to default values.              ==
-- ============================================================================

function HTConfig:SetDefaultPropertyValues()

  HTConfig:SetIsEnabledDebugMode(false, false)

end

-- ============================================================================
-- == ChatCommand(input)                                                     ==
-- ==                                                                        ==
-- == This function responds to calls to the addon via chat commands.        ==
-- ============================================================================

function HTConfig:ChatCommand(input)

  if not input or input:trim() == "" then
    InterfaceOptionsFrame_OpenToCategory(self.optionsFrame)
  else
    LibStub("AceConfigCmd-3.0").HandleCommand(HalonaTools, L["cfg-console-command-short"], L["addon-name"], input)
  end

end

-- ============================================================================
-- == ToggleValue(value)                                                     ==
-- ==                                                                        ==
-- == Toggles the supplied value between true and false states.              ==
-- ============================================================================

function HTConfig:ToggleValue(value)

    if value == true then
      return false
    else
      return true
    end

end

-- ============================================================================
-- == UpdateBuffMonitorByExpansion()                                         ==
-- ==                                                                        ==
-- == This function updates the individual buff categories that depend upon  ==
-- == the acceptable expansions selected.                                    ==
-- ============================================================================

function HTConfig:UpdateBuffMonitorByExpansion()

  if HTConfig:GetIsEnabledBuffMonitorMistsBuffs(nil) then
    self.db.profile.isEnabledBuffMonitorMistsFlasks          = true
    self.db.profile.isEnabledBuffMonitorMistsBattleElixirs   = true
    self.db.profile.isEnabledBuffMonitorMistsGuardianElixirs = true
    self.db.profile.isEnabledBuffMonitorMistsFood            = true
    self.db.profile.isEnabledBuffMonitorMistsPoisons         = true
  else
    self.db.profile.isEnabledBuffMonitorMistsFlasks          = false
    self.db.profile.isEnabledBuffMonitorMistsBattleElixirs   = false
    self.db.profile.isEnabledBuffMonitorMistsGuardianElixirs = false
    self.db.profile.isEnabledBuffMonitorMistsFood            = false
    self.db.profile.isEnabledBuffMonitorMistsPoisons         = false
  end

  if HTConfig:GetIsEnabledBuffMonitorCataBuffs(nil) then
    self.db.profile.isEnabledBuffMonitorCataFlasks           = true
    self.db.profile.isEnabledBuffMonitorCataBattleElixirs    = true
    self.db.profile.isEnabledBuffMonitorCataGuardianElixirs  = true
    self.db.profile.isEnabledBuffMonitorCataFood             = true
    self.db.profile.isEnabledBuffMonitorCataPoisons          = true
  else
    self.db.profile.isEnabledBuffMonitorCataFlasks           = false
    self.db.profile.isEnabledBuffMonitorCataBattleElixirs    = false
    self.db.profile.isEnabledBuffMonitorCataGuardianElixirs  = false
    self.db.profile.isEnabledBuffMonitorCataFood             = false
    self.db.profile.isEnabledBuffMonitorCataPoisons          = false
  end

  if HTConfig:GetIsEnabledBuffMonitorWrathBuffs(nil) then
    self.db.profile.isEnabledBuffMonitorWrathFlasks           = true
    self.db.profile.isEnabledBuffMonitorWrathBattleElixirs    = true
    self.db.profile.isEnabledBuffMonitorWrathGuardianElixirs  = true
    self.db.profile.isEnabledBuffMonitorWrathFood             = true
    self.db.profile.isEnabledBuffMonitorWrathPoisons          = true
  else
    self.db.profile.isEnabledBuffMonitorWrathFlasks           = false
    self.db.profile.isEnabledBuffMonitorWrathBattleElixirs    = false
    self.db.profile.isEnabledBuffMonitorWrathGuardianElixirs  = false
    self.db.profile.isEnabledBuffMonitorWrathFood             = false
    self.db.profile.isEnabledBuffMonitorWrathPoisons          = false
  end

end

-- ============================================================================
-- == RefreshHalonaRankTags()                                                ==
-- ==                                                                        ==
-- == Refreshes the rank-tags. This function can be called manually.         ==
-- ============================================================================

function HTConfig:RefreshHalonaRankTags()

  if HTCommon:GetGuildName() == L["default-guild-name"] then

    local rankTags01 = L["cfg-ranktags-default-gm"]              -- Guild Master
    local rankTags02 = L["cfg-ranktags-default-officer"]         -- Officer
    local rankTags03 = L["cfg-ranktags-default-raid-master"]     -- Raid Master
    local rankTags04 = L["cfg-ranktags-default-member"]          -- Member
    local rankTags05 = L["cfg-ranktags-default-trial-member"]    -- Trial Member
    local rankTags06 = L["cfg-ranktags-default-social-star"]     -- Social Star
    local rankTags07 = L["cfg-ranktags-default-social-officer"]  -- Social Officer
    local rankTags08 = L["cfg-ranktags-default-alt-officer"]     -- Alt-Officer
    local rankTags09 = L["cfg-ranktags-default-alt"]             -- Alt
    local rankTags10 = L["cfg-ranktags-default-free-bus-pass"]   -- Free Bus Pass

    HTConfig:SetRankTags01(rankTags01, rankTags01)
    HTConfig:SetRankTags02(rankTags02, rankTags02)
    HTConfig:SetRankTags03(rankTags03, rankTags03)
    HTConfig:SetRankTags04(rankTags04, rankTags04)
    HTConfig:SetRankTags05(rankTags05, rankTags05)
    HTConfig:SetRankTags06(rankTags06, rankTags06)
    HTConfig:SetRankTags07(rankTags07, rankTags07)
    HTConfig:SetRankTags08(rankTags08, rankTags08)
    HTConfig:SetRankTags09(rankTags09, rankTags09)
    HTConfig:SetRankTags10(rankTags10, rankTags10)

    HTConsole:SendChatMessage(L["cfg-ranktags-updated-for-halona"], "CHAT", nil, nil)

  end

end

-- ============================================================================
-- == RefreshHalonaRecruitmentMessage()                                      ==
-- ==                                                                        ==
-- == Refreshes the recruitment message. This function can be called         ==
-- == manually.                                                              ==
-- ============================================================================

function HTConfig:RefreshHalonaRecruitmentMessage()

  if HTCommon:GetGuildName() == L["default-guild-name"] then

    local recruitmentMessage = L["cfg-default-recruitment-msg"]

    HTConfig:SetRecruitmentMessage(recruitmentMessage, recruitmentMessage)

    HTConsole:SendChatMessage(L["cfg-recruitment-msg-updated-for-halona"], "CHAT", nil, nil)

  end

end

-- ============================================================================
-- == RefreshAutoInfoResponderMessages()                                     ==
-- ==                                                                        ==
-- == Refreshes the auto-info-responder messages. This function can be       ==
-- == called manually.                                                       ==
-- ============================================================================

function HTConfig:RefreshAutoInfoResponderMessages()

  if HTCommon:GetGuildName() == L["default-guild-name"] then

    local airInfoMessage        = L["con-autoinforesponse-info-msg-02"]
    local airGuildMessage       = L["con-autoinforesponse-guild-msg-02"]
    local airOfficerListMessage = L["con-autoinforesponse-officerlist-msg-02"]
    local guildOfficerList      = HTCommon:GetGuildOfficerList()

    for i,v in ipairs(guildOfficerList) do

      if i > 1 then
        airOfficerListMessage = airOfficerListMessage .. ", "
      end

      airOfficerListMessage = airOfficerListMessage .. guildOfficerList[i]

    end

    local airRaidTimesMessage   = L["con-autoinforesponse-raidtimes-msg-02"]
    local airRecruitmentMessage = L["con-autoinforesponse-recruitment-msg-02"]
    local airContactUsMessage   = L["con-autoinforesponse-contactus-msg-02"]
    local airZatMessage         = L["con-autoinforesponse-zat-msg-02"]

    HTConfig:SetAirInfoMessage(airInfoMessage, airInfoMessage)
    HTConfig:SetAirGuildMessage(airGuildMessage, airGuildMessage)
    HTConfig:SetAirOfficerListMessage(airOfficerListMessage, airOfficerListMessage)
    HTConfig:SetAirRaidTimesMessage(airRaidTimesMessage, airRaidTimesMessage)
    HTConfig:SetAirRecruitmentMessage(airRecruitmentMessage, airRecruitmentMessage)
    HTConfig:SetAirContactUsMessage(airContactUsMessage, airContactUsMessage)
    HTConfig:SetAirZatMessage(airZatMessage, airZatMessage)

    HTConsole:SendChatMessage(L["cfg-air-msg-updated-for-halona"], "CHAT", nil, nil)

  end

end

-- ============================================================================
-- == ShowRankTags()                                                         ==
-- ==                                                                        ==
-- == Displays the rank-tags in the chat window for easy reference.          ==
-- ============================================================================

function HTConfig:ShowRankTags()

  HTConsole:SendChatMessage(HTConsole:GetTitleBar(), "CHAT", nil, nil)
  HTConsole:SendChatMessage(L["cfg-ranktags-show"], "CHAT", nil, nil)
  HTConsole:SendChatMessage(HTConsole:GetTitleBar(), "CHAT", nil, nil)
  HTConsole:SendChatMessage("|cffffff00" .. HTCommon:GetGuildRankNameByIndex(1)  .. ":|r |cff00ff00" .. HTConfig:GetRankTags01(nil) .. "|r", "CHAT", nil, nil)
  HTConsole:SendChatMessage("|cffffff00" .. HTCommon:GetGuildRankNameByIndex(2)  .. ":|r |cff00ff00" .. HTConfig:GetRankTags02(nil) .. "|r", "CHAT", nil, nil)
  HTConsole:SendChatMessage("|cffffff00" .. HTCommon:GetGuildRankNameByIndex(3)  .. ":|r |cff00ff00" .. HTConfig:GetRankTags03(nil) .. "|r", "CHAT", nil, nil)
  HTConsole:SendChatMessage("|cffffff00" .. HTCommon:GetGuildRankNameByIndex(4)  .. ":|r |cff00ff00" .. HTConfig:GetRankTags04(nil) .. "|r", "CHAT", nil, nil)
  HTConsole:SendChatMessage("|cffffff00" .. HTCommon:GetGuildRankNameByIndex(5)  .. ":|r |cff00ff00" .. HTConfig:GetRankTags05(nil) .. "|r", "CHAT", nil, nil)
  HTConsole:SendChatMessage("|cffffff00" .. HTCommon:GetGuildRankNameByIndex(6)  .. ":|r |cff00ff00" .. HTConfig:GetRankTags06(nil) .. "|r", "CHAT", nil, nil)
  HTConsole:SendChatMessage("|cffffff00" .. HTCommon:GetGuildRankNameByIndex(7)  .. ":|r |cff00ff00" .. HTConfig:GetRankTags07(nil) .. "|r", "CHAT", nil, nil)
  HTConsole:SendChatMessage("|cffffff00" .. HTCommon:GetGuildRankNameByIndex(8)  .. ":|r |cff00ff00" .. HTConfig:GetRankTags08(nil) .. "|r", "CHAT", nil, nil)
  HTConsole:SendChatMessage("|cffffff00" .. HTCommon:GetGuildRankNameByIndex(9)  .. ":|r |cff00ff00" .. HTConfig:GetRankTags09(nil) .. "|r", "CHAT", nil, nil)
  HTConsole:SendChatMessage("|cffffff00" .. HTCommon:GetGuildRankNameByIndex(10) .. ":|r |cff00ff00" .. HTConfig:GetRankTags10(nil) .. "|r", "CHAT", nil, nil)
  HTConsole:SendChatMessage("|cffffff00" .. HTConsole:GetTitleBar(), "CHAT", nil, nil)

end

-- ============================================================================
-- == SetVoipDetailsForHalonaMembers()                                       ==
-- ==                                                                        ==
-- == Sets the internal VOIP properties to Halona values if the member       ==
-- == belongs to the main Halona guild.                                      ==
-- ============================================================================

function HTConfig:SetVoipDetailsForHalonaMembers()

  if HTCommon:GetGuildName() == L["default-guild-name"] then

    HTConfig:SetVoipType(L["halona-guild-voip-account-type"], L["halona-guild-voip-account-type"])
    HTConfig:SetVoipHostname(L["halona-guild-voip-account-hostname"], L["halona-guild-voip-account-hostname"])
    HTConfig:SetVoipPortNumber(L["halona-guild-voip-account-portnumber"], L["halona-guild-voip-account-portnumber"])
    HTConfig:SetVoipUsername(L["halona-guild-voip-account-username"], L["halona-guild-voip-account-username"])
    HTConfig:SetVoipPassword(L["halona-guild-voip-account-password"], L["halona-guild-voip-account-password"])

  end

end

-- ============================================================================
-- == DoOncePerVersion()                                                     ==
-- ==                                                                        ==
-- == This function is intended to run once per version release of the addon ==
-- == and is the place for locating routines that initialise or reset data   ==
-- == as required to ensure the user experiences a smooth upgrade process.   ==
-- ============================================================================

function HTConfig:DoOncePerVersion()

  local addonVersion  = L["addon-version-number"]
  local myLastVersion = HTConfig:GetMyLastVersion(nil)

  if tonumber(addonVersion) > tonumber(myLastVersion) then

    -- Update the 'myLastVersion' value so this only ever runs once per version.
    HTConfig:SetMyLastVersion(addonVersion, addonVersion)

    -- Version 2.18: Refresh VOIP Details.
    if tonumber(addonVersion) > 2.17 then
      HTConfig:SetVoipDetailsForHalonaMembers()
    end

    -- Version 2.15: Refresh Rank Tags.
    if tonumber(addonVersion) > 2.14 then
      HTConfig:RefreshHalonaRankTags()
      HTConfig:RefreshHalonaRecruitmentMessage()
    end

  end

end

-- ============================================================================
-- == ACCESSORS/MUTATORS* only beyond this point.                            ==
-- ==                                                                        ==
-- == The remainder of this file contains the accessors and mutators for the ==
-- == various different variables/data-items managed as part of the HTConfig ==
-- == model.                                                                 ==
-- ==                                                                        ==
-- == * Also known less formally as 'getters and setters'.                   ==
-- ============================================================================

-- ============================================================================
-- == GetMessage(info)                                                       ==
-- ==                                                                        ==
-- == Standard accessor function for the named property.                     ==
-- ============================================================================

function HTConfig:GetMessage(info)
    return self.db.profile.message
end

-- ============================================================================
-- == SetMessage(info, newValue)                                             ==
-- ==                                                                        ==
-- == Standard mutator function for the named property.                      ==
-- ============================================================================

function HTConfig:SetMessage(info, newValue)
    self.db.profile.message = newValue
end

-- ============================================================================
-- == GetRankTags01(info)                                                    ==
-- ==                                                                        ==
-- == Standard accessor function for the named property.                     ==
-- ============================================================================

function HTConfig:GetRankTags01(info)
    return self.db.profile.rankTags01
end

-- ============================================================================
-- == SetRankTags01(info, newValue)                                          ==
-- ==                                                                        ==
-- == Standard mutator function for the named property.                      ==
-- ============================================================================

function HTConfig:SetRankTags01(info, newValue)
    self.db.profile.rankTags01 = newValue
end

-- ============================================================================
-- == GetRankTags02(info)                                                    ==
-- ==                                                                        ==
-- == Standard accessor function for the named property.                     ==
-- ============================================================================

function HTConfig:GetRankTags02(info)
    return self.db.profile.rankTags02
end

-- ============================================================================
-- == SetRankTags02(info, newValue)                                          ==
-- ==                                                                        ==
-- == Standard mutator function for the named property.                      ==
-- ============================================================================

function HTConfig:SetRankTags02(info, newValue)
    self.db.profile.rankTags02 = newValue
end

-- ============================================================================
-- == GetRankTags03(info)                                                    ==
-- ==                                                                        ==
-- == Standard accessor function for the named property.                     ==
-- ============================================================================

function HTConfig:GetRankTags03(info)
    return self.db.profile.rankTags03
end

-- ============================================================================
-- == SetRankTags03(info, newValue)                                          ==
-- ==                                                                        ==
-- == Standard mutator function for the named property.                      ==
-- ============================================================================

function HTConfig:SetRankTags03(info, newValue)
    self.db.profile.rankTags03 = newValue
end

-- ============================================================================
-- == GetRankTags04(info)                                                    ==
-- ==                                                                        ==
-- == Standard accessor function for the named property.                     ==
-- ============================================================================

function HTConfig:GetRankTags04(info)
    return self.db.profile.rankTags04
end

-- ============================================================================
-- == SetRankTags04(info, newValue)                                          ==
-- ==                                                                        ==
-- == Standard mutator function for the named property.                      ==
-- ============================================================================

function HTConfig:SetRankTags04(info, newValue)
    self.db.profile.rankTags04 = newValue
end

-- ============================================================================
-- == GetRankTags05(info)                                                    ==
-- ==                                                                        ==
-- == Standard accessor function for the named property.                     ==
-- ============================================================================

function HTConfig:GetRankTags05(info)
    return self.db.profile.rankTags05
end

-- ============================================================================
-- == SetRankTags05(info, newValue)                                          ==
-- ==                                                                        ==
-- == Standard mutator function for the named property.                      ==
-- ============================================================================

function HTConfig:SetRankTags05(info, newValue)
    self.db.profile.rankTags05 = newValue
end

-- ============================================================================
-- == GetRankTags06(info)                                                    ==
-- ==                                                                        ==
-- == Standard accessor function for the named property.                     ==
-- ============================================================================

function HTConfig:GetRankTags06(info)
    return self.db.profile.rankTags06
end

-- ============================================================================
-- == SetRankTags06(info, newValue)                                          ==
-- ==                                                                        ==
-- == Standard mutator function for the named property.                      ==
-- ============================================================================

function HTConfig:SetRankTags06(info, newValue)
    self.db.profile.rankTags06 = newValue
end

-- ============================================================================
-- == GetRankTags07(info)                                                    ==
-- ==                                                                        ==
-- == Standard accessor function for the named property.                     ==
-- ============================================================================

function HTConfig:GetRankTags07(info)
    return self.db.profile.rankTags07
end

-- ============================================================================
-- == SetRankTags07(info, newValue)                                          ==
-- ==                                                                        ==
-- == Standard mutator function for the named property.                      ==
-- ============================================================================

function HTConfig:SetRankTags07(info, newValue)
    self.db.profile.rankTags07 = newValue
end

-- ============================================================================
-- == GetRankTags08(info)                                                    ==
-- ==                                                                        ==
-- == Standard accessor function for the named property.                     ==
-- ============================================================================

function HTConfig:GetRankTags08(info)
    return self.db.profile.rankTags08
end

-- ============================================================================
-- == SetRankTags08(info, newValue)                                          ==
-- ==                                                                        ==
-- == Standard mutator function for the named property.                      ==
-- ============================================================================

function HTConfig:SetRankTags08(info, newValue)
    self.db.profile.rankTags08 = newValue
end

-- ============================================================================
-- == GetRankTags09(info)                                                    ==
-- ==                                                                        ==
-- == Standard accessor function for the named property.                     ==
-- ============================================================================

function HTConfig:GetRankTags09(info)
    return self.db.profile.rankTags09
end

-- ============================================================================
-- == SetRankTags09(info, newValue)                                          ==
-- ==                                                                        ==
-- == Standard mutator function for the named property.                      ==
-- ============================================================================

function HTConfig:SetRankTags09(info, newValue)
    self.db.profile.rankTags09 = newValue
end

-- ============================================================================
-- == GetRankTags10(info)                                                    ==
-- ==                                                                        ==
-- == Standard accessor function for the named property.                     ==
-- ============================================================================

function HTConfig:GetRankTags10(info)
    return self.db.profile.rankTags10
end

-- ============================================================================
-- == SetRankTags10(info, newValue)                                          ==
-- ==                                                                        ==
-- == Standard mutator function for the named property.                      ==
-- ============================================================================

function HTConfig:SetRankTags10(info, newValue)
    self.db.profile.rankTags10 = newValue
end

-- ============================================================================
-- == GetIsEnabledAutoInvitations(info)                                      ==
-- ==                                                                        ==
-- == Standard accessor function for the named property.                     ==
-- ============================================================================

function HTConfig:GetIsEnabledAutoInvitations(info)
    return self.db.profile.isEnabledAutoInvitations
end

-- ============================================================================
-- == SetIsEnabledAutoInvitations(info, newValue)                            ==
-- ==                                                                        ==
-- == Standard mutator function for the named property.                      ==
-- ============================================================================

function HTConfig:SetIsEnabledAutoInvitations(info, newValue)
    self.db.profile.isEnabledAutoInvitations = newValue
end

-- ============================================================================
-- == ToggleIsEnabledAutoInvitations()                                       ==
-- ==                                                                        ==
-- == Toggles the value of the named property.                               ==
-- ============================================================================

function HTConfig:ToggleIsEnabledAutoInvitations()
    self.db.profile.isEnabledAutoInvitations = HTConfig:ToggleValue(HTConfig:GetIsEnabledAutoInvitations(nil))
end

-- ============================================================================
-- == GetIsEnabledAutoInvitationsGuildOnly(info)                             ==
-- ==                                                                        ==
-- == Standard accessor function for the named property.                     ==
-- ============================================================================

function HTConfig:GetIsEnabledAutoInvitationsGuildOnly(info)
    return self.db.profile.isEnabledAutoInvitationsGuildOnly
end

-- ============================================================================
-- == SetIsEnabledAutoInvitationsGuildOnly(info, newValue)                   ==
-- ==                                                                        ==
-- == Standard mutator function for the named property.                      ==
-- ============================================================================

function HTConfig:SetIsEnabledAutoInvitationsGuildOnly(info, newValue)
    self.db.profile.isEnabledAutoInvitationsGuildOnly = newValue
end

-- ============================================================================
-- == ToggleIsEnabledAutoInvitationsGuildOnly()                              ==
-- ==                                                                        ==
-- == Toggles the value of the named property.                               ==
-- ============================================================================

function HTConfig:ToggleIsEnabledAutoInvitationsGuildOnly()
    self.db.profile.isEnabledAutoInvitationsGuildOnly = HTConfig:ToggleValue(HTConfig:GetIsEnabledAutoInvitationsGuildOnly(nil))
end

-- ============================================================================
-- == GetIsEnabledAutoRaidPromotions(info)                                   ==
-- ==                                                                        ==
-- == Standard accessor function for the named property.                     ==
-- ============================================================================

function HTConfig:GetIsEnabledAutoRaidPromotions(info)
    return self.db.profile.isEnabledAutoRaidPromotions
end

-- ============================================================================
-- == SetIsEnabledAutoRaidPromotions(info, newValue)                         ==
-- ==                                                                        ==
-- == Standard mutator function for the named property.                      ==
-- ============================================================================

function HTConfig:SetIsEnabledAutoRaidPromotions(info, newValue)
    self.db.profile.isEnabledAutoRaidPromotions = newValue
end

-- ============================================================================
-- == ToggleIsEnabledAutoRaidPromotions()                                    ==
-- ==                                                                        ==
-- == Toggles the value of the named property.                               ==
-- ============================================================================

function HTConfig:ToggleIsEnabledAutoRaidPromotions()
    self.db.profile.isEnabledAutoRaidPromotions = HTConfig:ToggleValue(HTConfig:GetIsEnabledAutoRaidPromotions(nil))
end

-- ============================================================================
-- == GetIsEnabledAutoRIAResponse(info)                                      ==
-- ==                                                                        ==
-- == Standard accessor function for the named property.                     ==
-- ============================================================================

function HTConfig:GetIsEnabledAutoRIAResponse(info)
    return self.db.profile.isEnabledAutoRIAResponse
end

-- ============================================================================
-- == SetIsEnabledAutoRaidPromotions(info, newValue)                         ==
-- ==                                                                        ==
-- == Standard mutator function for the named property.                      ==
-- ============================================================================

function HTConfig:SetIsEnabledAutoRIAResponse(info, newValue)
    self.db.profile.isEnabledAutoRIAResponse = newValue
end

-- ============================================================================
-- == ToggleIsEnabledAutoRIAResponse()                                       ==
-- ==                                                                        ==
-- == Toggles the value of the named property.                               ==
-- ============================================================================

function HTConfig:ToggleIsEnabledAutoRIAResponse()
    self.db.profile.isEnabledAutoRIAResponse = HTConfig:ToggleValue(HTConfig:GetIsEnabledAutoRIAResponse(nil))
end

-- ============================================================================
-- == GetIsEnabledAutoRQAResponse(info)                                     ==
-- ==                                                                        ==
-- == Standard accessor function for the named property.                     ==
-- ============================================================================

function HTConfig:GetIsEnabledAutoRQAResponse(info)
    return self.db.profile.isEnabledAutoRQAResponse
end

-- ============================================================================
-- == SetIsEnabledAutoRQAResponse(info, newValue)                            ==
-- ==                                                                        ==
-- == Standard mutator function for the named property.                      ==
-- ============================================================================

function HTConfig:SetIsEnabledAutoRQAResponse(info, newValue)
    self.db.profile.isEnabledAutoRQAResponse = newValue
end

-- ============================================================================
-- == ToggleIsEnabledAutoRQAResponse()                                       ==
-- ==                                                                        ==
-- == Toggles the value of the named property.                               ==
-- ============================================================================

function HTConfig:ToggleIsEnabledAutoRQAResponse()
    self.db.profile.isEnabledAutoRQAResponse = HTConfig:ToggleValue(HTConfig:GetIsEnabledAutoRQAResponse(nil))
end

-- ============================================================================
-- == GetIsEnabledDebugMode(info)                                            ==
-- ==                                                                        ==
-- == Standard accessor function for the named property.                     ==
-- ============================================================================

function HTConfig:GetIsEnabledDebugMode(info)
    return self.db.profile.isEnabledDebugMode
end

-- ============================================================================
-- == SetIsEnabledDebugMode(info, newValue)                                  ==
-- ==                                                                        ==
-- == Standard mutator function for the named property.                      ==
-- ============================================================================

function HTConfig:SetIsEnabledDebugMode(info, newValue)
    self.db.profile.isEnabledDebugMode = newValue
end

-- ============================================================================
-- == ToggleIsEnabledDebugMode()                                             ==
-- ==                                                                        ==
-- == Toggles the value of the named property.                               ==
-- ============================================================================

function HTConfig:ToggleIsEnabledDebugMode()
    self.db.profile.isEnabledDebugMode = HTConfig:ToggleValue(HTConfig:GetIsEnabledDebugMode(nil))
end

-- ============================================================================
-- == GetIsEnabledDebugFilter(info)                                          ==
-- ==                                                                        ==
-- == Standard accessor function for the named property.                     ==
-- ============================================================================

function HTConfig:GetIsEnabledDebugFilter(info)
    return self.db.profile.isEnabledDebugFilter
end

-- ============================================================================
-- == SetIsEnabledDebugFilter(info, newValue)                                ==
-- ==                                                                        ==
-- == Standard mutator function for the named property.                      ==
-- ============================================================================

function HTConfig:SetIsEnabledDebugFilter(info, newValue)
    self.db.profile.isEnabledDebugFilter = newValue
end

-- ============================================================================
-- == ToggleIsEnabledDebugFilter()                                           ==
-- ==                                                                        ==
-- == Toggles the value of the named property.                               ==
-- ============================================================================

function HTConfig:ToggleIsEnabledDebugFilter()
    self.db.profile.isEnabledDebugFilter = HTConfig:ToggleValue(HTConfig:GetIsEnabledDebugFilter(nil))
end

-- ============================================================================
-- == GetDebugFilter(info)                                                   ==
-- ==                                                                        ==
-- == Standard accessor function for the named property.                     ==
-- ============================================================================

function HTConfig:GetDebugFilter(info)
    return self.db.profile.debugFilter
end

-- ============================================================================
-- == SetDebugFilter(info, newValue)                                         ==
-- ==                                                                        ==
-- == Standard mutator function for the named property.                      ==
-- ============================================================================

function HTConfig:SetDebugFilter(info, newValue)
    self.db.profile.debugFilter = newValue
end

-- ============================================================================
-- == GetIsEnabledAlertNewAddonVersion(info)                                 ==
-- ==                                                                        ==
-- == Standard accessor function for the named property.                     ==
-- ============================================================================

function HTConfig:GetIsEnabledAlertNewAddonVersion(info)
    return self.db.profile.isEnabledAlertNewAddonVersion
end

-- ============================================================================
-- == SetIsEnabledAlertNewAddonVersion(info, newValue)                       ==
-- ==                                                                        ==
-- == Standard mutator function for the named property.                      ==
-- ============================================================================

function HTConfig:SetIsEnabledAlertNewAddonVersion(info, newValue)
    self.db.profile.isEnabledAlertNewAddonVersion = newValue
end

-- ============================================================================
-- == ToggleIsEnabledAlertNewAddonVersion()                                  ==
-- ==                                                                        ==
-- == Toggles the value of the named property.                               ==
-- ============================================================================

function HTConfig:ToggleIsEnabledAlertNewAddonVersion()
    self.db.profile.isEnabledAlertNewAddonVersion = HTConfig:ToggleValue(HTConfig:GetIsEnabledAlertNewAddonVersion(nil))
end

-- ============================================================================
-- == GetChatWindowTextMaxWidth(info)                                        ==
-- ==                                                                        ==
-- == Standard accessor function for the named property.                     ==
-- ============================================================================

function HTConfig:GetChatWindowTextMaxWidth(info)
    return self.db.profile.chatWindowTextMaxWidth
end

-- ============================================================================
-- == SetChatWindowTextMaxWidth(info, newValue)                              ==
-- ==                                                                        ==
-- == Standard mutator function for the named property.                      ==
-- ============================================================================

function HTConfig:SetChatWindowTextMaxWidth(info, newValue)
    self.db.profile.chatWindowTextMaxWidth = newValue
end

-- ============================================================================
-- == GetHeartbeatInterval(info)                                             ==
-- ==                                                                        ==
-- == Standard accessor function for the named property.                     ==
-- ============================================================================

function HTConfig:GetHeartbeatInterval(info)
    return self.db.profile.heartbeatInterval
end

-- ============================================================================
-- == SetHeartbeatInterval(info, newValue)                                   ==
-- ==                                                                        ==
-- == Standard mutator function for the named property.                      ==
-- ============================================================================

function HTConfig:SetHeartbeatInterval(info, newValue)
    self.db.profile.heartbeatInterval = newValue
end

-- ============================================================================
-- == GetMaxAddonVersionSeen(info)                                            ==
-- ==                                                                        ==
-- == Standard accessor function for the named property.                     ==
-- ============================================================================

function HTConfig:GetMaxAddonVersionSeen(info)
    return self.db.profile.maxAddonVersionSeen
end

-- ============================================================================
-- == SetMaxAddonVersionSeen(info, newValue)                                 ==
-- ==                                                                        ==
-- == Standard mutator function for the named property.                      ==
-- ============================================================================

function HTConfig:SetMaxAddonVersionSeen(info, newValue)
    self.db.profile.maxAddonVersionSeen = newValue
end

-- ============================================================================
-- == GetMyLastVersion(info)                                                 ==
-- ==                                                                        ==
-- == Standard accessor function for the named property.                     ==
-- ============================================================================

function HTConfig:GetMyLastVersion(info)
    return self.db.profile.myLastVersion
end

-- ============================================================================
-- == SetMyLastVersion(info, newValue)                                       ==
-- ==                                                                        ==
-- == Standard mutator function for the named property.                      ==
-- ============================================================================

function HTConfig:SetMyLastVersion(info, newValue)
    self.db.profile.myLastVersion = newValue
end

-- ============================================================================
-- == GetIsEnabledTooltipContentButtonActions(info)                          ==
-- ==                                                                        ==
-- == Standard accessor function for the named property.                     ==
-- ============================================================================

function HTConfig:GetIsEnabledTooltipContentButtonActions(info)
    return self.db.profile.isEnabledTooltipContentButtonActions
end

-- ============================================================================
-- == SetIsEnabledTooltipContentButtonActions(info, newValue)                ==
-- ==                                                                        ==
-- == Standard mutator function for the named property.                      ==
-- ============================================================================

function HTConfig:SetIsEnabledTooltipContentButtonActions(info, newValue)
    self.db.profile.isEnabledTooltipContentButtonActions = newValue
end

-- ============================================================================
-- == ToggleIsEnabledTooltipContentButtonActions()                           ==
-- ==                                                                        ==
-- == Toggles the value of the named property.                               ==
-- ============================================================================

function HTConfig:ToggleIsEnabledTooltipContentButtonActions()
    self.db.profile.isEnabledTooltipContentButtonActions = HTConfig:ToggleValue(HTConfig:GetIsEnabledTooltipContentButtonActions(nil))
end

-- ============================================================================
-- == GetBrokerSupportHeartbeatResting(info)                                 ==
-- ==                                                                        ==
-- == Standard accessor function for the named property.                     ==
-- ============================================================================

function HTConfig:GetBrokerSupportHeartbeatResting(info)
    return self.db.profile.brokerSupportHeartbeatResting
end

-- ============================================================================
-- == SetBrokerSupportHeartbeatResting(info, newValue)                       ==
-- ==                                                                        ==
-- == Standard mutator function for the named property.                      ==
-- ============================================================================

function HTConfig:SetBrokerSupportHeartbeatResting(info, newValue)
    self.db.profile.brokerSupportHeartbeatResting = newValue
end

-- ============================================================================
-- == GetIsEnabledTextLabelContentBRMessageNum(info)                         ==
-- ==                                                                        ==
-- == Standard accessor function for the named property.                     ==
-- ============================================================================

function HTConfig:GetIsEnabledTextLabelContentBRMessageNum(info)
    return self.db.profile.isEnabledTextLabelContentBRMessageNum
end

-- ============================================================================
-- == SetIsEnabledTextLabelContentBRMessageNum(info, newValue)               ==
-- ==                                                                        ==
-- == Standard mutator function for the named property.                      ==
-- ============================================================================

function HTConfig:SetIsEnabledTextLabelContentBRMessageNum(info, newValue)
    self.db.profile.isEnabledTextLabelContentBRMessageNum = newValue
end

-- ============================================================================
-- == ToggleIsEnabledTextLabelContentBRMessageNum()                          ==
-- ==                                                                        ==
-- == Toggles the value of the named property.                               ==
-- ============================================================================

function HTConfig:ToggleIsEnabledTextLabelContentBRMessageNum()
    self.db.profile.isEnabledTextLabelContentBRMessageNum = HTConfig:ToggleValue(HTConfig:GetIsEnabledTextLabelContentBRMessageNum(nil))
end

-- ============================================================================
-- == GetIsEnabledTextLabelContentGStatsMembers(info)                        ==
-- ==                                                                        ==
-- == Standard accessor function for the named property.                     ==
-- ============================================================================

function HTConfig:GetIsEnabledTextLabelContentGStatsMembers(info)
    return self.db.profile.isEnabledTextLabelContentGStatsMembers
end

-- ============================================================================
-- == SetIsEnabledTextLabelContentGStatsMembers(info, newValue)              ==
-- ==                                                                        ==
-- == Standard mutator function for the named property.                      ==
-- ============================================================================

function HTConfig:SetIsEnabledTextLabelContentGStatsMembers(info, newValue)
    self.db.profile.isEnabledTextLabelContentGStatsMembers = newValue
end

-- ============================================================================
-- == ToggleIsEnabledTextLabelContentGStatsMembers()                         ==
-- ==                                                                        ==
-- == Toggles the value of the named property.                               ==
-- ============================================================================

function HTConfig:ToggleIsEnabledTextLabelContentGStatsMembers()
    self.db.profile.isEnabledTextLabelContentGStatsMembers = HTConfig:ToggleValue(HTConfig:GetIsEnabledTextLabelContentGStatsMembers(nil))
end

-- ============================================================================
-- == GetIsEnabledTextLabelContentGStatsRaiders(info)                        ==
-- ==                                                                        ==
-- == Standard accessor function for the named property.                     ==
-- ============================================================================

function HTConfig:GetIsEnabledTextLabelContentGStatsRaiders(info)
    return self.db.profile.isEnabledTextLabelContentGStatsRaiders
end

-- ============================================================================
-- == SetIsEnabledTextLabelContentGStatsRaiders(info, newValue)              ==
-- ==                                                                        ==
-- == Standard mutator function for the named property.                      ==
-- ============================================================================

function HTConfig:SetIsEnabledTextLabelContentGStatsRaiders(info, newValue)
    self.db.profile.isEnabledTextLabelContentGStatsRaiders = newValue
end

-- ============================================================================
-- == ToggleIsEnabledTextLabelContentGStatsRaiders()                         ==
-- ==                                                                        ==
-- == Toggles the value of the named property.                               ==
-- ============================================================================

function HTConfig:ToggleIsEnabledTextLabelContentGStatsRaiders()
    self.db.profile.isEnabledTextLabelContentGStatsRaiders = HTConfig:ToggleValue(HTConfig:GetIsEnabledTextLabelContentGStatsRaiders(nil))
end

-- ============================================================================
-- == GetIsEnabledTextLabelContentGStatsOfficers(info)                       ==
-- ==                                                                        ==
-- == Standard accessor function for the named property.                     ==
-- ============================================================================

function HTConfig:GetIsEnabledTextLabelContentGStatsOfficers(info)
    return self.db.profile.isEnabledTextLabelContentGStatsOfficers
end

-- ============================================================================
-- == SetIsEnabledTextLabelContentGStatsOfficers(info, newValue)             ==
-- ==                                                                        ==
-- == Standard mutator function for the named property.                      ==
-- ============================================================================

function HTConfig:SetIsEnabledTextLabelContentGStatsOfficers(info, newValue)
    self.db.profile.isEnabledTextLabelContentGStatsOfficers = newValue
end

-- ============================================================================
-- == ToggleIsEnabledTextLabelContentGStatsOfficers()                        ==
-- ==                                                                        ==
-- == Toggles the value of the named property.                               ==
-- ============================================================================

function HTConfig:ToggleIsEnabledTextLabelContentGStatsOfficers()
    self.db.profile.isEnabledTextLabelContentGStatsOfficers = HTConfig:ToggleValue(HTConfig:GetIsEnabledTextLabelContentGStatsOfficers(nil))
end

-- ============================================================================
-- == GetIsEnabledTextLabelContentGStatsCharacters(info)                     ==
-- ==                                                                        ==
-- == Standard accessor function for the named property.                     ==
-- ============================================================================

function HTConfig:GetIsEnabledTextLabelContentGStatsCharacters(info)
    return self.db.profile.isEnabledTextLabelContentGStatsCharacters
end

-- ============================================================================
-- == SetIsEnabledTextLabelContentGStatsCharacters(info, newValue)           ==
-- ==                                                                        ==
-- == Standard mutator function for the named property.                      ==
-- ============================================================================

function HTConfig:SetIsEnabledTextLabelContentGStatsCharacters(info, newValue)
    self.db.profile.isEnabledTextLabelContentGStatsCharacters = newValue
end

-- ============================================================================
-- == ToggleIsEnabledTextLabelContentGStatsCharacters()                      ==
-- ==                                                                        ==
-- == Toggles the value of the named property.                               ==
-- ============================================================================

function HTConfig:ToggleIsEnabledTextLabelContentGStatsCharacters()
    self.db.profile.isEnabledTextLabelContentGStatsCharacters = HTConfig:ToggleValue(HTConfig:GetIsEnabledTextLabelContentGStatsCharacters(nil))
end

-- ============================================================================
-- == GetIsEnabledTextLabelContentGuildPlayMode(info)                        ==
-- ==                                                                        ==
-- == Standard accessor function for the named property.                     ==
-- ============================================================================

function HTConfig:GetIsEnabledTextLabelContentGuildPlayMode(info)
    return self.db.profile.isEnabledTextLabelContentGuildPlayMode
end

-- ============================================================================
-- == SetIsEnabledTextLabelContentGuildPlayMode(info, newValue)              ==
-- ==                                                                        ==
-- == Standard mutator function for the named property.                      ==
-- ============================================================================

function HTConfig:SetIsEnabledTextLabelContentGuildPlayMode(info, newValue)
    self.db.profile.isEnabledTextLabelContentGuildPlayMode = newValue
end

-- ============================================================================
-- == ToggleIsEnabledTextLabelContentGuildPlayMode()                         ==
-- ==                                                                        ==
-- == Toggles the value of the named property.                               ==
-- ============================================================================

function HTConfig:ToggleIsEnabledTextLabelContentGuildPlayMode()
    self.db.profile.isEnabledTextLabelContentGuildPlayMode = HTConfig:ToggleValue(HTConfig:GetIsEnabledTextLabelContentGuildPlayMode(nil))
end

-- ============================================================================
-- == GetIsEnabledTextLabelContentCombatStatus(info)                         ==
-- ==                                                                        ==
-- == Standard accessor function for the named property.                     ==
-- ============================================================================

function HTConfig:GetIsEnabledTextLabelContentCombatStatus(info)
    return self.db.profile.isEnabledTextLabelContentCombatStatus
end

-- ============================================================================
-- == SetIsEnabledTextLabelContentCombatStatus(info, newValue)               ==
-- ==                                                                        ==
-- == Standard mutator function for the named property.                      ==
-- ============================================================================

function HTConfig:SetIsEnabledTextLabelContentCombatStatus(info, newValue)
    self.db.profile.isEnabledTextLabelContentCombatStatus = newValue
end

-- ============================================================================
-- == ToggleIsEnabledTextLabelContentCombatStatus()                          ==
-- ==                                                                        ==
-- == Toggles the value of the named property.                               ==
-- ============================================================================

function HTConfig:ToggleIsEnabledTextLabelContentCombatStatus()
    self.db.profile.isEnabledTextLabelContentCombatStatus = HTConfig:ToggleValue(HTConfig:GetIsEnabledTextLabelContentCombatStatus(nil))
end

-- ============================================================================
-- == GetIsEnabledTextLabelContentShowMinimised(info)                        ==
-- ==                                                                        ==
-- == Standard accessor function for the named property.                     ==
-- ============================================================================

function HTConfig:GetIsEnabledTextLabelContentShowMinimised(info)
    return self.db.profile.isEnabledTextLabelContentShowMinimised
end

-- ============================================================================
-- == SetIsEnabledTextLabelContentShowMinimised(info, newValue)              ==
-- ==                                                                        ==
-- == Standard mutator function for the named property.                      ==
-- ============================================================================

function HTConfig:SetIsEnabledTextLabelContentShowMinimised(info, newValue)
    self.db.profile.isEnabledTextLabelContentShowMinimised = newValue
end

-- ============================================================================
-- == ToggleIsEnabledTextLabelContentShowMinimised()                         ==
-- ==                                                                        ==
-- == Toggles the value of the named property.                               ==
-- ============================================================================

function HTConfig:ToggleIsEnabledTextLabelContentShowMinimised()
    self.db.profile.isEnabledTextLabelContentShowMinimised = HTConfig:ToggleValue(HTConfig:GetIsEnabledTextLabelContentShowMinimised(nil))
end

-- ============================================================================
-- == GetIsEnabledTooltipContentGuildInformation(info)                       ==
-- ==                                                                        ==
-- == Standard accessor function for the named property.                     ==
-- ============================================================================

function HTConfig:GetIsEnabledTooltipContentGuildInformation(info)
    return self.db.profile.isEnabledTooltipContentGuildInformation
end

-- ============================================================================
-- == SetIsEnabledTooltipContentGuildInformation(info, newValue)             ==
-- ==                                                                        ==
-- == Standard mutator function for the named property.                      ==
-- ============================================================================

function HTConfig:SetIsEnabledTooltipContentGuildInformation(info, newValue)
    self.db.profile.isEnabledTooltipContentGuildInformation = newValue
end

-- ============================================================================
-- == ToggleIsEnabledTooltipContentGuildInformation()                        ==
-- ==                                                                        ==
-- == Toggles the value of the named property.                               ==
-- ============================================================================

function HTConfig:ToggleIsEnabledTooltipContentGuildInformation()
    self.db.profile.isEnabledTooltipContentGuildInformation = HTConfig:ToggleValue(HTConfig:GetIsEnabledTooltipContentGuildInformation(nil))
end

-- ============================================================================
-- == GetIsEnabledTooltipContentGuildStatistics(info)                        ==
-- ==                                                                        ==
-- == Standard accessor function for the named property.                     ==
-- ============================================================================

function HTConfig:GetIsEnabledTooltipContentGuildStatistics(info)
    return self.db.profile.isEnabledTooltipContentGuildStatistics
end

-- ============================================================================
-- == SetIsEnabledTooltipContentGuildStatistics(info, newValue)              ==
-- ==                                                                        ==
-- == Standard mutator function for the named property.                      ==
-- ============================================================================

function HTConfig:SetIsEnabledTooltipContentGuildStatistics(info, newValue)
    self.db.profile.isEnabledTooltipContentGuildStatistics = newValue
end

-- ============================================================================
-- == ToggleIsEnabledTooltipContentGuildStatistics()                         ==
-- ==                                                                        ==
-- == Toggles the value of the named property.                               ==
-- ============================================================================

function HTConfig:ToggleIsEnabledTooltipContentGuildStatistics()
    self.db.profile.isEnabledTooltipContentGuildStatistics = HTConfig:ToggleValue(HTConfig:GetIsEnabledTooltipContentGuildStatistics(nil))
end

-- ============================================================================
-- == GetIsEnabledTooltipContentGMOTD(info)                                  ==
-- ==                                                                        ==
-- == Standard accessor function for the named property.                     ==
-- ============================================================================

function HTConfig:GetIsEnabledTooltipContentGMOTD(info)
    return self.db.profile.isEnabledTooltipContentGMOTD
end

-- ============================================================================
-- == SetIsEnabledTooltipContentGMOTD(info, newValue)                        ==
-- ==                                                                        ==
-- == Standard mutator function for the named property.                      ==
-- ============================================================================

function HTConfig:SetIsEnabledTooltipContentGMOTD(info, newValue)
    self.db.profile.isEnabledTooltipContentGMOTD = newValue
end

-- ============================================================================
-- == ToggleIsEnabledTooltipContentGMOTD()                                   ==
-- ==                                                                        ==
-- == Toggles the value of the named property.                               ==
-- ============================================================================

function HTConfig:ToggleIsEnabledTooltipContentGMOTD()
    self.db.profile.isEnabledTooltipContentGMOTD = HTConfig:ToggleValue(HTConfig:GetIsEnabledTooltipContentGMOTD(nil))
end

-- ============================================================================
-- == GetIsEnabledTooltipContentOfficerList(info)                            ==
-- ==                                                                        ==
-- == Standard accessor function for the named property.                     ==
-- ============================================================================

function HTConfig:GetIsEnabledTooltipContentOfficerList(info)
    return self.db.profile.isEnabledTooltipContentOfficerList
end

-- ============================================================================
-- == SetIsEnabledTooltipContentOfficerList(info, newValue)             ==
-- ==                                                                        ==
-- == Standard mutator function for the named property.                      ==
-- ============================================================================

function HTConfig:SetIsEnabledTooltipContentOfficerList(info, newValue)
    self.db.profile.isEnabledTooltipContentOfficerList = newValue
end

-- ============================================================================
-- == ToggleIsEnabledTooltipContentOfficerList()                        ==
-- ==                                                                        ==
-- == Toggles the value of the named property.                               ==
-- ============================================================================

function HTConfig:ToggleIsEnabledTooltipContentOfficerList()
    self.db.profile.isEnabledTooltipContentOfficerList = HTConfig:ToggleValue(HTConfig:GetIsEnabledTooltipContentOfficerList(nil))
end

-- ============================================================================
-- == GetIsEnabledTooltipContentToolStatusInfo(info)                       ==
-- ==                                                                        ==
-- == Standard accessor function for the named property.                     ==
-- ============================================================================

function HTConfig:GetIsEnabledTooltipContentToolStatusInfo(info)
    return self.db.profile.isEnabledTooltipContentToolStatusInfo
end

-- ============================================================================
-- == SetIsEnabledTooltipContentToolStatusInfo(info, newValue)             ==
-- ==                                                                        ==
-- == Standard mutator function for the named property.                      ==
-- ============================================================================

function HTConfig:SetIsEnabledTooltipContentToolStatusInfo(info, newValue)
    self.db.profile.isEnabledTooltipContentToolStatusInfo = newValue
end

-- ============================================================================
-- == ToggleIsEnabledTooltipContentToolStatusInfo()                        ==
-- ==                                                                        ==
-- == Toggles the value of the named property.                               ==
-- ============================================================================

function HTConfig:ToggleIsEnabledTooltipContentToolStatusInfo()
    self.db.profile.isEnabledTooltipContentToolStatusInfo = HTConfig:ToggleValue(HTConfig:GetIsEnabledTooltipContentToolStatusInfo(nil))
end

-- ============================================================================
-- == GetIsEnabledBuffMonitor(info)                                          ==
-- ==                                                                        ==
-- == Standard accessor function for the named property.                     ==
-- ============================================================================

function HTConfig:GetIsEnabledBuffMonitor(info)
    return self.db.profile.isEnabledBuffMonitor
end

-- ============================================================================
-- == SetIsEnabledBuffMonitor(info, newValue)                                ==
-- ==                                                                        ==
-- == Standard mutator function for the named property.                      ==
-- ============================================================================

function HTConfig:SetIsEnabledBuffMonitor(info, newValue)
    self.db.profile.isEnabledBuffMonitor = newValue
end

-- ============================================================================
-- == ToggleIsEnabledBuffMonitor()                                           ==
-- ==                                                                        ==
-- == Toggles the value of the named property.                               ==
-- ============================================================================

function HTConfig:ToggleIsEnabledBuffMonitor()
    self.db.profile.isEnabledBuffMonitor = HTConfig:ToggleValue(HTConfig:GetIsEnabledBuffMonitor(nil))
end

-- ============================================================================
-- == GetIsEnabledBuffMonitorCheckOnReadyCheck(info)                         ==
-- ==                                                                        ==
-- == Standard accessor function for the named property.                     ==
-- ============================================================================

function HTConfig:GetIsEnabledBuffMonitorCheckOnReadyCheck(info)
    return self.db.profile.isEnabledBuffMonitorCheckOnReadyCheck
end

-- ============================================================================
-- == SetIsEnabledBuffMonitorCheckOnReadyCheck(info, newValue)               ==
-- ==                                                                        ==
-- == Standard mutator function for the named property.                      ==
-- ============================================================================

function HTConfig:SetIsEnabledBuffMonitorCheckOnReadyCheck(info, newValue)
    self.db.profile.isEnabledBuffMonitorCheckOnReadyCheck = newValue
end

-- ============================================================================
-- == ToggleIsEnabledBuffMonitorCheckOnReadyCheck()                          ==
-- ==                                                                        ==
-- == Toggles the value of the named property.                               ==
-- ============================================================================

function HTConfig:ToggleIsEnabledBuffMonitorCheckOnReadyCheck()
    self.db.profile.isEnabledBuffMonitorCheckOnReadyCheck = HTConfig:ToggleValue(HTConfig:GetIsEnabledBuffMonitorCheckOnReadyCheck(nil))
end

-- ============================================================================
-- == GetIsEnabledBuffMonitorCheckOnCombatStart(info)                        ==
-- ==                                                                        ==
-- == Standard accessor function for the named property.                     ==
-- ============================================================================

function HTConfig:GetIsEnabledBuffMonitorCheckOnCombatStart(info)
    return self.db.profile.isEnabledBuffMonitorCheckOnCombatStart
end

-- ============================================================================
-- == SetIsEnabledBuffMonitorCheckOnCombatStart(info, newValue)              ==
-- ==                                                                        ==
-- == Standard mutator function for the named property.                      ==
-- ============================================================================

function HTConfig:SetIsEnabledBuffMonitorCheckOnCombatStart(info, newValue)
    self.db.profile.isEnabledBuffMonitorCheckOnCombatStart = newValue
end

-- ============================================================================
-- == ToggleIsEnabledBuffMonitorCheckOnCombatStart()                         ==
-- ==                                                                        ==
-- == Toggles the value of the named property.                               ==
-- ============================================================================

function HTConfig:ToggleIsEnabledBuffMonitorCheckOnCombatStart()
    self.db.profile.isEnabledBuffMonitorCheckOnCombatStart = HTConfig:ToggleValue(HTConfig:GetIsEnabledBuffMonitorCheckOnCombatStart(nil))
end

-- ============================================================================
-- == GetIsEnabledBuffMonitorCheckOnHeartbeat(info)                          ==
-- ==                                                                        ==
-- == Standard accessor function for the named property.                     ==
-- ============================================================================

function HTConfig:GetIsEnabledBuffMonitorCheckOnHeartbeat(info)
    return self.db.profile.isEnabledBuffMonitorCheckOnHeartbeat
end

-- ============================================================================
-- == SetIsEnabledBuffMonitorCheckOnHeartbeat(info, newValue)                ==
-- ==                                                                        ==
-- == Standard mutator function for the named property.                      ==
-- ============================================================================

function HTConfig:SetIsEnabledBuffMonitorCheckOnHeartbeat(info, newValue)
    self.db.profile.isEnabledBuffMonitorCheckOnHeartbeat = newValue
end

-- ============================================================================
-- == ToggleIsEnabledBuffMonitorCheckOnHeartbeat()                           ==
-- ==                                                                        ==
-- == Toggles the value of the named property.                               ==
-- ============================================================================

function HTConfig:ToggleIsEnabledBuffMonitorCheckOnHeartbeat()
    self.db.profile.isEnabledBuffMonitorCheckOnHeartbeat = HTConfig:ToggleValue(HTConfig:GetIsEnabledBuffMonitorCheckOnHeartbeat(nil))
end

-- ============================================================================
-- == GetIsEnabledBuffMonitorMistsBuffs(info)                                ==
-- ==                                                                        ==
-- == Standard accessor function for the named property.                     ==
-- ============================================================================

function HTConfig:GetIsEnabledBuffMonitorMistsBuffs(info)
    return self.db.profile.isEnabledBuffMonitorMistsBuffs
end

-- ============================================================================
-- == SetIsEnabledBuffMonitorMistsBuffs(info, newValue)                      ==
-- ==                                                                        ==
-- == Standard mutator function for the named property.                      ==
-- ============================================================================

function HTConfig:SetIsEnabledBuffMonitorMistsBuffs(info, newValue)
    self.db.profile.isEnabledBuffMonitorMistsBuffs = newValue
end

-- ============================================================================
-- == ToggleIsEnabledBuffMonitorMistsBuffs()                                 ==
-- ==                                                                        ==
-- == Toggles the value of the named property.                               ==
-- ============================================================================

function HTConfig:ToggleIsEnabledBuffMonitorMistsBuffs()
    self.db.profile.isEnabledBuffMonitorMistsBuffs = HTConfig:ToggleValue(HTConfig:GetIsEnabledBuffMonitorMistsBuffs(nil))
end

-- ============================================================================
-- == GetIsEnabledBuffMonitorCataBuffs(info)                                 ==
-- ==                                                                        ==
-- == Standard accessor function for the named property.                     ==
-- ============================================================================

function HTConfig:GetIsEnabledBuffMonitorCataBuffs(info)
    return self.db.profile.isEnabledBuffMonitorCataBuffs
end

-- ============================================================================
-- == SetIsEnabledBuffMonitorCataBuffs(info, newValue)                       ==
-- ==                                                                        ==
-- == Standard mutator function for the named property.                      ==
-- ============================================================================

function HTConfig:SetIsEnabledBuffMonitorCataBuffs(info, newValue)
    self.db.profile.isEnabledBuffMonitorCataBuffs = newValue
end

-- ============================================================================
-- == ToggleIsEnabledBuffMonitorCataBuffs()                                  ==
-- ==                                                                        ==
-- == Toggles the value of the named property.                               ==
-- ============================================================================

function HTConfig:ToggleIsEnabledBuffMonitorCataBuffs()
    self.db.profile.isEnabledBuffMonitorCataBuffs = HTConfig:ToggleValue(HTConfig:GetIsEnabledBuffMonitorCataBuffs(nil))
end

-- ============================================================================
-- == GetIsEnabledBuffMonitorWrathBuffs(info)                                ==
-- ==                                                                        ==
-- == Standard accessor function for the named property.                     ==
-- ============================================================================

function HTConfig:GetIsEnabledBuffMonitorWrathBuffs(info)
    return self.db.profile.isEnabledBuffMonitorWrathBuffs
end

-- ============================================================================
-- == SetIsEnabledBuffMonitorWrathBuffs(info, newValue)                      ==
-- ==                                                                        ==
-- == Standard mutator function for the named property.                      ==
-- ============================================================================

function HTConfig:SetIsEnabledBuffMonitorWrathBuffs(info, newValue)
    self.db.profile.isEnabledBuffMonitorWrathBuffs = newValue
end

-- ============================================================================
-- == ToggleIsEnabledBuffMonitorWrathBuffs()                                 ==
-- ==                                                                        ==
-- == Toggles the value of the named property.                               ==
-- ============================================================================

function HTConfig:ToggleIsEnabledBuffMonitorWrathBuffs()
    self.db.profile.isEnabledBuffMonitorWrathBuffs = HTConfig:ToggleValue(HTConfig:GetIsEnabledBuffMonitorWrathBuffs(nil))
end

-- ============================================================================
-- == GetIsEnabledBuffMonitorMistsFlasks(info)                               ==
-- ==                                                                        ==
-- == Standard accessor function for the named property.                     ==
-- ============================================================================

function HTConfig:GetIsEnabledBuffMonitorMistsFlasks(info)
    return self.db.profile.isEnabledBuffMonitorMistsFlasks
end

-- ============================================================================
-- == SetIsEnabledBuffMonitorMistsFlasks(info, newValue)                     ==
-- ==                                                                        ==
-- == Standard mutator function for the named property.                      ==
-- ============================================================================

function HTConfig:SetIsEnabledBuffMonitorMistsFlasks(info, newValue)
    self.db.profile.isEnabledBuffMonitorMistsFlasks = newValue
end

-- ============================================================================
-- == ToggleIsEnabledBuffMonitorMistsFlasks()                                ==
-- ==                                                                        ==
-- == Toggles the value of the named property.                               ==
-- ============================================================================

function HTConfig:ToggleIsEnabledBuffMonitorMistsFlasks()
    self.db.profile.isEnabledBuffMonitorMistsFlasks = HTConfig:ToggleValue(HTConfig:GetIsEnabledBuffMonitorMistsFlasks(nil))
end

-- ============================================================================
-- == GetIsEnabledBuffMonitorMistsBattleElixirs(info)                        ==
-- ==                                                                        ==
-- == Standard accessor function for the named property.                     ==
-- ============================================================================

function HTConfig:GetIsEnabledBuffMonitorMistsBattleElixirs(info)
    return self.db.profile.isEnabledBuffMonitorMistsBattleElixirs
end

-- ============================================================================
-- == BuffMonitorMistsBattleElixirs(info, newValue)                          ==
-- ==                                                                        ==
-- == Standard mutator function for the named property.                      ==
-- ============================================================================

function HTConfig:SetIsEnabledBuffMonitorMistsBattleElixirs(info, newValue)
    self.db.profile.isEnabledBuffMonitorMistsBattleElixirs = newValue
end

-- ============================================================================
-- == ToggleIsEnabledBuffMonitorMistsBattleElixirs()                         ==
-- ==                                                                        ==
-- == Toggles the value of the named property.                               ==
-- ============================================================================

function HTConfig:ToggleIsEnabledBuffMonitorMistsBattleElixirs()
    self.db.profile.isEnabledBuffMonitorMistsBattleElixirs = HTConfig:ToggleValue(HTConfig:GetIsEnabledBuffMonitorMistsBattleElixirs(nil))
end

-- ============================================================================
-- == GetIsEnabledBuffMonitorMistsGuardianElixirs(info)                      ==
-- ==                                                                        ==
-- == Standard accessor function for the named property.                     ==
-- ============================================================================

function HTConfig:GetIsEnabledBuffMonitorMistsGuardianElixirs(info)
    return self.db.profile.isEnabledBuffMonitorMistsGuardianElixirs
end

-- ============================================================================
-- == BuffMonitorMistsGuardianElixirs(info, newValue)                        ==
-- ==                                                                        ==
-- == Standard mutator function for the named property.                      ==
-- ============================================================================

function HTConfig:SetIsEnabledBuffMonitorMistsGuardianElixirs(info, newValue)
    self.db.profile.isEnabledBuffMonitorMistsGuardianElixirs = newValue
end

-- ============================================================================
-- == ToggleIsEnabledBuffMonitorMistsGuardianElixirs()                       ==
-- ==                                                                        ==
-- == Toggles the value of the named property.                               ==
-- ============================================================================

function HTConfig:ToggleIsEnabledBuffMonitorMistsGuardianElixirs()
    self.db.profile.isEnabledBuffMonitorMistsGuardianElixirs = HTConfig:ToggleValue(HTConfig:GetIsEnabledBuffMonitorMistsGuardianElixirs(nil))
end

-- ============================================================================
-- == GetIsEnabledBuffMonitorMistsFood(info)                                 ==
-- ==                                                                        ==
-- == Standard accessor function for the named property.                     ==
-- ============================================================================

function HTConfig:GetIsEnabledBuffMonitorMistsFood(info)
    return self.db.profile.isEnabledBuffMonitorMistsFood
end

-- ============================================================================
-- == BuffMonitorMistsFood(info, newValue)                                   ==
-- ==                                                                        ==
-- == Standard mutator function for the named property.                      ==
-- ============================================================================

function HTConfig:SetIsEnabledBuffMonitorMistsFood(info, newValue)
    self.db.profile.isEnabledBuffMonitorMistsFood = newValue
end

-- ============================================================================
-- == ToggleIsEnabledBuffMonitorMistsFood()                                  ==
-- ==                                                                        ==
-- == Toggles the value of the named property.                               ==
-- ============================================================================

function HTConfig:ToggleIsEnabledBuffMonitorMistsFood()
    self.db.profile.isEnabledBuffMonitorMistsFood = HTConfig:ToggleValue(HTConfig:GetIsEnabledBuffMonitorMistsFood(nil))
end

-- ============================================================================
-- == GetIsEnabledBuffMonitorMistsPoisons(info)                              ==
-- ==                                                                        ==
-- == Standard accessor function for the named property.                     ==
-- ============================================================================

function HTConfig:GetIsEnabledBuffMonitorMistsPoisons(info)
    return self.db.profile.isEnabledBuffMonitorMistsPoisons
end

-- ============================================================================
-- == BuffMonitorMistsPoisons(info, newValue)                                ==
-- ==                                                                        ==
-- == Standard mutator function for the named property.                      ==
-- ============================================================================

function HTConfig:SetIsEnabledBuffMonitorMistsPoisons(info, newValue)
    self.db.profile.isEnabledBuffMonitorMistsPoisons = newValue
end

-- ============================================================================
-- == ToggleIsEnabledBuffMonitorMistsPoisons()                               ==
-- ==                                                                        ==
-- == Toggles the value of the named property.                               ==
-- ============================================================================

function HTConfig:ToggleIsEnabledBuffMonitorMistsPoisons()
    self.db.profile.isEnabledBuffMonitorMistsPoisons = HTConfig:ToggleValue(HTConfig:GetIsEnabledBuffMonitorMistsPoisons(nil))
end

-- ============================================================================
-- == GetIsEnabledBuffMonitorCataFlasks(info)                                ==
-- ==                                                                        ==
-- == Standard accessor function for the named property.                     ==
-- ============================================================================

function HTConfig:GetIsEnabledBuffMonitorCataFlasks(info)
    return self.db.profile.isEnabledBuffMonitorCataFlasks
end

-- ============================================================================
-- == SetIsEnabledBuffMonitorCataFlasks(info, newValue)                      ==
-- ==                                                                        ==
-- == Standard mutator function for the named property.                      ==
-- ============================================================================

function HTConfig:SetIsEnabledBuffMonitorCataFlasks(info, newValue)
    self.db.profile.isEnabledBuffMonitorCataFlasks = newValue
end

-- ============================================================================
-- == ToggleIsEnabledBuffMonitorCataFlasks()                                 ==
-- ==                                                                        ==
-- == Toggles the value of the named property.                               ==
-- ============================================================================

function HTConfig:ToggleIsEnabledBuffMonitorCataFlasks()
    self.db.profile.isEnabledBuffMonitorCataFlasks = HTConfig:ToggleValue(HTConfig:GetIsEnabledBuffMonitorCataFlasks(nil))
end

-- ============================================================================
-- == GetIsEnabledBuffMonitorCataBattleElixirs(info)                         ==
-- ==                                                                        ==
-- == Standard accessor function for the named property.                     ==
-- ============================================================================

function HTConfig:GetIsEnabledBuffMonitorCataBattleElixirs(info)
    return self.db.profile.isEnabledBuffMonitorCataBattleElixirs
end

-- ============================================================================
-- == BuffMonitorCataBattleElixirs(info, newValue)                           ==
-- ==                                                                        ==
-- == Standard mutator function for the named property.                      ==
-- ============================================================================

function HTConfig:SetIsEnabledBuffMonitorCataBattleElixirs(info, newValue)
    self.db.profile.isEnabledBuffMonitorCataBattleElixirs = newValue
end

-- ============================================================================
-- == ToggleIsEnabledBuffMonitorCataBattleElixirs()                          ==
-- ==                                                                        ==
-- == Toggles the value of the named property.                               ==
-- ============================================================================

function HTConfig:ToggleIsEnabledBuffMonitorCataBattleElixirs()
    self.db.profile.isEnabledBuffMonitorCataBattleElixirs = HTConfig:ToggleValue(HTConfig:GetIsEnabledBuffMonitorCataBattleElixirs(nil))
end

-- ============================================================================
-- == GetIsEnabledBuffMonitorCataGuardianElixirs(info)                       ==
-- ==                                                                        ==
-- == Standard accessor function for the named property.                     ==
-- ============================================================================

function HTConfig:GetIsEnabledBuffMonitorCataGuardianElixirs(info)
    return self.db.profile.isEnabledBuffMonitorCataGuardianElixirs
end

-- ============================================================================
-- == BuffMonitorCataGuardianElixirs(info, newValue)                         ==
-- ==                                                                        ==
-- == Standard mutator function for the named property.                      ==
-- ============================================================================

function HTConfig:SetIsEnabledBuffMonitorCataGuardianElixirs(info, newValue)
    self.db.profile.isEnabledBuffMonitorCataGuardianElixirs = newValue
end

-- ============================================================================
-- == ToggleIsEnabledBuffMonitorCataGuardianElixirs()                        ==
-- ==                                                                        ==
-- == Toggles the value of the named property.                               ==
-- ============================================================================

function HTConfig:ToggleIsEnabledBuffMonitorCataGuardianElixirs()
    self.db.profile.isEnabledBuffMonitorCataGuardianElixirs = HTConfig:ToggleValue(HTConfig:GetIsEnabledBuffMonitorCataGuardianElixirs(nil))
end

-- ============================================================================
-- == GetIsEnabledBuffMonitorCataFood(info)                                  ==
-- ==                                                                        ==
-- == Standard accessor function for the named property.                     ==
-- ============================================================================

function HTConfig:GetIsEnabledBuffMonitorCataFood(info)
    return self.db.profile.isEnabledBuffMonitorCataFood
end

-- ============================================================================
-- == BuffMonitorCataFood(info, newValue)                                    ==
-- ==                                                                        ==
-- == Standard mutator function for the named property.                      ==
-- ============================================================================

function HTConfig:SetIsEnabledBuffMonitorCataFood(info, newValue)
    self.db.profile.isEnabledBuffMonitorCataFood = newValue
end

-- ============================================================================
-- == ToggleIsEnabledBuffMonitorCataFood()                                   ==
-- ==                                                                        ==
-- == Toggles the value of the named property.                               ==
-- ============================================================================

function HTConfig:ToggleIsEnabledBuffMonitorCataFood()
    self.db.profile.isEnabledBuffMonitorCataFood = HTConfig:ToggleValue(HTConfig:GetIsEnabledBuffMonitorCataFood(nil))
end

-- ============================================================================
-- == GetIsEnabledBuffMonitorCataPoisons(info)                               ==
-- ==                                                                        ==
-- == Standard accessor function for the named property.                     ==
-- ============================================================================

function HTConfig:GetIsEnabledBuffMonitorCataPoisons(info)
    return self.db.profile.isEnabledBuffMonitorCataPoisons
end

-- ============================================================================
-- == BuffMonitorCataPoisons(info, newValue)                                 ==
-- ==                                                                        ==
-- == Standard mutator function for the named property.                      ==
-- ============================================================================

function HTConfig:SetIsEnabledBuffMonitorCataPoisons(info, newValue)
    self.db.profile.isEnabledBuffMonitorCataPoisons = newValue
end

-- ============================================================================
-- == ToggleIsEnabledBuffMonitorCataPoisons()                                ==
-- ==                                                                        ==
-- == Toggles the value of the named property.                               ==
-- ============================================================================

function HTConfig:ToggleIsEnabledBuffMonitorCataPoisons()
    self.db.profile.isEnabledBuffMonitorCataPoisons = HTConfig:ToggleValue(HTConfig:GetIsEnabledBuffMonitorCataPoisons(nil))
end

-- ============================================================================
-- == GetIsEnabledBuffMonitorWrathFlasks(info)                               ==
-- ==                                                                        ==
-- == Standard accessor function for the named property.                     ==
-- ============================================================================

function HTConfig:GetIsEnabledBuffMonitorWrathFlasks(info)
    return self.db.profile.isEnabledBuffMonitorWrathFlasks
end

-- ============================================================================
-- == BuffMonitorWrathFlasks(info, newValue)                                 ==
-- ==                                                                        ==
-- == Standard mutator function for the named property.                      ==
-- ============================================================================

function HTConfig:SetIsEnabledBuffMonitorWrathFlasks(info, newValue)
    self.db.profile.isEnabledBuffMonitorWrathFlasks = newValue
end

-- ============================================================================
-- == ToggleIsEnabledBuffMonitorWrathFlasks()                                ==
-- ==                                                                        ==
-- == Toggles the value of the named property.                               ==
-- ============================================================================

function HTConfig:ToggleIsEnabledBuffMonitorWrathFlasks()
    self.db.profile.isEnabledBuffMonitorWrathFlasks = HTConfig:ToggleValue(HTConfig:GetIsEnabledBuffMonitorWrathFlasks(nil))
end

-- ============================================================================
-- == GetIsEnabledBuffMonitorWrathBattleElixirs(info)                        ==
-- ==                                                                        ==
-- == Standard accessor function for the named property.                     ==
-- ============================================================================

function HTConfig:GetIsEnabledBuffMonitorWrathBattleElixirs(info)
    return self.db.profile.isEnabledBuffMonitorWrathBattleElixirs
end

-- ============================================================================
-- == BuffMonitorWrathBattleElixirs(info, newValue)                          ==
-- ==                                                                        ==
-- == Standard mutator function for the named property.                      ==
-- ============================================================================

function HTConfig:SetIsEnabledBuffMonitorWrathBattleElixirs(info, newValue)
    self.db.profile.isEnabledBuffMonitorWrathBattleElixirs = newValue
end

-- ============================================================================
-- == ToggleIsEnabledBuffMonitorWrathBattleElixirs()                         ==
-- ==                                                                        ==
-- == Toggles the value of the named property.                               ==
-- ============================================================================

function HTConfig:ToggleIsEnabledBuffMonitorWrathBattleElixirs()
    self.db.profile.isEnabledBuffMonitorWrathBattleElixirs = HTConfig:ToggleValue(HTConfig:GetIsEnabledBuffMonitorWrathBattleElixirs(nil))
end

-- ============================================================================
-- == GetIsEnabledBuffMonitorWrathGuardianElixirs(info)                      ==
-- ==                                                                        ==
-- == Standard accessor function for the named property.                     ==
-- ============================================================================

function HTConfig:GetIsEnabledBuffMonitorWrathGuardianElixirs(info)
    return self.db.profile.isEnabledBuffMonitorWrathGuardianElixirs
end

-- ============================================================================
-- == BuffMonitorWrathGuardianElixirs(info, newValue)                        ==
-- ==                                                                        ==
-- == Standard mutator function for the named property.                      ==
-- ============================================================================

function HTConfig:SetIsEnabledBuffMonitorWrathGuardianElixirs(info, newValue)
    self.db.profile.isEnabledBuffMonitorWrathGuardianElixirs = newValue
end

-- ============================================================================
-- == ToggleIsEnabledBuffMonitorWrathGuardianElixirs()                       ==
-- ==                                                                        ==
-- == Toggles the value of the named property.                               ==
-- ============================================================================

function HTConfig:ToggleIsEnabledBuffMonitorWrathGuardianElixirs()
    self.db.profile.isEnabledBuffMonitorWrathGuardianElixirs = HTConfig:ToggleValue(HTConfig:GetIsEnabledBuffMonitorWrathGuardianElixirs(nil))
end

-- ============================================================================
-- == GetIsEnabledBuffMonitorWrathFood(info)                                 ==
-- ==                                                                        ==
-- == Standard accessor function for the named property.                     ==
-- ============================================================================

function HTConfig:GetIsEnabledBuffMonitorWrathFood(info)
    return self.db.profile.isEnabledBuffMonitorWrathFood
end

-- ============================================================================
-- == BuffMonitorWrathFood(info, newValue)                                   ==
-- ==                                                                        ==
-- == Standard mutator function for the named property.                      ==
-- ============================================================================

function HTConfig:SetIsEnabledBuffMonitorWrathFood(info, newValue)
    self.db.profile.isEnabledBuffMonitorWrathFood = newValue
end

-- ============================================================================
-- == ToggleIsEnabledBuffMonitorWrathFood()                                  ==
-- ==                                                                        ==
-- == Toggles the value of the named property.                               ==
-- ============================================================================

function HTConfig:ToggleIsEnabledBuffMonitorWrathFood()
    self.db.profile.isEnabledBuffMonitorWrathFood = HTConfig:ToggleValue(HTConfig:GetIsEnabledBuffMonitorWrathFood(nil))
end

-- ============================================================================
-- == GetIsEnabledBuffMonitorWrathPoisons(info)                              ==
-- ==                                                                        ==
-- == Standard accessor function for the named property.                     ==
-- ============================================================================

function HTConfig:GetIsEnabledBuffMonitorWrathPoisons(info)
    return self.db.profile.isEnabledBuffMonitorWrathPoisons
end

-- ============================================================================
-- == BuffMonitorWrathPoisons(info, newValue)                                ==
-- ==                                                                        ==
-- == Standard mutator function for the named property.                      ==
-- ============================================================================

function HTConfig:SetIsEnabledBuffMonitorWrathPoisons(info, newValue)
    self.db.profile.isEnabledBuffMonitorWrathPoisons = newValue
end

-- ============================================================================
-- == ToggleIsEnabledBuffMonitorWrathPoisons()                               ==
-- ==                                                                        ==
-- == Toggles the value of the named property.                               ==
-- ============================================================================

function HTConfig:ToggleIsEnabledBuffMonitorWrathPoisons()
    self.db.profile.isEnabledBuffMonitorWrathPoisons = HTConfig:ToggleValue(HTConfig:GetIsEnabledBuffMonitorWrathPoisons(nil))
end

-- ============================================================================
-- == GetIsEnabledBuffMonitorExpiryTimeCheck(info)                           ==
-- ==                                                                        ==
-- == Standard accessor function for the named property.                     ==
-- ============================================================================

function HTConfig:GetIsEnabledBuffMonitorExpiryTimeCheck(info)
    return self.db.profile.isEnabledBuffMonitorExpiryTimeCheck
end

-- ============================================================================
-- == BuffMonitorExpiryTimeCheck(info, newValue)                             ==
-- ==                                                                        ==
-- == Standard mutator function for the named property.                      ==
-- ============================================================================

function HTConfig:SetIsEnabledBuffMonitorExpiryTimeCheck(info, newValue)
    self.db.profile.isEnabledBuffMonitorExpiryTimeCheck = newValue
end

-- ============================================================================
-- == ToggleIsEnabledBuffMonitorExpiryTimeCheck()                            ==
-- ==                                                                        ==
-- == Toggles the value of the named property.                               ==
-- ============================================================================

function HTConfig:ToggleIsEnabledBuffMonitorExpiryTimeCheck()
    self.db.profile.isEnabledBuffMonitorExpiryTimeCheck = HTConfig:ToggleValue(HTConfig:GetIsEnabledBuffMonitorExpiryTimeCheck(nil))
end

-- ============================================================================
-- == GetBuffMonitorExpiryTimeLimit(info)                                    ==
-- ==                                                                        ==
-- == Standard accessor function for the named property.                     ==
-- ============================================================================

function HTConfig:GetBuffMonitorExpiryTimeLimit(info)
    return self.db.profile.buffMonitorExpiryTimeLimit
end

-- ============================================================================
-- == SetBuffMonitorExpiryTimeLimit(info, newValue)                          ==
-- ==                                                                        ==
-- == Standard mutator function for the named property.                      ==
-- ============================================================================

function HTConfig:SetBuffMonitorExpiryTimeLimit(info, newValue)
    self.db.profile.buffMonitorExpiryTimeLimit = newValue
end

-- ============================================================================
-- == GetIsEnabledBuffMonitorReportDead(info)                                ==
-- ==                                                                        ==
-- == Standard accessor function for the named property.                     ==
-- ============================================================================

function HTConfig:GetIsEnabledBuffMonitorReportDead(info)
    return self.db.profile.isEnabledBuffMonitorReportDead
end

-- ============================================================================
-- == BuffMonitorReportDead(info, newValue)                                  ==
-- ==                                                                        ==
-- == Standard mutator function for the named property.                      ==
-- ============================================================================

function HTConfig:SetIsEnabledBuffMonitorReportDead(info, newValue)
    self.db.profile.isEnabledBuffMonitorReportDead = newValue
end

-- ============================================================================
-- == ToggleIsEnabledBuffMonitorReportDead()                                 ==
-- ==                                                                        ==
-- == Toggles the value of the named property.                               ==
-- ============================================================================

function HTConfig:ToggleIsEnabledBuffMonitorReportDead()
    self.db.profile.isEnabledBuffMonitorReportDead = HTConfig:ToggleValue(HTConfig:GetIsEnabledBuffMonitorReportDead(nil))
end

-- ============================================================================
-- == GetIsEnabledBuffMonitorReportOffline(info)                             ==
-- ==                                                                        ==
-- == Standard accessor function for the named property.                     ==
-- ============================================================================

function HTConfig:GetIsEnabledBuffMonitorReportOffline(info)
    return self.db.profile.isEnabledBuffMonitorReportOffline
end

-- ============================================================================
-- == BuffMonitorReportOffline(info, newValue)                               ==
-- ==                                                                        ==
-- == Standard mutator function for the named property.                      ==
-- ============================================================================

function HTConfig:SetIsEnabledBuffMonitorReportOffline(info, newValue)
    self.db.profile.isEnabledBuffMonitorReportOffline = newValue
end

-- ============================================================================
-- == ToggleIsEnabledBuffMonitorReportOffline()                              ==
-- ==                                                                        ==
-- == Toggles the value of the named property.                               ==
-- ============================================================================

function HTConfig:ToggleIsEnabledBuffMonitorReportOffline()
    self.db.profile.isEnabledBuffMonitorReportOffline = HTConfig:ToggleValue(HTConfig:GetIsEnabledBuffMonitorReportOffline(nil))
end

-- ============================================================================
-- == GetIsEnabledBuffMonitorCheckFlasks(info)                               ==
-- ==                                                                        ==
-- == Standard accessor function for the named property.                     ==
-- ============================================================================

function HTConfig:GetIsEnabledBuffMonitorCheckFlasks(info)
    return self.db.profile.isEnabledBuffMonitorCheckFlasks
end

-- ============================================================================
-- == BuffMonitorCheckFlasks(info, newValue)                                 ==
-- ==                                                                        ==
-- == Standard mutator function for the named property.                      ==
-- ============================================================================

function HTConfig:SetIsEnabledBuffMonitorCheckFlasks(info, newValue)
    self.db.profile.isEnabledBuffMonitorCheckFlasks = newValue
end

-- ============================================================================
-- == ToggleIsEnabledBuffMonitorCheckFlasks()                                ==
-- ==                                                                        ==
-- == Toggles the value of the named property.                               ==
-- ============================================================================

function HTConfig:ToggleIsEnabledBuffMonitorCheckFlasks()
    self.db.profile.isEnabledBuffMonitorCheckFlasks = HTConfig:ToggleValue(HTConfig:GetIsEnabledBuffMonitorCheckFlasks(nil))
end

-- ============================================================================
-- == GetIsEnabledBuffMonitorCheckBattleElixirs(info)                        ==
-- ==                                                                        ==
-- == Standard accessor function for the named property.                     ==
-- ============================================================================

function HTConfig:GetIsEnabledBuffMonitorCheckBattleElixirs(info)
    return self.db.profile.isEnabledBuffMonitorCheckBattleElixirs
end

-- ============================================================================
-- == BuffMonitorCheckBattleElixirs(info, newValue)                          ==
-- ==                                                                        ==
-- == Standard mutator function for the named property.                      ==
-- ============================================================================

function HTConfig:SetIsEnabledBuffMonitorCheckBattleElixirs(info, newValue)
    self.db.profile.isEnabledBuffMonitorCheckBattleElixirs = newValue
end

-- ============================================================================
-- == ToggleIsEnabledBuffMonitorCheckBattleElixirs()                         ==
-- ==                                                                        ==
-- == Toggles the value of the named property.                               ==
-- ============================================================================

function HTConfig:ToggleIsEnabledBuffMonitorCheckBattleElixirs()
    self.db.profile.isEnabledBuffMonitorCheckBattleElixirs = HTConfig:ToggleValue(HTConfig:GetIsEnabledBuffMonitorCheckBattleElixirs(nil))
end

-- ============================================================================
-- == GetIsEnabledBuffMonitorCheckGuardianElixirs(info)                      ==
-- ==                                                                        ==
-- == Standard accessor function for the named property.                     ==
-- ============================================================================

function HTConfig:GetIsEnabledBuffMonitorCheckGuardianElixirs(info)
    return self.db.profile.isEnabledBuffMonitorCheckGuardianElixirs
end

-- ============================================================================
-- == BuffMonitorCheckGuardianElixirs(info, newValue)                        ==
-- ==                                                                        ==
-- == Standard mutator function for the named property.                      ==
-- ============================================================================

function HTConfig:SetIsEnabledBuffMonitorCheckGuardianElixirs(info, newValue)
    self.db.profile.isEnabledBuffMonitorCheckGuardianElixirs = newValue
end

-- ============================================================================
-- == ToggleIsEnabledBuffMonitorCheckGuardianElixirs()                       ==
-- ==                                                                        ==
-- == Toggles the value of the named property.                               ==
-- ============================================================================

function HTConfig:ToggleIsEnabledBuffMonitorCheckGuardianElixirs()
    self.db.profile.isEnabledBuffMonitorCheckGuardianElixirs = HTConfig:ToggleValue(HTConfig:GetIsEnabledBuffMonitorCheckGuardianElixirs(nil))
end

-- ============================================================================
-- == GetIsEnabledBuffMonitorCheckFood(info)                                 ==
-- ==                                                                        ==
-- == Standard accessor function for the named property.                     ==
-- ============================================================================

function HTConfig:GetIsEnabledBuffMonitorCheckFood(info)
    return self.db.profile.isEnabledBuffMonitorCheckFood
end

-- ============================================================================
-- == BuffMonitorCheckFood(info, newValue)                                   ==
-- ==                                                                        ==
-- == Standard mutator function for the named property.                      ==
-- ============================================================================

function HTConfig:SetIsEnabledBuffMonitorCheckFood(info, newValue)
    self.db.profile.isEnabledBuffMonitorCheckFood = newValue
end

-- ============================================================================
-- == ToggleIsEnabledBuffMonitorCheckFood()                                  ==
-- ==                                                                        ==
-- == Toggles the value of the named property.                               ==
-- ============================================================================

function HTConfig:ToggleIsEnabledBuffMonitorCheckFood()
    self.db.profile.isEnabledBuffMonitorCheckFood = HTConfig:ToggleValue(HTConfig:GetIsEnabledBuffMonitorCheckFood(nil))
end

-- ============================================================================
-- == GetIsEnabledBuffMonitorCheckPoisons(info)                              ==
-- ==                                                                        ==
-- == Standard accessor function for the named property.                     ==
-- ============================================================================

function HTConfig:GetIsEnabledBuffMonitorCheckPoisons(info)
    return self.db.profile.isEnabledBuffMonitorCheckPoisons
end

-- ============================================================================
-- == BuffMonitorCheckPoisons(info, newValue)                                ==
-- ==                                                                        ==
-- == Standard mutator function for the named property.                      ==
-- ============================================================================

function HTConfig:SetIsEnabledBuffMonitorCheckPoisons(info, newValue)
    self.db.profile.isEnabledBuffMonitorCheckPoisons = newValue
end

-- ============================================================================
-- == ToggleIsEnabledBuffMonitorCheckPoisons()                               ==
-- ==                                                                        ==
-- == Toggles the value of the named property.                               ==
-- ============================================================================

function HTConfig:ToggleIsEnabledBuffMonitorCheckPoisons()
    self.db.profile.isEnabledBuffMonitorCheckPoisons = HTConfig:ToggleValue(HTConfig:GetIsEnabledBuffMonitorCheckPoisons(nil))
end

-- ============================================================================
-- == GetIsPlayerInCombat(info)                                              ==
-- ==                                                                        ==
-- == Standard accessor function for the named property.                     ==
-- ============================================================================

function HTConfig:GetIsPlayerInCombat(info)
    return self.db.profile.isPlayerInCombat
end

-- ============================================================================
-- == SetIsPlayerInCombat(info, newValue)                                    ==
-- ==                                                                        ==
-- == Standard mutator function for the named property.                      ==
-- ============================================================================

function HTConfig:SetIsPlayerInCombat(info, newValue)
    self.db.profile.isPlayerInCombat = newValue
end

-- ============================================================================
-- == ToggleIsPlayerInCombat()                                               ==
-- ==                                                                        ==
-- == Toggles the value of the named property.                               ==
-- ============================================================================

function HTConfig:ToggleIsPlayerInCombat()
    self.db.profile.isPlayerInCombat = HTConfig:ToggleValue(HTConfig:GetIsPlayerInCombat(nil))
end

-- ============================================================================
-- == GetDefaultOfftimeGMOTD(info)                                           ==
-- ==                                                                        ==
-- == Standard accessor function for the named property.                     ==
-- ============================================================================

function HTConfig:GetDefaultOfftimeGMOTD(info)
    return self.db.profile.defaultOfftimeGMOTD
end

-- ============================================================================
-- == SetDefaultOfftimeGMOTD(info, newValue)                                 ==
-- ==                                                                        ==
-- == Standard mutator function for the named property.                      ==
-- ============================================================================

function HTConfig:SetDefaultOfftimeGMOTD(info, newValue)
    self.db.profile.defaultOfftimeGMOTD = newValue
end

-- ============================================================================
-- == GetIsEnabledRecruitmentMessageSender(info)                             ==
-- ==                                                                        ==
-- == Standard accessor function for the named property.                     ==
-- ============================================================================

function HTConfig:GetIsEnabledRecruitmentMessageSender(info)
    return self.db.profile.isEnabledRecruitmentMessageSender
end

-- ============================================================================
-- == SetIsEnabledRecruitmentMessageSender(info, newValue)                   ==
-- ==                                                                        ==
-- == Standard mutator function for the named property.                      ==
-- ============================================================================

function HTConfig:SetIsEnabledRecruitmentMessageSender(info, newValue)
    self.db.profile.isEnabledRecruitmentMessageSender = newValue
end

-- ============================================================================
-- == ToggleIsEnabledRecruitmentMessageSender()                              ==
-- ==                                                                        ==
-- == Toggles the value of the named property.                               ==
-- ============================================================================

function HTConfig:ToggleIsEnabledRecruitmentMessageSender()
    self.db.profile.isEnabledRecruitmentMessageSender = HTConfig:ToggleValue(HTConfig:GetIsEnabledRecruitmentMessageSender(nil))
end

-- ============================================================================
-- == GetIsEnabledRMSBroadcastOnZoneChanged(info)                            ==
-- ==                                                                        ==
-- == Standard accessor function for the named property.                     ==
-- ============================================================================

function HTConfig:GetIsEnabledRMSBroadcastOnZoneChanged(info)
    return self.db.profile.isEnabledRMSBroadcastOnZoneChanged
end

-- ============================================================================
-- == SetIsEnabledRMSBroadcastOnZoneChanged(info, newValue)                  ==
-- ==                                                                        ==
-- == Standard mutator function for the named property.                      ==
-- ============================================================================

function HTConfig:SetIsEnabledRMSBroadcastOnZoneChanged(info, newValue)
    self.db.profile.isEnabledRMSBroadcastOnZoneChanged = newValue
end

-- ============================================================================
-- == ToggleIsEnabledRMSBroadcastOnZoneChanged()                             ==
-- ==                                                                        ==
-- == Toggles the value of the named property.                               ==
-- ============================================================================

function HTConfig:ToggleIsEnabledRMSBroadcastOnZoneChanged()
    self.db.profile.isEnabledRMSBroadcastOnZoneChanged = HTConfig:ToggleValue(HTConfig:GetIsEnabledRMSBroadcastOnZoneChanged(nil))
end

-- ============================================================================
-- == GetIsEnabledRMSGroupLock(info)                                         ==
-- ==                                                                        ==
-- == Standard accessor function for the named property.                     ==
-- ============================================================================

function HTConfig:GetIsEnabledRMSGroupLock(info)
    return self.db.profile.isEnabledRMSGroupLock
end

-- ============================================================================
-- == SetIsEnabledRMSGroupLock(info, newValue)                               ==
-- ==                                                                        ==
-- == Standard mutator function for the named property.                      ==
-- ============================================================================

function HTConfig:SetIsEnabledRMSGroupLock(info, newValue)
    self.db.profile.isEnabledRMSGroupLock = newValue
end

-- ============================================================================
-- == ToggleIsEnabledRMSGroupLock()                                          ==
-- ==                                                                        ==
-- == Toggles the value of the named property.                               ==
-- ============================================================================

function HTConfig:ToggleIsEnabledRMSGroupLock()
    self.db.profile.isEnabledRMSGroupLock = HTConfig:ToggleValue(HTConfig:GetIsEnabledRMSGroupLock(nil))
end

-- ============================================================================
-- == GetIsEnabledRMSGuildLocked(info)                                       ==
-- ==                                                                        ==
-- == Standard accessor function for the named property.                     ==
-- ============================================================================

function HTConfig:GetIsEnabledRMSGuildLocked(info)
    return self.db.profile.isEnabledRMSGuildLocked
end

-- ============================================================================
-- == SetIsEnabledRMSGuildLocked(info, newValue)                             ==
-- ==                                                                        ==
-- == Standard mutator function for the named property.                      ==
-- ============================================================================

function HTConfig:SetIsEnabledRMSGuildLocked(info, newValue)
    self.db.profile.isEnabledRMSGuildLocked = newValue
end

-- ============================================================================
-- == ToggleIsEnabledRMSGuildLocked()                                        ==
-- ==                                                                        ==
-- == Toggles the value of the named property.                               ==
-- ============================================================================

function HTConfig:ToggleIsEnabledRMSGuildLocked()
    self.db.profile.isEnabledRMSGuildLocked = HTConfig:ToggleValue(HTConfig:GetIsEnabledRMSGuildLocked(nil))
end

-- ============================================================================
-- == GetPreferredRMSGuild(info)                                             ==
-- ==                                                                        ==
-- == Standard accessor function for the named property.                     ==
-- ============================================================================

function HTConfig:GetPreferredRMSGuild(info)
    return self.db.profile.preferredRMSGuild
end

-- ============================================================================
-- == SetPreferredRMSGuild(info, newValue)                                   ==
-- ==                                                                        ==
-- == Standard mutator function for the named property.                      ==
-- ============================================================================

function HTConfig:SetPreferredRMSGuild(info, newValue)
    self.db.profile.preferredRMSGuild = newValue
end

-- ============================================================================
-- == GetRecruitmentMessage(info)                                            ==
-- ==                                                                        ==
-- == Standard accessor function for the named property.                     ==
-- ============================================================================

function HTConfig:GetRecruitmentMessage(info)
    return self.db.profile.recruitmentMessage
end

-- ============================================================================
-- == SetRecruitmentMessage(info, newValue)                                  ==
-- ==                                                                        ==
-- == Standard mutator function for the named property.                      ==
-- ============================================================================

function HTConfig:SetRecruitmentMessage(info, newValue)
    self.db.profile.recruitmentMessage = newValue
end

-- ============================================================================
-- == GetRecruitmentInterval(info)                                           ==
-- ==                                                                        ==
-- == Standard accessor function for the named property.                     ==
-- ============================================================================

function HTConfig:GetRecruitmentInterval(info)
    return self.db.profile.recruitmentInterval
end

-- ============================================================================
-- == SetRecruitmentInterval(info, newValue)                                 ==
-- ==                                                                        ==
-- == Standard mutator function for the named property.                      ==
-- ============================================================================

function HTConfig:SetRecruitmentInterval(info, newValue)
    self.db.profile.recruitmentInterval = newValue
end

-- ============================================================================
-- == GetRecruitmentZoneName(info)                                           ==
-- ==                                                                        ==
-- == Standard accessor function for the named property.                     ==
-- ============================================================================

function HTConfig:GetRecruitmentZoneName(info)
    return self.db.profile.recruitmentZoneName
end

-- ============================================================================
-- == SetRecruitmentZoneName(info, newValue)                                 ==
-- ==                                                                        ==
-- == Standard mutator function for the named property.                      ==
-- ============================================================================

function HTConfig:SetRecruitmentZoneName(info, newValue)
    self.db.profile.recruitmentZoneName = newValue
end

-- ============================================================================
-- == GetIsEnabledBusyResponder(info)                                        ==
-- ==                                                                        ==
-- == Standard accessor function for the named property.                     ==
-- ============================================================================

function HTConfig:GetIsEnabledBusyResponder(info)
    return self.db.profile.isEnabledBusyResponder
end

-- ============================================================================
-- == SetIsEnabledBusyResponder(info, newValue)                              ==
-- ==                                                                        ==
-- == Standard mutator function for the named property.                      ==
-- ============================================================================

function HTConfig:SetIsEnabledBusyResponder(info, newValue)
    self.db.profile.isEnabledBusyResponder = newValue
end

-- ============================================================================
-- == ToggleIsEnabledBusyResponder()                                         ==
-- ==                                                                        ==
-- == Toggles the value of the named property.                               ==
-- ============================================================================

function HTConfig:ToggleIsEnabledBusyResponder()
    self.db.profile.isEnabledBusyResponder = HTConfig:ToggleValue(HTConfig:GetIsEnabledBusyResponder(nil))
end

-- ============================================================================
-- == GetIsGuildMemberAllowed(info)                                          ==
-- ==                                                                        ==
-- == Standard accessor function for the named property.                     ==
-- ============================================================================

function HTConfig:GetIsGuildMemberAllowed(info)
    return self.db.profile.isGuildMemberAllowed
end

-- ============================================================================
-- == SetIsGuildMemberAllowed(info, newValue)                                ==
-- ==                                                                        ==
-- == Standard mutator function for the named property.                      ==
-- ============================================================================

function HTConfig:SetIsGuildMemberAllowed(info, newValue)
    self.db.profile.isGuildMemberAllowed = newValue
end

-- ============================================================================
-- == ToggleIsGuildMemberAllowed()                                           ==
-- ==                                                                        ==
-- == Toggles the value of the named property.                               ==
-- ============================================================================

function HTConfig:ToggleIsGuildMemberAllowed()
    self.db.profile.isGuildMemberAllowed = HTConfig:ToggleValue(HTConfig:GetIsGuildMemberAllowed(nil))
end

-- ============================================================================
-- == GetIsGuildOfficerAllowed(info)                                         ==
-- ==                                                                        ==
-- == Standard accessor function for the named property.                     ==
-- ============================================================================

function HTConfig:GetIsGuildOfficerAllowed(info)
    return self.db.profile.isGuildOfficerAllowed
end

-- ============================================================================
-- == SetIsGuildOfficerAllowed(info, newValue)                               ==
-- ==                                                                        ==
-- == Standard mutator function for the named property.                      ==
-- ============================================================================

function HTConfig:SetIsGuildOfficerAllowed(info, newValue)
    self.db.profile.isGuildOfficerAllowed = newValue
end

-- ============================================================================
-- == ToggleIsGuildOfficerAllowed()                                          ==
-- ==                                                                        ==
-- == Toggles the value of the named property.                               ==
-- ============================================================================

function HTConfig:ToggleIsGuildOfficerAllowed()
    self.db.profile.isGuildOfficerAllowed = HTConfig:ToggleValue(HTConfig:GetIsGuildOfficerAllowed(nil))
end

-- ============================================================================
-- == GetIsRaidMemberAllowed(info)                                           ==
-- ==                                                                        ==
-- == Standard accessor function for the named property.                     ==
-- ============================================================================

function HTConfig:GetIsRaidMemberAllowed(info)
    return self.db.profile.isRaidMemberAllowed
end

-- ============================================================================
-- == SetIsRaidMemberAllowed(info, newValue)                                 ==
-- ==                                                                        ==
-- == Standard mutator function for the named property.                      ==
-- ============================================================================

function HTConfig:SetIsRaidMemberAllowed(info, newValue)
    self.db.profile.isRaidMemberAllowed = newValue
end

-- ============================================================================
-- == ToggleIsRaidMemberAllowed()                                            ==
-- ==                                                                        ==
-- == Toggles the value of the named property.                               ==
-- ============================================================================

function HTConfig:ToggleIsRaidMemberAllowed()
    self.db.profile.isRaidMemberAllowed = HTConfig:ToggleValue(HTConfig:GetIsRaidMemberAllowed(nil))
end

-- ============================================================================
-- == GetIsPartyMemberAllowed(info)                                          ==
-- ==                                                                        ==
-- == Standard accessor function for the named property.                     ==
-- ============================================================================

function HTConfig:GetIsPartyMemberAllowed(info)
    return self.db.profile.isPartyMemberAllowed
end

-- ============================================================================
-- == SetIsPartyMemberAllowed(info, newValue)                                ==
-- ==                                                                        ==
-- == Standard mutator function for the named property.                      ==
-- ============================================================================

function HTConfig:SetIsPartyMemberAllowed(info, newValue)
    self.db.profile.isPartyMemberAllowed = newValue
end

-- ============================================================================
-- == ToggleIsPartyMemberAllowed()                                           ==
-- ==                                                                        ==
-- == Toggles the value of the named property.                               ==
-- ============================================================================

function HTConfig:ToggleIsPartyMemberAllowed()
    self.db.profile.isPartyMemberAllowed = HTConfig:ToggleValue(HTConfig:GetIsPartyMemberAllowed(nil))
end

-- ============================================================================
-- == GetIsFriendAllowed(info)                                               ==
-- ==                                                                        ==
-- == Standard accessor function for the named property.                     ==
-- ============================================================================

function HTConfig:GetIsFriendAllowed(info)
    return self.db.profile.isFriendAllowed
end

-- ============================================================================
-- == SetIsFriendAllowed(info, newValue)                                     ==
-- ==                                                                        ==
-- == Standard mutator function for the named property.                      ==
-- ============================================================================

function HTConfig:SetIsFriendAllowed(info, newValue)
    self.db.profile.isFriendAllowed = newValue
end

-- ============================================================================
-- == ToggleIsFriendAllowed()                                                ==
-- ==                                                                        ==
-- == Toggles the value of the named property.                               ==
-- ============================================================================

function HTConfig:ToggleIsFriendAllowed()
    self.db.profile.isFriendAllowed = HTConfig:ToggleValue(HTConfig:GetIsFriendAllowed(nil))
end

-- ============================================================================
-- == GetIsRealIDFriendAllowed(info)                                         ==
-- ==                                                                        ==
-- == Standard accessor function for the named property.                     ==
-- ============================================================================

function HTConfig:GetIsRealIDFriendAllowed(info)
    return self.db.profile.isRealIDFriendAllowed
end

-- ============================================================================
-- == SetIsRealIDFriendAllowed(info, newValue)                               ==
-- ==                                                                        ==
-- == Standard mutator function for the named property.                      ==
-- ============================================================================

function HTConfig:SetIsRealIDFriendAllowed(info, newValue)
    self.db.profile.isRealIDFriendAllowed = newValue
end

-- ============================================================================
-- == ToggleIsRealIDFriendAllowed()                                          ==
-- ==                                                                        ==
-- == Toggles the value of the named property.                               ==
-- ============================================================================

function HTConfig:ToggleIsRealIDFriendAllowed()
    self.db.profile.isRealIDFriendAllowed = HTConfig:ToggleValue(HTConfig:GetIsRealIDFriendAllowed(nil))
end

-- ============================================================================
-- == GetBRMessageOutgoing(info)                                             ==
-- ==                                                                        ==
-- == Standard accessor function for the named property.                     ==
-- ============================================================================

function HTConfig:GetBRMessageOutgoing(info)
    return self.db.profile.brMessageOutgoing
end

-- ============================================================================
-- == SetBRMessageOutgoing(info, newValue)                                   ==
-- ==                                                                        ==
-- == Standard mutator function for the named property.                      ==
-- ============================================================================

function HTConfig:SetBRMessageOutgoing(info, newValue)
    self.db.profile.brMessageOutgoing = newValue
end

-- ============================================================================
-- == GetBRMessageCustom(info)                                               ==
-- ==                                                                        ==
-- == Standard accessor function for the named property.                     ==
-- ============================================================================

function HTConfig:GetBRMessageCustom(info)
    return self.db.profile.brMessageCustom
end

-- ============================================================================
-- == SetBRMessageCustom(info, newValue)                                     ==
-- ==                                                                        ==
-- == Standard mutator function for the named property.                      ==
-- ============================================================================

function HTConfig:SetBRMessageCustom(info, newValue)
    self.db.profile.brMessageCustom = newValue
end

-- ============================================================================
-- == GetIsEnabledBRAutoProfileSelect(info)                                  ==
-- ==                                                                        ==
-- == Standard accessor function for the named property.                     ==
-- ============================================================================

function HTConfig:GetIsEnabledBRAutoProfileSelect(info)
    return self.db.profile.isEnabledBRAutoProfileSelect
end

-- ============================================================================
-- == SetIsEnabledBRAutoProfileSelect(info, newValue)                        ==
-- ==                                                                        ==
-- == Standard mutator function for the named property.                      ==
-- ============================================================================

function HTConfig:SetIsEnabledBRAutoProfileSelect(info, newValue)
    self.db.profile.isEnabledBRAutoProfileSelect = newValue
end

-- ============================================================================
-- == ToggleIsEnabledBRAutoProfileSelect()                                   ==
-- ==                                                                        ==
-- == Toggles the value of the named property.                               ==
-- ============================================================================

function HTConfig:ToggleIsEnabledBRAutoProfileSelect()
    self.db.profile.isEnabledBRAutoProfileSelect = HTConfig:ToggleValue(HTConfig:GetIsEnabledBRAutoProfileSelect(nil))
end

-- ============================================================================
-- == GetBRProfileName(info)                                                 ==
-- ==                                                                        ==
-- == Standard accessor function for the named property.                     ==
-- ============================================================================

function HTConfig:GetBRProfileName(info)
    return self.db.profile.brProfileName
end

-- ============================================================================
-- == SetBRProfileName(info, newValue)                                       ==
-- ==                                                                        ==
-- == Standard mutator function for the named property.                      ==
-- ============================================================================

function HTConfig:SetBRProfileName(info, newValue)
    self.db.profile.brProfileName = newValue
end

-- ============================================================================
-- == GetBRProfileBusy(info)                                                 ==
-- ==                                                                        ==
-- == Standard accessor function for the named property.                     ==
-- ============================================================================

function HTConfig:GetBRProfileBusy(info)
    return self.db.profile.brProfileBusy
end

-- ============================================================================
-- == SetBRProfileBusy(info, newValue)                                       ==
-- ==                                                                        ==
-- == Standard mutator function for the named property.                      ==
-- ============================================================================

function HTConfig:SetBRProfileBusy(info, newValue)
    self.db.profile.brProfileBusy = newValue
end

-- ============================================================================
-- == GetBRProfileRaiding(info)                                              ==
-- ==                                                                        ==
-- == Standard accessor function for the named property.                     ==
-- ============================================================================

function HTConfig:GetBRProfileRaiding(info)
    return self.db.profile.brProfileRaiding
end

-- ============================================================================
-- == SetBRProfileRaiding(info, newValue)                                    ==
-- ==                                                                        ==
-- == Standard mutator function for the named property.                      ==
-- ============================================================================

function HTConfig:SetBRProfileRaiding(info, newValue)
    self.db.profile.brProfileRaiding = newValue
end

-- ============================================================================
-- == GetBRProfileAway(info)                                                 ==
-- ==                                                                        ==
-- == Standard accessor function for the named property.                     ==
-- ============================================================================

function HTConfig:GetBRProfileAway(info)
    return self.db.profile.brProfileAway
end

-- ============================================================================
-- == SetBRProfileAway(info, newValue)                                       ==
-- ==                                                                        ==
-- == Standard mutator function for the named property.                      ==
-- ============================================================================

function HTConfig:SetBRProfileAway(info, newValue)
    self.db.profile.brProfileAway = newValue
end

-- ============================================================================
-- == GetBRProfileRecruiting(info)                                           ==
-- ==                                                                        ==
-- == Standard accessor function for the named property.                     ==
-- ============================================================================

function HTConfig:GetBRProfileRecruiting(info)
    return self.db.profile.brProfileRecruiting
end

-- ============================================================================
-- == SetBRProfileRecruiting(info, newValue)                                 ==
-- ==                                                                        ==
-- == Standard mutator function for the named property.                      ==
-- ============================================================================

function HTConfig:SetBRProfileRecruiting(info, newValue)
    self.db.profile.brProfileRecruiting = newValue
end

-- ============================================================================
-- == GetBRProfileCustom(info)                                               ==
-- ==                                                                        ==
-- == Standard accessor function for the named property.                     ==
-- ============================================================================

function HTConfig:GetBRProfileCustom(info)
    return self.db.profile.brProfileCustom
end

-- ============================================================================
-- == SetBRProfileCustom(info, newValue)                                     ==
-- ==                                                                        ==
-- == Standard mutator function for the named property.                      ==
-- ============================================================================

function HTConfig:SetBRProfileCustom(info, newValue)
    self.db.profile.brProfileCustom = newValue
end


-- ============================================================================
-- == GetIsEnabledBuffAnnouncer(info)                                        ==
-- ==                                                                        ==
-- == Standard accessor function for the named property.                     ==
-- ============================================================================

function HTConfig:GetIsEnabledBuffAnnouncer(info)
    return self.db.profile.isEnabledBuffAnnouncer
end

-- ============================================================================
-- == SetIsEnabledBuffAnnouncer(info, newValue)                              ==
-- ==                                                                        ==
-- == Standard mutator function for the named property.                      ==
-- ============================================================================

function HTConfig:SetIsEnabledBuffAnnouncer(info, newValue)
    self.db.profile.isEnabledBuffAnnouncer = newValue
end

-- ============================================================================
-- == ToggleIsEnabledBuffAnnouncer()                                         ==
-- ==                                                                        ==
-- == Toggles the value of the named property.                               ==
-- ============================================================================

function HTConfig:ToggleIsEnabledBuffAnnouncer()
    self.db.profile.isEnabledBuffAnnouncer = HTConfig:ToggleValue(HTConfig:GetIsEnabledBuffAnnouncer(nil))
end

-- ============================================================================
-- == GetIsEnabledBuffAnnouncerFood(info)                                    ==
-- ==                                                                        ==
-- == Standard accessor function for the named property.                     ==
-- ============================================================================

function HTConfig:GetIsEnabledBuffAnnouncerFood(info)
    return self.db.profile.isEnabledBuffAnnouncerFood
end

-- ============================================================================
-- == SetIsEnabledBuffAnnouncerFood(info, newValue)                          ==
-- ==                                                                        ==
-- == Standard mutator function for the named property.                      ==
-- ============================================================================

function HTConfig:SetIsEnabledBuffAnnouncerFood(info, newValue)
    self.db.profile.isEnabledBuffAnnouncerFood = newValue
end

-- ============================================================================
-- == ToggleIsEnabledBuffAnnouncerFood()                                     ==
-- ==                                                                        ==
-- == Toggles the value of the named property.                               ==
-- ============================================================================

function HTConfig:ToggleIsEnabledBuffAnnouncerFood()
    self.db.profile.isEnabledBuffAnnouncerFood = HTConfig:ToggleValue(HTConfig:GetIsEnabledBuffAnnouncerFood(nil))
end

-- ============================================================================
-- == GetIsEnabledBuffAnnouncerCauldron(info)                                ==
-- ==                                                                        ==
-- == Standard accessor function for the named property.                     ==
-- ============================================================================

function HTConfig:GetIsEnabledBuffAnnouncerCauldron(info)
    return self.db.profile.isEnabledBuffAnnouncerCauldron
end

-- ============================================================================
-- == SetIsEnabledBuffAnnouncerCauldron(info, newValue)                      ==
-- ==                                                                        ==
-- == Standard mutator function for the named property.                      ==
-- ============================================================================

function HTConfig:SetIsEnabledBuffAnnouncerCauldron(info, newValue)
    self.db.profile.isEnabledBuffAnnouncerCauldron = newValue
end

-- ============================================================================
-- == ToggleIsEnabledBuffAnnouncerCauldron()                                 ==
-- ==                                                                        ==
-- == Toggles the value of the named property.                               ==
-- ============================================================================

function HTConfig:ToggleIsEnabledBuffAnnouncerCauldron()
    self.db.profile.isEnabledBuffAnnouncerCauldron = HTConfig:ToggleValue(HTConfig:GetIsEnabledBuffAnnouncerCauldron(nil))
end

-- ============================================================================
-- == GetIsEnabledBuffAnnouncerHealthStones(info)                            ==
-- ==                                                                        ==
-- == Standard accessor function for the named property.                     ==
-- ============================================================================

function HTConfig:GetIsEnabledBuffAnnouncerHealthStones(info)
    return self.db.profile.isEnabledBuffAnnouncerHealthStones
end

-- ============================================================================
-- == SetIsEnabledBuffAnnouncerHealthStones(info, newValue)                  ==
-- ==                                                                        ==
-- == Standard mutator function for the named property.                      ==
-- ============================================================================

function HTConfig:SetIsEnabledBuffAnnouncerHealthStones(info, newValue)
    self.db.profile.isEnabledBuffAnnouncerHealthStones = newValue
end

-- ============================================================================
-- == ToggleIsEnabledBuffAnnouncerHealthStones()                             ==
-- ==                                                                        ==
-- == Toggles the value of the named property.                               ==
-- ============================================================================

function HTConfig:ToggleIsEnabledBuffAnnouncerHealthStones()
    self.db.profile.isEnabledBuffAnnouncerHealthStones = HTConfig:ToggleValue(HTConfig:GetIsEnabledBuffAnnouncerHealthStones(nil))
end

-- ============================================================================
-- == GetIsEnabledBuffAnnouncerFoodTable(info)                               ==
-- ==                                                                        ==
-- == Standard accessor function for the named property.                     ==
-- ============================================================================

function HTConfig:GetIsEnabledBuffAnnouncerFoodTable(info)
    return self.db.profile.isEnabledBuffAnnouncerFoodTable
end

-- ============================================================================
-- == SetIsEnabledBuffAnnouncerFoodTable(info, newValue)                     ==
-- ==                                                                        ==
-- == Standard mutator function for the named property.                      ==
-- ============================================================================

function HTConfig:SetIsEnabledBuffAnnouncerFoodTable(info, newValue)
    self.db.profile.isEnabledBuffAnnouncerFoodTable = newValue
end

-- ============================================================================
-- == ToggleIsEnabledBuffAnnouncerFoodTable()                                ==
-- ==                                                                        ==
-- == Toggles the value of the named property.                               ==
-- ============================================================================

function HTConfig:ToggleIsEnabledBuffAnnouncerFoodTable()
    self.db.profile.isEnabledBuffAnnouncerFoodTable = HTConfig:ToggleValue(HTConfig:GetIsEnabledBuffAnnouncerFoodTable(nil))
end

-- ============================================================================
-- == GetIsEnabledBuffAnnouncerRepairBot(info)                               ==
-- ==                                                                        ==
-- == Standard accessor function for the named property.                     ==
-- ============================================================================

function HTConfig:GetIsEnabledBuffAnnouncerRepairBot(info)
    return self.db.profile.isEnabledBuffAnnouncerRepairBot
end

-- ============================================================================
-- == SetIsEnabledBuffAnnouncerRepairBot(info, newValue)                     ==
-- ==                                                                        ==
-- == Standard mutator function for the named property.                      ==
-- ============================================================================

function HTConfig:SetIsEnabledBuffAnnouncerRepairBot(info, newValue)
    self.db.profile.isEnabledBuffAnnouncerRepairBot = newValue
end

-- ============================================================================
-- == ToggleIsEnabledBuffAnnouncerRepairBot()                                ==
-- ==                                                                        ==
-- == Toggles the value of the named property.                               ==
-- ============================================================================

function HTConfig:ToggleIsEnabledBuffAnnouncerRepairBot()
    self.db.profile.isEnabledBuffAnnouncerRepairBot = HTConfig:ToggleValue(HTConfig:GetIsEnabledBuffAnnouncerRepairBot(nil))
end

-- ============================================================================
-- == GetBuffAnnouncerFoodMessage(info)                                      ==
-- ==                                                                        ==
-- == Standard accessor function for the named property.                     ==
-- ============================================================================

function HTConfig:GetBuffAnnouncerFoodMessage(info)
    return self.db.profile.buffAnnouncerFoodMessage
end

-- ============================================================================
-- == SetBuffAnnouncerFoodMessage(info, newValue)                            ==
-- ==                                                                        ==
-- == Standard mutator function for the named property.                      ==
-- ============================================================================

function HTConfig:SetBuffAnnouncerFoodMessage(info, newValue)
    self.db.profile.buffAnnouncerFoodMessage = newValue
end

-- ============================================================================
-- == GetBuffAnnouncerCauldronMessage(info)                                  ==
-- ==                                                                        ==
-- == Standard accessor function for the named property.                     ==
-- ============================================================================

function HTConfig:GetBuffAnnouncerCauldronMessage(info)
    return self.db.profile.buffAnnouncerCauldronMessage
end

-- ============================================================================
-- == SetBuffAnnouncerCauldronMessage(info, newValue)                        ==
-- ==                                                                        ==
-- == Standard mutator function for the named property.                      ==
-- ============================================================================

function HTConfig:SetBuffAnnouncerCauldronMessage(info, newValue)
    self.db.profile.buffAnnouncerCauldronMessage = newValue
end

-- ============================================================================
-- == GetBuffAnnouncerHealthStonesMessage(info)                              ==
-- ==                                                                        ==
-- == Standard accessor function for the named property.                     ==
-- ============================================================================

function HTConfig:GetBuffAnnouncerHealthStonesMessage(info)
    return self.db.profile.buffAnnouncerHealthStonesMessage
end

-- ============================================================================
-- == SetBuffAnnouncerHealthStonesMessage(info, newValue)                    ==
-- ==                                                                        ==
-- == Standard mutator function for the named property.                      ==
-- ============================================================================

function HTConfig:SetBuffAnnouncerHealthStonesMessage(info, newValue)
    self.db.profile.buffAnnouncerHealthStonesMessage = newValue
end

-- ============================================================================
-- == GetIsEnabledAutoConvertRaidInvitesToSession(info)                      ==
-- ==                                                                        ==
-- == Standard accessor function for the named property.                     ==
-- ============================================================================

function HTConfig:GetIsEnabledAutoConvertRaidInvitesToSession(info)
    return self.db.profile.isEnabledAutoConvertRaidInvitesToSession
end

-- ============================================================================
-- == SetIsEnabledAutoConvertRaidInvitesToSession(info, newValue)            ==
-- ==                                                                        ==
-- == Standard mutator function for the named property.                      ==
-- ============================================================================

function HTConfig:SetIsEnabledAutoConvertRaidInvitesToSession(info, newValue)
    self.db.profile.isEnabledAutoConvertRaidInvitesToSession = newValue
end

-- ============================================================================
-- == ToggleIsEnabledAutoConvertRaidInvitesToSession()                       ==
-- ==                                                                        ==
-- == Toggles the value of the named property.                               ==
-- ============================================================================

function HTConfig:ToggleIsEnabledAutoConvertRaidInvitesToSession()
    self.db.profile.isEnabledAutoConvertRaidInvitesToSession = HTConfig:ToggleValue(HTConfig:GetIsEnabledAutoConvertRaidInvitesToSession(nil))
end

-- ============================================================================
-- == GetIsEnabledAutoSetMasterLoot(info)                                    ==
-- ==                                                                        ==
-- == Standard accessor function for the named property.                     ==
-- ============================================================================

function HTConfig:GetIsEnabledAutoSetMasterLoot(info)
    return self.db.profile.isEnabledAutoSetMasterLoot
end

-- ============================================================================
-- == SetIsEnabledAutoSetMasterLoot(info, newValue)                          ==
-- ==                                                                        ==
-- == Standard mutator function for the named property.                      ==
-- ============================================================================

function HTConfig:SetIsEnabledAutoSetMasterLoot(info, newValue)
    self.db.profile.isEnabledAutoSetMasterLoot = newValue
end

-- ============================================================================
-- == ToggleIsEnabledAutoSetMasterLoot()                                     ==
-- ==                                                                        ==
-- == Toggles the value of the named property.                               ==
-- ============================================================================

function HTConfig:ToggleIsEnabledAutoSetMasterLoot()
    self.db.profile.isEnabledAutoSetMasterLoot = HTConfig:ToggleValue(HTConfig:GetIsEnabledAutoSetMasterLoot(nil))
end

-- ============================================================================
-- == GetIsEnabledAutoSelectMasterLooter(info)                               ==
-- ==                                                                        ==
-- == Standard accessor function for the named property.                     ==
-- ============================================================================

function HTConfig:GetIsEnabledAutoSelectMasterLooter(info)
    return self.db.profile.isEnabledAutoSelectMasterLooter
end

-- ============================================================================
-- == SetIsEnabledAutoSelectMasterLooter(info, newValue)                     ==
-- ==                                                                        ==
-- == Standard mutator function for the named property.                      ==
-- ============================================================================

function HTConfig:SetIsEnabledAutoSelectMasterLooter(info, newValue)
    self.db.profile.isEnabledAutoSelectMasterLooter = newValue
end

-- ============================================================================
-- == ToggleIsEnabledAutoSelectMasterLooter()                                ==
-- ==                                                                        ==
-- == Toggles the value of the named property.                               ==
-- ============================================================================

function HTConfig:ToggleIsEnabledAutoSelectMasterLooter()
    self.db.profile.isEnabledAutoSelectMasterLooter = HTConfig:ToggleValue(HTConfig:GetIsEnabledAutoSelectMasterLooter(nil))
end

-- ============================================================================
-- == GetIsEnabledASMLRaidLeaderTest(info)                                   ==
-- ==                                                                        ==
-- == Standard accessor function for the named property.                     ==
-- ============================================================================

function HTConfig:GetIsEnabledASMLRaidLeaderTest(info)
    return self.db.profile.isEnabledASMLRaidLeaderTest
end

-- ============================================================================
-- == SetIsEnabledASMLRaidLeaderTest(info, newValue)                         ==
-- ==                                                                        ==
-- == Standard mutator function for the named property.                      ==
-- ============================================================================

function HTConfig:SetIsEnabledASMLRaidLeaderTest(info, newValue)
    self.db.profile.isEnabledASMLRaidLeaderTest = newValue
end

-- ============================================================================
-- == ToggleIsEnabledASMLRaidLeaderTest()                                    ==
-- ==                                                                        ==
-- == Toggles the value of the named property.                               ==
-- ============================================================================

function HTConfig:ToggleIsEnabledASMLRaidLeaderTest()
    self.db.profile.isEnabledASMLRaidLeaderTest = HTConfig:ToggleValue(HTConfig:GetIsEnabledASMLRaidLeaderTest(nil))
end

-- ============================================================================
-- == GetIsEnabledASMLRaidAssistantTest(info)                                ==
-- ==                                                                        ==
-- == Standard accessor function for the named property.                     ==
-- ============================================================================

function HTConfig:GetIsEnabledASMLRaidAssistantTest(info)
    return self.db.profile.isEnabledASMLRaidAssistantTest
end

-- ============================================================================
-- == SetIsEnabledASMLRaidAssistantTest(info, newValue)                      ==
-- ==                                                                        ==
-- == Standard mutator function for the named property.                      ==
-- ============================================================================

function HTConfig:SetIsEnabledASMLRaidAssistantTest(info, newValue)
    self.db.profile.isEnabledASMLRaidAssistantTest = newValue
end

-- ============================================================================
-- == ToggleIsEnabledASMLRaidAssistantTest()                                 ==
-- ==                                                                        ==
-- == Toggles the value of the named property.                               ==
-- ============================================================================

function HTConfig:ToggleIsEnabledASMLRaidAssistantTest()
    self.db.profile.isEnabledASMLRaidAssistantTest = HTConfig:ToggleValue(HTConfig:GetIsEnabledASMLRaidAssistantTest(nil))
end

-- ============================================================================
-- == GetIsEnabledASMLGuildMasterTest(info)                                  ==
-- ==                                                                        ==
-- == Standard accessor function for the named property.                     ==
-- ============================================================================

function HTConfig:GetIsEnabledASMLGuildMasterTest(info)
    return self.db.profile.isEnabledASMLGuildMasterTest
end

-- ============================================================================
-- == SetIsEnabledASMLGuildMasterTest(info, newValue)                        ==
-- ==                                                                        ==
-- == Standard mutator function for the named property.                      ==
-- ============================================================================

function HTConfig:SetIsEnabledASMLGuildMasterTest(info, newValue)
    self.db.profile.isEnabledASMLGuildMasterTest = newValue
end

-- ============================================================================
-- == ToggleIsEnabledASMLGuildMasterTest()                                   ==
-- ==                                                                        ==
-- == Toggles the value of the named property.                               ==
-- ============================================================================

function HTConfig:ToggleIsEnabledASMLGuildMasterTest()
    self.db.profile.isEnabledASMLGuildMasterTest = HTConfig:ToggleValue(HTConfig:GetIsEnabledASMLGuildMasterTest(nil))
end

-- ============================================================================
-- == GetIsEnabledASMLGuildOfficerTest(info)                                 ==
-- ==                                                                        ==
-- == Standard accessor function for the named property.                     ==
-- ============================================================================

function HTConfig:GetIsEnabledASMLGuildOfficerTest(info)
    return self.db.profile.isEnabledASMLGuildOfficerTest
end

-- ============================================================================
-- == SetIsEnabledASMLGuildOfficerTest(info, newValue)                       ==
-- ==                                                                        ==
-- == Standard mutator function for the named property.                      ==
-- ============================================================================

function HTConfig:SetIsEnabledASMLGuildOfficerTest(info, newValue)
    self.db.profile.isEnabledASMLGuildOfficerTest = newValue
end

-- ============================================================================
-- == ToggleIsEnabledASMLGuildOfficerTest()                                  ==
-- ==                                                                        ==
-- == Toggles the value of the named property.                               ==
-- ============================================================================

function HTConfig:ToggleIsEnabledASMLGuildOfficerTest()
    self.db.profile.isEnabledASMLGuildOfficerTest = HTConfig:ToggleValue(HTConfig:GetIsEnabledASMLGuildOfficerTest(nil))
end

-- ============================================================================
-- == GetIsEnabledASMLRaidMasterTest(info)                                   ==
-- ==                                                                        ==
-- == Standard accessor function for the named property.                     ==
-- ============================================================================

function HTConfig:GetIsEnabledASMLRaidMasterTest(info)
    return self.db.profile.isEnabledASMLRaidMasterTest
end

-- ============================================================================
-- == SetIsEnabledASMLRaidMasterTest(info, newValue)                         ==
-- ==                                                                        ==
-- == Standard mutator function for the named property.                      ==
-- ============================================================================

function HTConfig:SetIsEnabledASMLRaidMasterTest(info, newValue)
    self.db.profile.isEnabledASMLRaidMasterTest = newValue
end

-- ============================================================================
-- == ToggleIsEnabledASMLRaidMasterTest()                                    ==
-- ==                                                                        ==
-- == Toggles the value of the named property.                               ==
-- ============================================================================

function HTConfig:ToggleIsEnabledASMLRaidMasterTest()
    self.db.profile.isEnabledASMLRaidMasterTest = HTConfig:ToggleValue(HTConfig:GetIsEnabledASMLRaidMasterTest(nil))
end

-- ============================================================================
-- == GetIsEnabledASMLDesignatedMasterLooterTest(info)                       ==
-- ==                                                                        ==
-- == Standard accessor function for the named property.                     ==
-- ============================================================================

function HTConfig:GetIsEnabledASMLDesignatedMasterLooterTest(info)
    return self.db.profile.isEnabledASMLDesignatedMasterLooterTest
end

-- ============================================================================
-- == SetIsEnabledASMLDesignatedMasterLooterTest(info, newValue)             ==
-- ==                                                                        ==
-- == Standard mutator function for the named property.                      ==
-- ============================================================================

function HTConfig:SetIsEnabledASMLDesignatedMasterLooterTest(info, newValue)
    self.db.profile.isEnabledASMLDesignatedMasterLooterTest = newValue
end

-- ============================================================================
-- == ToggleIsEnabledASMLDesignatedMasterLooterTest()                        ==
-- ==                                                                        ==
-- == Toggles the value of the named property.                               ==
-- ============================================================================

function HTConfig:ToggleIsEnabledASMLDesignatedMasterLooterTest()
    self.db.profile.isEnabledASMLDesignatedMasterLooterTest = HTConfig:ToggleValue(HTConfig:GetIsEnabledASMLDesignatedMasterLooterTest(nil))
end

-- ============================================================================
-- == GetVoipType(info)                                                      ==
-- ==                                                                        ==
-- == Standard accessor function for the named property.                     ==
-- ============================================================================

function HTConfig:GetVoipType(info)
    return self.db.profile.voipType
end

-- ============================================================================
-- == SetVoipType(info, newValue)                                            ==
-- ==                                                                        ==
-- == Standard mutator function for the named property.                      ==
-- ============================================================================

function HTConfig:SetVoipType(info, newValue)
    self.db.profile.voipType = newValue
end

-- ============================================================================
-- == GetVoipHostname(info)                                                  ==
-- ==                                                                        ==
-- == Standard accessor function for the named property.                     ==
-- ============================================================================

function HTConfig:GetVoipHostname(info)
    return self.db.profile.voipHostname
end

-- ============================================================================
-- == SetVoipHostname(info, newValue)                                        ==
-- ==                                                                        ==
-- == Standard mutator function for the named property.                      ==
-- ============================================================================

function HTConfig:SetVoipHostname(info, newValue)
    self.db.profile.voipHostname = newValue
end

-- ============================================================================
-- == GetVoipPortNumber(info)                                                ==
-- ==                                                                        ==
-- == Standard accessor function for the named property.                     ==
-- ============================================================================

function HTConfig:GetVoipPortNumber(info)
    return self.db.profile.voipPortNumber
end

-- ============================================================================
-- == SetVoipPortNumber(info, newValue)                                      ==
-- ==                                                                        ==
-- == Standard mutator function for the named property.                      ==
-- ============================================================================

function HTConfig:SetVoipPortNumber(info, newValue)
    self.db.profile.voipPortNumber = newValue
end

-- ============================================================================
-- == GetVoipUsername(info)                                                  ==
-- ==                                                                        ==
-- == Standard accessor function for the named property.                     ==
-- ============================================================================

function HTConfig:GetVoipUsername(info)
    return self.db.profile.voipUsername
end

-- ============================================================================
-- == SetVoipUsername(info, newValue)                                        ==
-- ==                                                                        ==
-- == Standard mutator function for the named property.                      ==
-- ============================================================================

function HTConfig:SetVoipUsername(info, newValue)
    self.db.profile.voipUsername = newValue
end

-- ============================================================================
-- == GetVoipPassword(info)                                                  ==
-- ==                                                                        ==
-- == Standard accessor function for the named property.                     ==
-- ============================================================================

function HTConfig:GetVoipPassword(info)
    return self.db.profile.voipPassword
end

-- ============================================================================
-- == SetVoipPassword(info, newValue)                                        ==
-- ==                                                                        ==
-- == Standard mutator function for the named property.                      ==
-- ============================================================================

function HTConfig:SetVoipPassword(info, newValue)
    self.db.profile.voipPassword = newValue
end

-- ============================================================================
-- == GetAirInfoMessage(info)                                                ==
-- ==                                                                        ==
-- == Standard accessor function for the named property.                     ==
-- ============================================================================

function HTConfig:GetAirInfoMessage(info)
    return self.db.profile.airInfoMessage
end

-- ============================================================================
-- == SetAirInfoMessage(info, newValue)                                      ==
-- ==                                                                        ==
-- == Standard mutator function for the named property.                      ==
-- ============================================================================

function HTConfig:SetAirInfoMessage(info, newValue)
    self.db.profile.airInfoMessage = newValue
end

-- ============================================================================
-- == GetAirGuildMessage(info)                                               ==
-- ==                                                                        ==
-- == Standard accessor function for the named property.                     ==
-- ============================================================================

function HTConfig:GetAirGuildMessage(info)
    return self.db.profile.airGuildMessage
end

-- ============================================================================
-- == SetAirGuildMessage(info, newValue)                                     ==
-- ==                                                                        ==
-- == Standard mutator function for the named property.                      ==
-- ============================================================================

function HTConfig:SetAirGuildMessage(info, newValue)
    self.db.profile.airGuildMessage = newValue
end

-- ============================================================================
-- == GetAirOfficerListMessage(info)                                         ==
-- ==                                                                        ==
-- == Standard accessor function for the named property.                     ==
-- ============================================================================

function HTConfig:GetAirOfficerListMessage(info)
    return self.db.profile.airOfficerListMessage
end

-- ============================================================================
-- == SetAirOfficerListMessage(info, newValue)                               ==
-- ==                                                                        ==
-- == Standard mutator function for the named property.                      ==
-- ============================================================================

function HTConfig:SetAirOfficerListMessage(info, newValue)
    self.db.profile.airOfficerListMessage = newValue
end

-- ============================================================================
-- == GetAirRaidTimesMessage(info)                                           ==
-- ==                                                                        ==
-- == Standard accessor function for the named property.                     ==
-- ============================================================================

function HTConfig:GetAirRaidTimesMessage(info)
    return self.db.profile.airRaidTimesMessage
end

-- ============================================================================
-- == SetAirRaidTimesMessage(info, newValue)                                 ==
-- ==                                                                        ==
-- == Standard mutator function for the named property.                      ==
-- ============================================================================

function HTConfig:SetAirRaidTimesMessage(info, newValue)
    self.db.profile.airRaidTimesMessage = newValue
end

-- ============================================================================
-- == GetAirRecruitmentMessage(info)                                         ==
-- ==                                                                        ==
-- == Standard accessor function for the named property.                     ==
-- ============================================================================

function HTConfig:GetAirRecruitmentMessage(info)
    return self.db.profile.airRecruitmentMessage
end

-- ============================================================================
-- == SetAirRecruitmentMessage(info, newValue)                               ==
-- ==                                                                        ==
-- == Standard mutator function for the named property.                      ==
-- ============================================================================

function HTConfig:SetAirRecruitmentMessage(info, newValue)
    self.db.profile.airRecruitmentMessage = newValue
end

-- ============================================================================
-- == GetAirContactUsMessage(info)                                           ==
-- ==                                                                        ==
-- == Standard accessor function for the named property.                     ==
-- ============================================================================

function HTConfig:GetAirContactUsMessage(info)
    return self.db.profile.airContactUsMessage
end

-- ============================================================================
-- == SetAirContactUsMessage(info, newValue)                                 ==
-- ==                                                                        ==
-- == Standard mutator function for the named property.                      ==
-- ============================================================================

function HTConfig:SetAirContactUsMessage(info, newValue)
    self.db.profile.airContactUsMessage = newValue
end

-- ============================================================================
-- == GetAirZatMessage(info)                                                 ==
-- ==                                                                        ==
-- == Standard accessor function for the named property.                     ==
-- ============================================================================

function HTConfig:GetAirZatMessage(info)
    return self.db.profile.airZatMessage
end

-- ============================================================================
-- == SetAirZatMessage(info, newValue)                                       ==
-- ==                                                                        ==
-- == Standard mutator function for the named property.                      ==
-- ============================================================================

function HTConfig:SetAirZatMessage(info, newValue)
    self.db.profile.airZatMessage = newValue
end

-- ============================================================================
-- == GetIsEnabledXXX(info)                                                  ==
-- ==                                                                        ==
-- == Standard accessor function for the named property.                     ==
-- ============================================================================

function HTConfig:GetIsEnabledXXX(info)
    return self.db.profile.isEnabledXXX
end

-- ============================================================================
-- == SetIsEnabledXXX(info, newValue)                                        ==
-- ==                                                                        ==
-- == Standard mutator function for the named property.                      ==
-- ============================================================================

function HTConfig:SetIsEnabledXXX(info, newValue)
    self.db.profile.isEnabledXXX = newValue
end

-- ============================================================================
-- == ToggleIsEnabledXXX()                                                   ==
-- ==                                                                        ==
-- == Toggles the value of the named property.                               ==
-- ============================================================================

function HTConfig:ToggleIsEnabledXXX()
    self.db.profile.isEnabledXXX = HTConfig:ToggleValue(HTConfig:GetIsEnabledXXX(nil))
end
