-- ============================================================================
-- == HTConsole - A collection of functions related to interactions that     ==
-- ==             occur via the console. This includes most forms of chat    ==
-- ==             based communication and the display of text-messages       ==
-- ==             within Chat windows.                                       ==
-- ============================================================================

HTConsole           = LibStub("AceAddon-3.0"):NewAddon("HTConsole", "AceConsole-3.0", "AceEvent-3.0", "AceTimer-3.0")
local L             = LibStub("AceLocale-3.0"):GetLocale("HalonaTools")
local htUsers       = {}        -- Stores names/versions of HT users.
local versions      = {}        -- Stores versions of HT used by Guild.
local messages      = {}        -- Stores messages received from other players.
local senders       = {}        -- Stores names of message senders.
local taskHandleHTH = ""        -- Stores the handle for the HT heartbeat task.
local taskHandleRMS = ""        -- Stores the handle for the RMS timer task.
local whisperers    = {}        -- Stores the names of whisper-senders.
local guildInvites  = {}        -- Stores the details of guild-invitation tasks.

-- ============================================================================
-- == OnInitialize()                                                         ==
-- ==                                                                        ==
-- == This function is called when the addon is initialised.                 ==
-- ============================================================================

function HTConsole:OnInitialize()
end

-- ============================================================================
-- == OnEnable()                                                             ==
-- ==                                                                        ==
-- == This function is called when the addon is enabled.                     ==
-- ============================================================================

function HTConsole:OnEnable()

  -- Subscribe to the events which this component monitors.
  self:RegisterEvent("CHAT_MSG_WHISPER")
  self:RegisterEvent("CHAT_MSG_BN_WHISPER")
  self:RegisterEvent("CHAT_MSG_SYSTEM")
  self:RegisterEvent("CHAT_MSG_ADDON")
  self:RegisterEvent("ZONE_CHANGED_NEW_AREA")

  -- Subscribe to the CHAT_MSG_ADDON prefixes used by HalonaTools.
  RegisterAddonMessagePrefix(L["con-addonmessage-prefix-htria"])
  RegisterAddonMessagePrefix(L["con-addonmessage-prefix-htrqa"])
  RegisterAddonMessagePrefix(L["con-addonmessage-prefix-htrea"])
  RegisterAddonMessagePrefix(L["con-addonmessage-prefix-htavb"])
  RegisterAddonMessagePrefix(L["con-addonmessage-prefix-htavq"])
  RegisterAddonMessagePrefix(L["con-addonmessage-prefix-htrms"])

  -- Ensure versions table contains at least one record; the record for this user.
  local thisVersionRecord = UnitName("player") .. L["all-text-separator"] .. L["addon-version-name"] .. L["all-text-separator"] .. L["addon-version-number"]
  table.insert(versions, thisVersionRecord)

  -- Initial call to the heartbeat function. Once called, it reschedules itself.
  taskHandleHTH = L["con-rms-scheduled-timer-unset"]
  HTConsole:DoHeartbeat()

  -- Attempt to schedule the recruitment message sender. Will only work if enabled.
  taskHandleRMS = L["con-rms-scheduled-timer-unset"]
  HTConsole:ScheduleTaskRMS()

end

-- ============================================================================
-- == OnDisable()                                                            ==
-- ==                                                                        ==
-- == This function is called when the addon is disabled.                    ==
-- ============================================================================

function HTConsole:OnDisable()
end

-- ============================================================================
-- == DoHeartbeat()                                                          ==
-- ==                                                                        ==
-- == This function is intended to provide a place where non-critical tasks  ==
-- == that need to be performed periodically can be called from. The         ==
-- == function would typically be called when the addon is enabled and at    ==
-- == the function's conclusion it reschedules itself to be called again     ==
-- == in the future.                                                         ==
-- ============================================================================

function HTConsole:DoHeartbeat()

  -- Invalidate the task-handle. (Protects "GetHeartbeatTimer()" calls.)
  taskHandleHTH = L["con-rms-scheduled-timer-unset"]

  -- HTConsole:Debug("Heartbeat - Performing periodic tasks.")

  -- Broadcast the details of the version of HT this user has.
  HTConsole:BroadcastMessageAVB()

  -- Check if the RMS feature needs to be jump-started.
  HTConsole:JumpstartTaskRMS()

  -- Perform auto-promotion if feature is enabled.
  if HTConfig:GetIsEnabledAutoRaidPromotions(nil) then
    HTConsole:DoAllRaidPromotions()
  end

  -- Perform automatic busy responder profile selection, if enabled.
  HTConsole:BusyResponderAutoSelectProfile()

  -- Call heartbeat functions for other HT components.
  HalonaTools:DoHeartbeat()
  HTBuffMonitor:DoHeartbeat()

  -- Reschedule this function to be called again after the prescribed interval.
  taskHandleHTH = self:ScheduleTimer("DoHeartbeat", HTConfig:GetHeartbeatInterval(nil))

end

-- ============================================================================
-- == GetHeartbeatTimer()                                                    ==
-- ==                                                                        ==
-- == This function retrieves the current value of the heartbeat timer.      ==
-- ============================================================================

function HTConsole:GetHeartbeatTimer()

  local timeInSeconds = "0.0"

  if taskHandleHTH ~= L["con-rms-scheduled-timer-unset"] then
    local timerValue = HTData:SafeNumber(self:TimeLeft(taskHandleHTH))
    local timerArgs  = HTData:StringSplit(timerValue, ".")
    timeInSeconds    = timerArgs[1]
  end

  return timeInSeconds

end

-- ============================================================================
-- == ExecuteChatCommand(arg)                                                ==
-- ==                                                                        ==
-- == This function attempts to execute the supplied argument as though it   ==
-- == were a command entered by the user in the chat window.                 ==
-- ============================================================================

function HTConsole:ExecuteChatCommand(arg)

  if( not DEFAULT_CHAT_FRAME ) then return end

  DEFAULT_CHAT_FRAME.editBox:SetText(arg);
  ChatEdit_SendText(DEFAULT_CHAT_FRAME.editBox);

end

-- ============================================================================
-- == SendChatMessage(messageText, channelName, language, recipient)         ==
-- ==                                                                        ==
-- == This function is ostensibly a wrapper to the normal SendChatMessage    ==
-- == function with minor changes as follows:                                ==
-- ==                                                                        ==
-- == 1: Language is checked because it may not be passed in.                ==
-- == 2: If channelName = "CHAT", output is routed to self:Print() instead.  ==
-- == 3: If channelName = "NULL", output is muted.                           ==
-- ==                                                                        ==
-- == The intention for the existence of the NULL option for the channel     ==
-- == name is to allow for functions to pass a parameter that can be         ==
-- == switched between a normal channel and null to turn on/off debug mode   ==
-- == features.                                                              ==
-- ============================================================================

function HTConsole:SendChatMessage(messageText, channelName, language, recipient)

  -- == -----------------------------------------------------------------------
  -- == -- Check whether the language option has been provided.              --
  -- == -----------------------------------------------------------------------
  if language == nil or language == " " then
    language = nil
  end

  channelName = HTConsole:SafeChatChannelName(channelName)

  -- == -----------------------------------------------------------------------
  -- == -- Send chat output to 'chat' or to intended channel if not 'NULL'.  --
  -- == -----------------------------------------------------------------------
  if channelName == "CHAT" then
    HTConsole:PrintChatMessage(messageText)
  elseif channelName == "ERRORFRAME" then
    HTConsole:PrintErrorFrameMessage(messageText)
  elseif channelName ~= "NULL" then
    SendChatMessage(messageText, channelName, language, recipient)
  end

end

-- ============================================================================
-- == PrintChatMessage(messageText)                                          ==
-- ==                                                                        ==
-- == This function prints the supplied message text parameter to the chat   ==
-- == window. Since the chat-window supports colour encoding of content, the ==
-- == text is preprocessed to colourise recognised tokens.                   ==
-- ============================================================================

function HTConsole:PrintChatMessage(messageText)

  -- Colourise: '[HT] - Subtitle - OtherText...', Yellow Subtitle.
  messageText = string.gsub(messageText, "[%-](.-)[%-]", "-|cffffff00%1|r-", 1)

  -- Colourise: '[HT]', Blizzard-Blue [HT].
  messageText = string.gsub(messageText, "[%[]HT[%]]", "|cff00c0ff[HT]|r", 1)

  print(messageText)

end

-- ============================================================================
-- == PrintErrorFrameMessage(messageText)                                    ==
-- ==                                                                        ==
-- == This function prints the supplied message text parameter to the UI     ==
-- == error-frame.                                                           ==
-- ============================================================================

function HTConsole:PrintErrorFrameMessage(messageText)

  UIErrorsFrame:AddMessage(messageText, 0, 1.0, 1.0, 1.0, 1)

end

-- ============================================================================
-- == SendWrappedMessage(messageText, channelName)                           ==
-- ==                                                                        ==
-- == This function processes the supplied messageText data into a series of ==
-- == individual messages which are then output to the channel identified by ==
-- == the channelName parameter.                                             ==
-- ============================================================================

function HTConsole:SendWrappedMessage(messageText, channelName, language, recipient)

  local maxWidth        = HTConfig:GetChatWindowTextMaxWidth(nil)
  local words           = HTData:StringSplit(messageText, " ")
  local characterCount  = 0
  local thisLineText    = " "
  local spacerChar      = ""

  -- HTConsole:Debug("maxWidth=[" .. maxWidth .. "]")

  -- Loop through the list of words, printing as many per line as the maximum
  -- line width allows.
  for i,v in ipairs(words) do

    -- HTConsole:Debug("Line: [" .. thisLineText .. "], Word: [" .. v .. "], Length: [" .. characterCount .. "], Limit: [" .. maxWidth .. "]")

    if (characterCount + string.len(v)) < maxWidth then
      thisLineText   = thisLineText .. spacerChar .. v
      characterCount = characterCount + string.len(v) + 1
      spacerChar     = " "
    else
      HTConsole:SendChatMessage(thisLineText, channelName, language, recipient)
      thisLineText      = spacerChar .. v .. spacerChar
      characterCount    = 0
      spacerChar        = ""
    end

  end

  -- Check if there are any words remaining to be printed as a final non-full
  -- line.
  if string.len(thisLineText) > 0 then
    HTConsole:SendChatMessage(thisLineText, channelName, language, recipient)
  end

end

-- ============================================================================
-- == SendChannelMessage(messageText, channelNumber)                         ==
-- ==                                                                        ==
-- == This function sends the supplied message text to the nominated chat    ==
-- == channel. If the nominated channelNumber is 0, it is assumed that no    ==
-- == suitable channel exists and the output is redirected to the CHAT       ==
-- == channel instead.                                                       ==
-- ============================================================================

function HTConsole:SendChannelMessage(messageText, channelNumber)

  if channelNumber == 0 then
    HTConsole:SendChatMessage(messageText, "CHAT", nil, nil)
  else
    HTConsole:SendChatMessage(messageText, "CHANNEL", nil, channelNumber)
  end

end

-- ============================================================================
-- == SendTitleMessage(messageText, channelName)                             ==
-- ==                                                                        ==
-- == This function processes the supplied messageText data into a series of ==
-- == individual messages which are then output to the channel identified by ==
-- == the channelName parameter.                                             ==
-- ============================================================================

function HTConsole:SendTitleMessage(messageText, channelName)


end

-- ============================================================================
-- == SendTitleBar(channelName)                                              ==
-- ==                                                                        ==
-- == This function outputs a title-bar configured to the width specified in ==
-- == the configuration property describing the maximum chat window width.   ==
-- ============================================================================

function HTConsole:SendTitleBar(channelName)

  local titleBarText = ""
  local maxWidth     = abs(HTConfig:GetChatWindowTextMaxWidth(nil) * 1.5 )

  for i=1,maxWidth do
    titleBarText = titleBarText .. "-"
  end

  HTConsole:SendChatMessage(HTConsole:GetTitleBar(), channelName, nil, nil)

end

-- ============================================================================
-- == GetTitleBar()                                                          ==
-- ==                                                                        ==
-- == This function returns a title-bar whose width is defined by the        ==
-- == current max-width calculation.                                         ==
-- ============================================================================

function HTConsole:GetTitleBar()

  local titleBarText = ""
  local maxWidth     = abs(HTConfig:GetChatWindowTextMaxWidth(nil) * 1.5 )

  for i=1,maxWidth do
    titleBarText = titleBarText .. "-"
  end

  return titleBarText

end

-- ============================================================================
-- == Debug(messageText)                                                     ==
-- ==                                                                        ==
-- == This function outputs the supplied message text to the "CHAT" channel  ==
-- == as a standard format 'debug' message if the debug-mode is currently    ==
-- == enabled.                                                               ==
-- ==                                                                        ==
-- == Support has been added for a 'debug filter' that will check for the    ==
-- == existence of a defined string within the message which acts as an      ==
-- == identifier, a means to categorise debug messages with a specific topic.==
-- ==                                                                        ==
-- == Typically, the debug message format would be:                          ==
-- ==                                                                        ==
-- == "[HT-DEBUG] - {topicname} - Message"                                   ==
-- ==                                                                        ==
-- == ...and the match is performed on "- {topicname} -" sequence.           ==
-- ============================================================================

function HTConsole:Debug(messageText)

  -- Return immediately if the messageText parameter is empty/null.
  if messageText == nil then return end

  -- Only proceed if the Debug feature is enabled.
  if HTConfig:GetIsEnabledDebugMode(nil) then

    local debugText = "|cffff0000" .. "[HT-DEBUG]" .. "|r" .. " - " .. HTData:SafeString(messageText)

    -- If the Debug Filter is enabled, only output IF filter condition is met.
    if HTConfig:GetIsEnabledDebugFilter(nil) then
      if string.match(messageText, HTConfig:GetDebugFilter(nil)) then
        HTConsole:SendChatMessage(debugText, "CHAT", nil, nil)
        return
      else
        return
      end
    end

    -- The debug filter is not enabled so output debug message.
    HTConsole:SendChatMessage(debugText, "CHAT", nil, nil)

  end

end

-- ============================================================================
-- == SafeChatChannelName(channelName)                                       ==
-- ==                                                                        ==
-- == This function simply checks that the supplied channelName parameter    ==
-- == would be safe to use in the context of this user. If the name would be ==
-- == considered unsafe, a safe alternative is substituted.                  ==
-- ============================================================================

function HTConsole:SafeChatChannelName(channelName)

  -- == -----------------------------------------------------------------------
  -- == -- Setup variables that will be needed.                              --
  -- == -----------------------------------------------------------------------
  local playerName  = HTCommon:UnitName("player")
  -- print("playerName = "..playerName)     -- Can't use HTConsole:Debug here!
  
  -- == -----------------------------------------------------------------------
  -- == -- [GUILD] Checks...                                                 --
  -- == -----------------------------------------------------------------------
  if channelName == "GUILD" then
    if IsInGuild() == false then
      channelName = "CHAT"
      -- print(L["con-player-not-in-guild"]) -- Can't use HTConsole:Debug here!
    end
  end

  -- == -----------------------------------------------------------------------
  -- == -- [RAID] Checks...                                                  --
  -- == -----------------------------------------------------------------------
  if channelName == "RAID" then
    if HTCommon:IsPlayerInRaid() == false then
      channelName = "PARTY"
      -- print(L["con-player-not-in-raid"]) -- Can't use HTConsole:Debug here!
    end
  end

  -- == -----------------------------------------------------------------------
  -- == -- [PARTY] Checks...                                                 --
  -- == -----------------------------------------------------------------------
  if channelName == "PARTY" then
    if HTCommon:IsPlayerInParty() == false then
      channelName = "CHAT"
      -- print(L["con-player-not-in-party"]) -- Can't use HTConsole:Debug here!
    end
  end

  -- == -----------------------------------------------------------------------
  -- == -- [OFFICER] Checks...                                               --
  -- == -----------------------------------------------------------------------
  if channelName == "OFFICER" then
    if HTCommon:IsCharacterInGuild(playerName) == true then
      if HTCommon:IsOfficerRankedCharacter(playerName) == false then
        channelName = "CHAT"
        -- print(L["con-player-not-an-officer"]) -- Can't use HTConsole:Debug here!
      end
    else
      channelName = "CHAT"
      -- print(L["con-player-not-in-guild"]) -- Can't use HTConsole:Debug here!
    end
  end

  -- == -----------------------------------------------------------------------
  -- == -- Return the value, adjusted or otherwise, of channelName.          --
  -- == -----------------------------------------------------------------------
  -- print("channelName = "..channelName) -- Can't use HTConsole:Debug here!
  return channelName

end

-- ============================================================================
-- == CHAT_MSG_WHISPER(channel, msg, sender)                                 ==
-- ==                                                                        ==
-- == This function performs actions when the CHAT_MSG_WHISPER event is      ==
-- == triggered. It is triggered when the player's character receives a      ==
-- == message via the whisper 'channel.'                                     ==
-- ============================================================================

function HTConsole:CHAT_MSG_WHISPER(channel, msg, sender)

  HTConsole:Debug("Message:[" .. HTData:SafeString(msg) .. "], sender:[" .. HTData:SafeString(sender) .. "]")
  HTConsole:MessageListenerPersonalWhispers(channelString, msg, sender)

end

-- ============================================================================
-- == CHAT_MSG_BN_WHISPER(channel, msg, sender)                              ==
-- ==                                                                        ==
-- == This function performs actions when the CHAT_MSG_BN_WHISPER event is   ==
-- == triggered. It is triggered when the player's character receives a      ==
-- == message via Battle.Net.                                                ==
-- ==                                                                        ==
-- == NB: Processing only occurs for some functions IF the sender is on the  ==
-- ==     same server as the player, since many operations are only valid in ==
-- ==     such a context.                                                    ==
-- ============================================================================

function HTConsole:CHAT_MSG_BN_WHISPER(msg, sender, unknown1, unknown2, unknown3, unknown4, unknown5, unknown6, unknown7, unknown8, counter, unknown9, presenceID, unknown10)

  if HTCommon:IsCharacterFromSameServer(sender) == true then
    HTConsole:MessageListenerPersonalWhispers(L["all-comms-channel-name-whisper-bn"], msg, sender)
  end

end

-- ============================================================================
-- == MessageListenerPersonalWhispers(channel, msg, sender)                  ==
-- ==                                                                        ==
-- == This function consolidates message-listening functions for all sources ==
-- == of personal whispers which now includes both the original dedicated    ==
-- == whisper channel as well as additional Battle.net managed channels as   ==
-- == well.                                                                  ==
-- ============================================================================

function HTConsole:MessageListenerPersonalWhispers(channel, msg, sender)

  HTConsole:MessageListenerLogWhisperers(sender)        -- "Log Whisperers"
  HTConsole:MessageListenerAutoInvitations(msg, sender) -- "Auto Invitations"
  HTConsole:MessageListenerAIR(msg, sender)             -- "Auto Info Requests"
  HTConsole:MessageListenerBusyResponder(msg, sender)   -- "Busy Responder"

end

-- ============================================================================
-- == CHAT_MSG_SYSTEM(msg)                                                   ==
-- ==                                                                        ==
-- == This function performs actions when the CHAT_MSG_SYSTEM event is       ==
-- == triggered. It is triggered when the player's character receives a      ==
-- == message via the system 'channel.'                                      ==
-- ==                                                                        ==
-- ============================================================================

function HTConsole:CHAT_MSG_SYSTEM(event, msg)

  HTConsole:MessageListenerARP(msg)                   -- "Auto Raid Promotions"
  HTConsole:MessageListenerGuildInvitations(msg)      -- "Guild Invitations"

end

-- ============================================================================
-- == CHAT_MSG_ADDON(prefix, msg, channel, sender)                           ==
-- ==                                                                        ==
-- == This function performs actions when the CHAT_MSG_ADDON event is        ==
-- == triggered. It is triggered when the player's character receives a      ==
-- == message via the addon 'channel' that was introduced circa patch 1.12.  ==
-- ==                                                                        ==
-- == Currently, this event is monitored to permit communication between     ==
-- == instances of HalonaTools being run by different players.               ==
-- ============================================================================

function HTConsole:CHAT_MSG_ADDON(event, prefix, msg, channel, sender)

  -- HTConsole:Debug("CHAT_MSG_ADDON - event=["..HTData:SafeString(event).."], prefix=["..HTData:SafeString(prefix).."], msg=["..HTData:SafeString(msg).."], channel=["..HTData:SafeString(channel).."], sender=["..HTData:SafeString(sender).."]")

  HTConsole:MessageListenerRIA(prefix, msg, channel, sender) -- "Raid Invitation Announcement"
  HTConsole:MessageListenerRQA(prefix, msg, channel, sender) -- "Raid Queue Announcement"
  HTConsole:MessageListenerREA(prefix, msg, channel, sender) -- "Raid Ended Announcement"
  HTConsole:MessageListenerAVB(prefix, msg, channel, sender) -- "Addon Version Broadcast"
  HTConsole:MessageListenerAVQ(prefix, msg, channel, sender) -- "Addon Version Query"
  HTConsole:MessageListenerRMS(prefix, msg, channel, sender) -- "Recruitment Message Sent"

end

-- ============================================================================
-- == ZONE_CHANGED_NEW_AREA()                                                ==
-- ==                                                                        ==
-- == This function performs actions when the player moves between major     ==
-- == zones or into/out-of dungeons and instances.                           ==
-- ============================================================================

function HTConsole:ZONE_CHANGED_NEW_AREA()

  if HTConfig:GetIsEnabledRecruitmentMessageSender(nil) == true then
    if HTConfig:GetIsEnabledRMSBroadcastOnZoneChanged(nil) == true then

      -- Advertising in party and raid zones is frowned upon therefore DO NOT
      -- broadcast if the player is currently in a party or raid; the one reliable
      -- requirement for entering ANY party or raid zone.
      if HTConsole:IsRMSBroadcastDisabled() then return end

      -- local rmsChannelName = HTConsole:GetRMSChannelNameByNumber(HTConsole:GetRMSChannelNumber())
      local rmsChannelName = GetRealZoneText()

      -- We want to avoid spamming a single channel too often due to the eager
      -- firing of the zone change event. Therefore, we limit our announcements
      -- to when we've moved such that the name of the output channel changes.
      -- E.g.: "General - Stormwind", "General - Elwynn Forest" etc.
      if rmsChannelName == HTConfig:GetRecruitmentZoneName(nil) then return end

      HTConfig:SetRecruitmentZoneName(rmsChannelName, rmsChannelName)
      self:ScheduleTimer("ForceBroadcastMessageRMS", 5)

      HTConsole:Debug("[RMS] - [ZONE_CHANGED_NEW_AREA] - Broadcast scheduled for 5 seconds from now.")

    end
  end

end

-- ============================================================================
-- == MessageListenerRIA(prefix, msg, channel, sender)                       ==
-- ==                                                                        ==
-- == This function checks the supplied prefix value to determine whether    ==
-- == the addon-message was a raid invitation and forms a suitable response  ==
-- == if it was.                                                             ==
-- ==                                                                        ==
-- == Prefix Code: HTRIA                                                     ==
-- == Description: HalonaTools Raid Invitation Announcement.                 ==
-- == Message fmt: "characterName"                                           ==
-- ============================================================================

function HTConsole:MessageListenerRIA(prefix, msg, channel, sender)

  -- Check whether this addon message is a raid invitation announcement.
  if prefix ~= L["con-addonmessage-prefix-htria"] then
    return
  end

  -- Check whether the raid invitation announcement message is ignorable.
  if HTConsole:IsIgnorableMessageRIA(sender) then
    return
  end

  -- Okay, all checks passed. We need to respond to the RIA message received.
  HTGUI:PopupAskRequestRaidInvitation(msg, sender)

end

-- ============================================================================
-- == IsIgnorableMessageRIA(sender)                                          ==
-- ==                                                                        ==
-- == This function determines whether a raid invitation announcement (RIA)  ==
-- == should be ignored. Conditions under which an RIA should be ignored     ==
-- == are:                                                                   ==
-- ==                                                                        ==
-- == 1: The player is already in a party.                                   ==
-- == 2: The player is already in a raid.                                    ==
-- == 3: The player who sent the message is... YOU!                          ==
-- == 4: The player has configured HalonaTools not to respond to RIAs.       ==
-- ============================================================================

function HTConsole:IsIgnorableMessageRIA(sender)

  if HTCommon:IsPlayerInParty() then return true end
  if HTCommon:IsPlayerInRaid()  then return true end
  if HTCommon:IsMe(sender)      then return true end
  if not HTConfig:GetIsEnabledAutoRIAResponse(nil) then return true end

  return false

end

-- ============================================================================
-- == MessageListenerRQA(prefix, msg, channel, sender)                       ==
-- ==                                                                        ==
-- == This function checks the supplied prefix value to determine whether    ==
-- == the addon-message was a raid invitation and forms a suitable response  ==
-- == if it was.                                                             ==
-- ==                                                                        ==
-- == Prefix Code: HTRQA                                                     ==
-- == Description: HalonaTools Raid Queue Announcement.                      ==
-- == Message fmt: "characterName"                                           ==
-- ============================================================================

function HTConsole:MessageListenerRQA(prefix, msg, channel, sender)

  -- Check whether this addon message is a raid queue announcement.
  if prefix ~= L["con-addonmessage-prefix-htrqa"] then
    return
  end

  -- Check whether the raid invitation announcement message is ignorable.
  if HTConsole:IsIgnorableMessageRQA(sender) then
    return
  end

  -- Okay, all checks passed. We need to respond to the RQA message received.
  HTGUI:PopupAskRequestRaidQueueListing(msg, sender)

end

-- ============================================================================
-- == IsIgnorableMessageRQA(sender)                                          ==
-- ==                                                                        ==
-- == This function determines whether a raid queue announcement (RQA)       ==
-- == should be ignored. Conditions under which an RQA should be ignored     ==
-- == are:                                                                   ==
-- ==                                                                        ==
-- == 1: The player is already in a party.                                   ==
-- == 2: The player is already in a raid.                                    ==
-- == 3: The player who sent the message is... YOU!                          ==
-- == 4: The player has configured HalonaTools not to respond to RQAs.       ==
-- ============================================================================

function HTConsole:IsIgnorableMessageRQA(sender)

  if HTCommon:IsPlayerInParty() then return true end
  if HTCommon:IsPlayerInRaid()  then return true end
  if HTCommon:IsMe(sender)      then return true end
  if not HTConfig:GetIsEnabledAutoRQAResponse(nil) then return true end

  return false

end

-- ============================================================================
-- == MessageListenerREA(prefix, msg, channel, sender)                       ==
-- ==                                                                        ==
-- == This function checks the supplied prefix value to determine whether    ==
-- == the addon-message was a raid end announcement and performs appropriate ==
-- == raid-end tasks if it was.                                              ==
-- ==                                                                        ==
-- == Prefix Code: HTREA                                                     ==
-- == Description: HalonaTools Raid End Announcement.                        ==
-- == Message fmt: "characterName"                                           ==
-- ============================================================================

function HTConsole:MessageListenerREA(prefix, msg, channel, sender)

  -- Check whether this addon message is a raid invitation announcement.
  if prefix ~= L["con-addonmessage-prefix-htrea"] then
    return
  end

  -- Nothing to do at this time.
  -- HTConsole:Debug("Raid End Announcement detected.")

end

-- ============================================================================
-- == MessageListenerAVB(prefix, msg, channel, sender)                       ==
-- ==                                                                        ==
-- == This function checks the supplied prefix value to determine whether    ==
-- == the addon-message was an addon version broadcast. Such broadcasts are  ==
-- == sent in response to an addon version query or automatically when the   ==
-- == user logs into the game or reloads their UI. When an 'AVB' is detected ==
-- == this function updates the table of stored 'versions' data with the new ==
-- == data received in the broadcast message and the table of HT users.      ==
-- ==                                                                        ==
-- == Prefix Code: HTAVB                                                     ==
-- == Description: HalonaTools Addon Version Broadcast.                      ==
-- == Message fmt: "versionName::versionNumber"                              ==
-- ============================================================================

function HTConsole:MessageListenerAVB(prefix, msg, channel, sender)

  -- HTConsole:Debug("AVB message received from ["..sender.."] containing message ["..msg.."].")

  -- Check whether this addon message is an addon version broadcast.
  if prefix ~= L["con-addonmessage-prefix-htavb"] then
    return
  end

  HTConsole:UpdateHTUsers(msg, sender)
  HTConsole:UpdateVersions(msg, sender)

end

-- ============================================================================
-- == UpdateHTUsers(msg, sender)                                             ==
-- ==                                                                        ==
-- == This function updates the 'htUsers' table with the data supplied via   ==
-- == the Addon Version Broadcast message parameter supplied as input.       ==
-- ============================================================================

function HTConsole:UpdateHTUsers(msg, sender)

  -- Configure local variables.

  -- Iterate through the existing records.
  -- For each record, break down into name, versionName, versionNumber parts.
  -- If name = sender, replace record in case version details have changed.
  -- If name is not in list, add name record to list.

  local args                   = HTData:StringSplit(msg, L["all-text-separator"])
  local broadcastCharacterName = sender
  local broadcastVersionName   = args[1]
  local broadcastVersionNumber = args[2]
  local broadcastRecord        = broadcastCharacterName .. L["all-text-separator"] .. broadcastVersionName .. L["all-text-separator"] .. broadcastVersionNumber
  local updateMade             = false
  local currentHTUsersTable    = htUsers
  local newHTUsersTable        = {}

  -- If no addon version records currently exist, simply add the broadcast
  -- record to the table, otherwise loop through the records in the existing
  -- table. For each existing record, we simply copy it to the new table if it
  -- does not belong to the sender of the broadcast record or replace it if
  -- its owner matches the sender of the broadcast record.
  if #currentHTUsersTable == 0 then
    table.insert(newHTUsersTable, broadcastRecord)
    updateMade = true
  else
    for i,v in ipairs(currentHTUsersTable) do
      local thisArgs = HTData:StringSplit(v, L["all-text-separator"])
      local thisCharacterName = thisArgs[1]
      local thisVersionName   = thisArgs[2]
      local thisVersionNumber = thisArgs[3]

      if thisCharacterName == broadcastCharacterName then
        table.insert(newHTUsersTable, broadcastRecord)
        updateMade = true
      else
        table.insert(newHTUsersTable, v)
      end
    end
  end

  -- If we have not been able to match a record in the existing table, we need
  -- to simply add the broadcast record to the table.
  if not updateMade then
    table.insert(newHTUsersTable, broadcastRecord)
    updateMade = true
  end

  -- The broadcast record has been processed. Now we simply need to save the
  -- updated(new) table in place of the old table.
  htUsers = newHTUsersTable

end

-- ============================================================================
-- == UpdateVersions(msg, sender)                                            ==
-- ==                                                                        ==
-- == This function updates the 'versions' table with the data supplied via  ==
-- == the Addon Version Broadcast message parameter supplied as input.       ==
-- ============================================================================

function HTConsole:UpdateVersions(msg, sender)

  -- Extract the details of the message from the addon version broadcast.
  local args                   = HTData:StringSplit(msg, L["all-text-separator"])
  local broadcastCharacterName = sender
  local broadcastVersionName   = args[1]
  local broadcastVersionNumber = args[2]
  local broadcastRecord        = broadcastCharacterName .. L["all-text-separator"] .. broadcastVersionName .. L["all-text-separator"] .. broadcastVersionNumber
  local updateMade             = false
  local currentVersionsTable   = versions
  local newVersionsTable       = {}

  -- Check whether this is a newer version of HT than this user has.
  HTConsole:OldVersionCheck(broadcastVersionName, broadcastVersionNumber)

  -- If no addon version records currently exist, simply add the broadcast
  -- record to the table, otherwise loop through the records in the existing
  -- table. For each existing record, we simply copy it to the new table if it
  -- does not belong to the sender of the broadcast record or replace it if
  -- its owner matches the sender of the broadcast record.
  if #currentVersionsTable == 0 then
    table.insert(newVersionsTable, broadcastRecord)
    updateMade = true
  else
    for i,v in ipairs(currentVersionsTable) do
      local thisArgs = HTData:StringSplit(v, L["all-text-separator"])
      local thisCharacterName = thisArgs[1]
      local thisVersionName   = thisArgs[2]
      local thisVersionNumber = thisArgs[3]

      if thisCharacterName == broadcastCharacterName then
        table.insert(newVersionsTable, broadcastRecord)
        updateMade = true
      else
        table.insert(newVersionsTable, v)
      end
    end
  end

  -- If we have not been able to match a record in the existing table, we need
  -- to simply add the broadcast record to the table.
  if not updateMade then
    table.insert(newVersionsTable, broadcastRecord)
    updateMade = true
  end

  -- The broadcast record has been processed. Now we simply need to save the
  -- updated(new) table in place of the old table.
  versions = newVersionsTable

end

-- ============================================================================
-- == OldVersionCheck(versionName, versionNumber)                            ==
-- ==                                                                        ==
-- == This function checks if the user wishes to receive alerts when a newer ==
-- == version of the addon is detected. If they do, a check is performed to  ==
-- == determine if the addon version seen is newer. If it is newer, one      ==
-- == further check is made to determine whether the user has previously     ==
-- == been alerted about the existence of the specified version. If no       ==
-- == previous alert has been delivered, the user is alerted.                ==
-- ============================================================================

function HTConsole:OldVersionCheck(versionName, versionNumber)

  if HTConfig:GetIsEnabledAlertNewAddonVersion(nil) then

    local currentVersionName   = L["addon-version-name"]
    local currentVersionNumber = L["addon-version-number"]
    local maxVersionNumber     = HTConfig:GetMaxAddonVersionSeen(nil)

    if tonumber(versionNumber) > tonumber(currentVersionNumber) then
      if tonumber(versionNumber) > tonumber(maxVersionNumber) then

        -- Do Alert.
        local oldVersionText = string.gsub(L["con-ht-ovc-msg-02"], "WHOSE_VERSION", L["con-ht-ovc-msg-your"])
        local oldVersionText = string.gsub(oldVersionText, "VERSION_NAME", currentVersionName)
        local oldVersionText = string.gsub(oldVersionText, "VERSION_NUMBER", currentVersionNumber)

        local newVersionText = string.gsub(L["con-ht-ovc-msg-02"], "WHOSE_VERSION", L["con-ht-ovc-msg-new"])
        local newVersionText = string.gsub(newVersionText, "VERSION_NAME", versionName)
        local newVersionText = string.gsub(newVersionText, "VERSION_NUMBER", versionNumber)

        HTConsole:SendChatMessage(L["con-ht-ovc-title"], "CHAT", nil, nil)
        HTConsole:SendChatMessage(L["con-ht-ovc-msg-01"], "CHAT", nil, nil)
        HTConsole:SendChatMessage(oldVersionText, "CHAT", nil, nil)
        HTConsole:SendChatMessage(newVersionText, "CHAT", nil, nil)

        -- Update maxVersion.
        HTConfig:SetMaxAddonVersionSeen(" ", versionNumber)
      end
    end
  end
end

-- ============================================================================
-- == GetMaxVersionName()                                                    ==
-- ==                                                                        ==
-- == This function determines the name of the highest numbered version of   ==
-- == the addon currently logged within the versions table. The default      ==
-- == version number is the number of this instance of the addon. If any     ==
-- == entry in the versions table has a higher version number, this entry    ==
-- == becomes the highest known version. Once processing concludes, the      ==
-- == name of the highest numbered version is returned.                      ==
-- ============================================================================

function HTConsole:GetMaxVersionName()

  local maxVersionName   = L["addon-version-name"]
  local maxVersionNumber = L["addon-version-number"]

  -- Determine the max version number currently visible.
  for i,v in ipairs(versions) do

    local args = HTData:StringSplit(v, L["all-text-separator"])

    local currentUsername      = args[1]
    local currentVersionName   = args[2]
    local currentVersionNumber = args[3]

    if currentVersionNumber > maxVersionNumber then
      maxVersionNumber = currentVersionNumber
      maxVersionName   = currentVersionName
    end
  end

  return maxVersionName

end

-- ============================================================================
-- == GetMaxVersionNumber()                                                  ==
-- ==                                                                        ==
-- == This function determines the number of the highest numbered version of ==
-- == the addon currently logged within the versions table. The default      ==
-- == version number is the number of this instance of the addon. If any     ==
-- == entry in the versions table has a higher version number, this entry    ==
-- == becomes the highest known version. Once processing concludes, the      ==
-- == number of the highest numbered version is returned.                    ==
-- ============================================================================

function HTConsole:GetMaxVersionNumber()

  local maxVersionName   = L["addon-version-name"]
  local maxVersionNumber = L["addon-version-number"]

  -- Determine the max version number currently visible.
  for i,v in ipairs(versions) do

    local args = HTData:StringSplit(v, L["all-text-separator"])

    local currentUsername      = args[1]
    local currentVersionName   = args[2]
    local currentVersionNumber = args[3]

    if currentVersionNumber > maxVersionNumber then
      maxVersionNumber = currentVersionNumber
      maxVersionName   = currentVersionName
    end
  end

  return maxVersionNumber

end

-- ============================================================================
-- == GetHTUserData(dataType)                                                ==
-- ==                                                                        ==
-- == This function provides an accessor for data about the users of HT      ==
-- == within the guild the user is a member of. The call to this function    ==
-- == includes a dataType parameter, a simple string, informing the function ==
-- == which data-table the calling code wishes to receive. Options include:  ==
-- ==                                                                        ==
-- == "HT_USERDATA_TYPE_CURRENT"        - List of users with current HT.     ==
-- == "HT_USERDATA_TYPE_OLD"            - List of users with out-of-date HT. ==
-- == "HT_USERDATA_TYPE_ANY"            - List of users with any HT.         ==
-- == "HT_USERDATA_TYPE_NONE"           - List of users with no HT.          ==
-- ============================================================================

function HTConsole:GetHTUserData(dataType)

  local currentVersions     = versions
  local userDataTypeNone    = {}
  local userDataTypeOld     = {}
  local userDataTypeCurrent = {}
  local userDataTypeAny     = {}
  local maxVersionName      = HTConsole:GetMaxVersionName()
  local maxVersionNumber    = HTConsole:GetMaxVersionNumber()

  -- Process currentVersions table.
  for i,v in ipairs(versions) do

    local args = HTData:StringSplit(v, L["all-text-separator"])

    local currentUsername      = args[1]
    local currentVersionName   = args[2]
    local currentVersionNumber = args[3]

    if currentVersionNumber == maxVersionNumber then
      table.insert(userDataTypeCurrent, currentUsername)
      table.insert(userDataTypeAny, currentUsername)
    else
      table.insert(userDataTypeOld, currentUsername)
      table.insert(userDataTypeAny, currentUsername)
    end
  end

  -- Process all online members, looking for those online without HT installed.
  totalNumberOfGuildMembers = GetNumGuildMembers(true)

  for index=1, totalNumberOfGuildMembers, 1 do
    name, rank, rankIndex, level, class, zone, note, officernote, online, status = GetGuildRosterInfo(index)

    if online == 1 then
      if not HTData:IsInTable(userDataTypeAny, name) then
        table.insert(userDataTypeNone, name)
      end
    end

  end

  -- Now, return whichever data-type table the user requested.
  if     dataType == L["con-ht-userdata-type-current"] then
    return userDataTypeCurrent
  elseif dataType == L["con-ht-userdata-type-old"] then
    return userDataTypeOld
  elseif dataType == L["con-ht-userdata-type-any"] then
    return userDataTypeAny
  elseif dataType == L["con-ht-userdata-type-none"] then
    return userDataTypeNone
  else
    return nil
  end

end

-- ============================================================================
-- == GetVersions()                                                          ==
-- ==                                                                        ==
-- == This function provides a simple accessor for the named property.       ==
-- ============================================================================

function HTConsole:GetVersions()
  return versions
end

-- ============================================================================
-- == MessageListenerAVQ(prefix, msg, channel, sender)                       ==
-- ==                                                                        ==
-- == This function checks the supplied prefix value to determine whether    ==
-- == the addon-message was an addon version query. Such broadcasts are      ==
-- == sent when one user wishes to get an updated list of the versions of    ==
-- == this addon currently being used by members of his/her guild.           ==
-- == When an 'AVQ' is received, a broadcast is sent out informing other HT  ==
-- == users of this user's version of HT.                                    ==
-- ==                                                                        ==
-- == Prefix Code: HTAVQ                                                     ==
-- == Description: HalonaTools Addon Version Query.                          ==
-- == Message fmt: "{optional, no fixed format}"                             ==
-- ============================================================================

function HTConsole:MessageListenerAVQ(prefix, msg, channel, sender)

  -- Check whether this addon message is an addon version query.
  if prefix ~= L["con-addonmessage-prefix-htavq"] then
    return
  end

  HTConsole:BroadcastMessageAVB()

end

-- ============================================================================
-- == BroadcastMessageAVB()                                                  ==
-- ==                                                                        ==
-- == This function broadcasts a message over the addon channel. The message ==
-- == contains details of the version of HT that this user is using.         ==
-- ============================================================================

function HTConsole:BroadcastMessageAVB()

  local avbMessage = L["addon-version-name"] .. L["all-text-separator"] .. L["addon-version-number"]
  local prefix     = L["con-addonmessage-prefix-htavb"]

  SendAddonMessage(prefix, avbMessage, "GUILD")

end

-- ============================================================================
-- == BroadcastMessageAVQ()                                                  ==
-- ==                                                                        ==
-- == This function broadcasts a message over the addon channel. The message ==
-- == contains details of the version of HT that this user is using.         ==
-- ==                                                                        ==
-- == There is no requirement for the AVQ message to contain a message       ==
-- == payload but any message passed to this function will be used as this   ==
-- == broadcast's message data. This will allow calling code to refine the   ==
-- == outgoing message, offering the opportunity for receving code to make   ==
-- == differentiations between (say) queries sent out by differing           ==
-- == mechanisms.                                                            ==
-- ============================================================================

function HTConsole:BroadcastMessageAVQ(messageText)

  local avqMessage = HTData:SafeString(messageText)
  local prefix     = L["con-addonmessage-prefix-htavq"]

  SendAddonMessage(prefix, avqMessage, "GUILD")

end

-- ============================================================================
-- == MessageListenerLogWhisperers(sender)                                   ==
-- ==                                                                        ==
-- == This function simply logs the name of the sender in the 'whisperers'   ==
-- == table for later use/retrieval by other components.                     ==
-- ============================================================================

function HTConsole:MessageListenerLogWhisperers(sender)

  if HTData:IsInTable(whisperers, sender) == false then
    table.insert(whisperers, sender)
  end

end

-- ============================================================================
-- == GetWhisperers()                                                        ==
-- ==                                                                        ==
-- == This function simply returns the whisperers table.                     ==
-- ============================================================================

function HTConsole:GetWhisperers()

  return whisperers

end

-- ============================================================================
-- == TrimWhisperers(maxSize)                                                ==
-- ==                                                                        ==
-- == This function simply trims the whisperers table to a maximum size.     ==
-- ============================================================================

function HTConsole:TrimWhisperers(maxSize)

  local newTable = {}

  -- Attempt to trim the first X records from the table if over-sized.
  if #whisperers > maxSize then
    local limit = tonumber(#whisperers) - tonumber(maxSize)
    for i = 1, limit do
      table.remove(whisperers, i)
    end
  end

  -- Copy table contents to new table, helps reset the indexing.
  for i,v in ipairs(whisperers) do
    table.insert(newTable, v)
  end

  whisperers = newTable

end

-- ============================================================================
-- == GuildInvite(characterName)                                             ==
-- ==                                                                        ==
-- == This function invites the named character to join the guild.           ==
-- ============================================================================

function HTConsole:GuildInvite(characterName)

  -- TODO: Announce invitation to guild, asking them to welcome new member.
  -- TODO: Automatically set rank, notes etc. (Requires invitation-processor.)
  -- GuildInvite(characterName)
  HTConsole:GuildInviteTrialMember(characterName)

end

-- ============================================================================
-- == GuildInviteTrialMember(characterName)                                  ==
-- ==                                                                        ==
-- == This function invites the named character to join the guild.           ==
-- ============================================================================

function HTConsole:GuildInviteTrialMember(characterName)

  local mainTrialRankName  = HTCommon:GetLowestMainTrialRankName()
  local mainTrialRankIndex = HTCommon:GetGuildRankIndexByName(mainTrialRankName)
  local newGuildInvite     = characterName .. L["all-text-separator"] .. mainTrialRankIndex

  guildInvites = HTData:AddValue(guildInvites, newGuildInvite, true)

  GuildInvite(characterName)

end

-- ============================================================================
-- == MessageListenerGuildInvitations(msg)                                   ==
-- ==                                                                        ==
-- == This function checks the supplied 'msg' text for confirmation of an    ==
-- == accepted guild invitation and initiates post-join processing for that  ==
-- == new guild member.                                                      ==
-- ==                                                                        ==
-- == Example: Mickeymouse has joined the guild.                             ==
-- ============================================================================

function HTConsole:MessageListenerGuildInvitations(msg)

  local templateWords = HTData:StringSplit(L["con-ginvite-has-joined-the-guild"], " ")
  local messageWords  = HTData:StringSplit(msg, " ")

  -- Stop processing if the word-count values do not match.
  if (#templateWords + 1) ~= #messageWords then return end

  -- Attempt to match the message against the guildInvites candidates.
  for i,v in ipairs(guildInvites) do

    local guildInviteFields = HTData:StringSplit(v, L["all-text-separator"])
    local invitedName       = guildInviteFields[1]
    local invitedRankIndex  = guildInviteFields[2]
    local expectedMessage   = invitedName .. L["con-ginvite-has-joined-the-guild"]

    if msg == expectedMessage then
      local invitedRosterIndex = HTCommon:GetGuildRosterIndexByName(invitedName)
      SetGuildMemberRank(invitedRosterIndex, invitedRankIndex)

      local officerNote = L["con-ginvite-trial-officer-note"] .. date("%Y.%m.%d")
      HTCommon:SetCharacterOfficerNote(invitedName, officerNote)

      -- TODO: Whisper player forum address, advise to register using in-game name.
      -- TODO: Welcome new guild member in guild channel to alert members.
      guildInvites = HTData:RemoveValue(guildInvites, msg)
      break
    end

  end

end

-- ============================================================================
-- == MessageListenerAutoInvitations(msg, sender)                            ==
-- ==                                                                        ==
-- == This function checks the supplied 'msg' text for a recognised request  ==
-- == for a group invitation and sends one automatically when one is found.  ==
-- ============================================================================

function HTConsole:MessageListenerAutoInvitations(msg, sender)

  -- == -----------------------------------------------------------------------
  -- == -- Check if the sender was requesting an invite.                     --
  -- == -----------------------------------------------------------------------
  if HTConsole:IsInvitationKeyword(string.lower(msg)) and HTConfig:GetIsEnabledAutoInvitations(nil) then

    -- Check if guild-only invites are wanted. If so, verify user is a guild member.
    if HTConfig:GetIsEnabledAutoInvitationsGuildOnly(nil) == true then
      if HTCommon:IsCharacterInGuild(HTCommon:UnitName(sender)) == false then return end
    end

    -- Place quick call to AutoConvertToRaid in case such actions are necessary.
    HTConsole:DoAutoConvertToRaid()

    HTConsole:SendChatMessage(L["con-autoinvitations-msg-01"]  , "WHISPER", nil, sender)
    HTConsole:ExecuteChatCommand(L["con-autoinvitations-cmd-01"]..sender)

  end

end

-- ============================================================================
-- == DoAutoConvertToRaid()                                                  ==
-- ==                                                                        ==
-- == This function attempts to automatically convert the player's current   ==
-- == party into a raid. Some criteria must be satisfied before the          ==
-- == conversion attempt is made as follows:                                 ==
-- ==                                                                        ==
-- == -> Player is NOT already in a raid.                                    ==
-- == -> Player IS in a party.                                               ==
-- == -> Guild Play Mode is "Invites".                                       ==
-- ============================================================================

function HTConsole:DoAutoConvertToRaid()

  -- Return immediately if player is already in a raid group.
  if HTCommon:IsPlayerInRaid() then return end

  -- Return immediately if the auto-convert-to-raid is not enabled.


  -- Player will not be in party until at least one invitee joins.
  -- Only auto-convert to raid if the guild's playmode is 'invites'.
  if HTCommon:IsPlayerInParty() and HTCommon:GetCurrentGuildPlayMode() == L["cmn-guild-playmode-invites"] then
    HTConsole:SendChatMessage(L["con-auto-raid-conversion-msg-01"], "CHAT", nil, nil)
    ConvertToRaid()
  end

end

-- ============================================================================
-- == IsInvitationKeyword(msg)                                               ==
-- ==                                                                        ==
-- == This function checks the supplied 'msg' text to determine if it        ==
-- == matches one of the recognised invitation keywords.                     ==
-- ============================================================================

function HTConsole:IsInvitationKeyword(msg)

  if msg == L["con-autoinvitations-keyword-01"]
  or msg == L["con-autoinvitations-keyword-02"] then
    return true
  else
    return false
  end

end

-- ============================================================================
-- == MessageListenerARP(msg)                                                ==
-- ==                                                                        ==
-- == This function will attempt to automatically promote members joining a  ==
-- == raid group to assistant status if certain criteria are met:            ==
-- ==                                                                        ==
-- == - The auto-promotions feature is enabled.                              ==
-- == - This player is the raid leader.                                      ==
-- == - The player joining the raid has an officer-class guild rank.         ==
-- ============================================================================

function HTConsole:MessageListenerARP(msg)

  -- Check feature is enabled and player is raid leader, return if either is false.
  if not HTConfig:GetIsEnabledAutoRaidPromotions(nil) then return end

  -- If the system message was of the form "{playername} has joined the raid group"...
  if string.match(msg, L["con-autoraidpromotions-system-msg-01"]) then
    -- Pause for a few seconds to ensure the server has updated.
    self:ScheduleTimer("DoAllRaidPromotions", 10)
  end

end

-- ============================================================================
-- == DoAllRaidPromotions()                                                  ==
-- ==                                                                        ==
-- == This function will attempt to automatically promote any members of a   ==
-- == raid group to assistant status if certain criteria are met:            ==
-- ==                                                                        ==
-- == - This player is the raid leader.                                      ==
-- == - The raid member holds an officer-class guild rank.                   ==
-- == - The raid member has the role of 'TANK' assigned to them.             ==
-- ============================================================================

function HTConsole:DoAllRaidPromotions()

  -- Return immediately if the player is not in a raid.
  if not HTCommon:IsPlayerInRaid() then return end

  -- Return immediately if the player is not the raid leader. Only the raid
  -- leader can promote other players.
  if not HTCommon:IsCharacterRaidLeader(UnitName("player")) then return end

  for i = 1, GetNumGroupMembers() do
    local name, rank, subgroup, level, class, fileName, zone, online, isDead, role, isML = GetRaidRosterInfo(i)

    local raidMember      = HTData:SafeString(name)
    local raidRank        = HTData:SafeNumber(rank)
    local raidRole        = HTData:SafeString(UnitGroupRolesAssigned(raidMember))
    local hasBeenPromoted = false

    -- Attempt to promote all officer-ranked characters to raid assistant.
    if not HTCommon:IsMe(raidMember) then
      if HTCommon:IsOfficer(raidMember) then
        if tonumber(raidRank) == tonumber("0") then
          -- HTConsole:Debug("Attempting to promote "..raidMember.." to assistant status.")
          HTConsole:SendChatMessage(L["con-autoraidpromotions-msg-01"], "WHISPER", nil, raidMember)
          HTConsole:SendChatMessage(string.gsub(L["con-autoraidpromotions-msg-02"], "CHARACTER_NAME", raidMember), "CHAT", nil, nil)
          PromoteToAssistant(raidMember)
          raidRank = "1"
        end
      end
    end

    -- Attempt to promote all raid-master-ranked characters to raid assistant.
    if not HTCommon:IsMe(raidMember) then
      if HTCommon:IsRaidMasterRankedCharacter(raidMember) then
        if tonumber(raidRank) == tonumber("0") then
          -- HTConsole:Debug("Attempting to promote "..raidMember.." to assistant status.")
          HTConsole:SendChatMessage(L["con-autoraidpromotions-msg-05"], "WHISPER", nil, raidMember)
          HTConsole:SendChatMessage(string.gsub(L["con-autoraidpromotions-msg-06"], "CHARACTER_NAME", raidMember), "CHAT", nil, nil)
          PromoteToAssistant(raidMember)
          raidRank = "1"
        end
      end
    end

    -- Attempt to promote all 'TANK' role characters to raid assistant. (Excludes trial members.)
    if string.lower(L["all-data-rolename-tank"]) == string.lower(raidRole) then
      if tonumber(raidRank) == tonumber("0") and HTCommon:IsTrialRankedCharacter(raidMember) == false then
        HTConsole:SendChatMessage(L["con-autoraidpromotions-msg-03"], "WHISPER", nil, raidMember)
        HTConsole:SendChatMessage(string.gsub(L["con-autoraidpromotions-msg-04"], "CHARACTER_NAME", raidMember), "CHAT", nil, nil)
        PromoteToAssistant(raidMember)
      end
    end

  end

end

-- ============================================================================
-- == MessageListenerAIR(msg, sender)                                        ==
-- ==                                                                        ==
-- == This function checks the supplied 'msg' text for a recognised request  ==
-- == for information and sends a suitable response where appropriate.       ==
-- ============================================================================

function HTConsole:MessageListenerAIR(msg, sender)

  -- == -----------------------------------------------------------------------
  -- == -- Check if the sender was requesting an invite.                     --
  -- == -----------------------------------------------------------------------
  if HTConsole:IsInfoKeyword(msg) then

    -- Info Request = "info"...
    if     string.lower(msg) == L["con-autoinforesponse-keyword-info"] then
      HTConsole:SendAutoInfoResponse(sender)

    -- Info Request = "info contactus"...
    elseif string.lower(msg) == L["con-autoinforesponse-keyword-contactus"] then
      HTConsole:SendAutoInfoContactUsResponse(sender)

    -- Info Request = "info guild"...
    elseif string.lower(msg) == L["con-autoinforesponse-keyword-guild"] then
      HTConsole:SendAutoInfoGuildResponse(sender)

    -- Info Request = "info officerlist"...
    elseif string.lower(msg) == L["con-autoinforesponse-keyword-officerlist"] then
      HTConsole:SendAutoInfoOfficerListResponse(sender)

    -- Info Request = "info raidtimes"...
    elseif string.lower(msg) == L["con-autoinforesponse-keyword-raidtimes"] then
      HTConsole:SendAutoInfoRaidTimesResponse(sender)

    -- Info Request = "info recruitment"...
    elseif string.lower(msg) == L["con-autoinforesponse-keyword-recruitment"] then
      HTConsole:SendAutoInfoRecruitmentResponse(sender)

    -- Info Request = "info zat"...
    elseif string.lower(msg) == L["con-autoinforesponse-keyword-zat"] then
      HTConsole:SendAutoInfoZATResponse(sender)

    -- Info Request = "no match to any of the above"...
    else
      HTConsole:SendChatMessage(L["con-autoinforesponse-msg-01"]  , "WHISPER", nil, sender)
    end

  end

end

-- ============================================================================
-- == IsInfoKeyword(msg)                                                     ==
-- ==                                                                        ==
-- == This function checks the supplied 'msg' text to determine if it        ==
-- == matches one of the recognised info keywords.                           ==
-- ============================================================================

function HTConsole:IsInfoKeyword(msg)

  if string.lower(msg) == L["con-autoinforesponse-keyword-info"]
  or string.lower(msg) == L["con-autoinforesponse-keyword-contactus"]
  or string.lower(msg) == L["con-autoinforesponse-keyword-guild"]
  or string.lower(msg) == L["con-autoinforesponse-keyword-officerlist"]
  or string.lower(msg) == L["con-autoinforesponse-keyword-raidtimes"]
  or string.lower(msg) == L["con-autoinforesponse-keyword-recruitment"]
  or string.lower(msg) == L["con-autoinforesponse-keyword-zat"] then
    return true
  else
    return false
  end

end

-- ============================================================================
-- == SendInfoMessage(infoTitle, messageText, sender)                        ==
-- ==                                                                        ==
-- == This function sends the messageText to the sender using the infoTitle  ==
-- == provided.                                                              ==
-- ============================================================================

function HTConsole:SendInfoMessage(infoTitle, messageText, sender)

  HTConsole:SendChatMessage(HTConsole:GetTitleBar(), "WHISPER", nil, sender)
  HTConsole:SendChatMessage(L["con-autoinforesponse-title-msg-01"] .. infoTitle, "WHISPER", nil, sender)
  HTConsole:SendChatMessage(HTConsole:GetTitleBar(), "WHISPER", nil, sender)
  HTConsole:SendChatMessage(" ", "WHISPER", nil, sender)
  HTConsole:SendWrappedMessage(messageText, "WHISPER", nil, sender)
  HTConsole:SendChatMessage(" ", "WHISPER", nil, sender)
  HTConsole:SendChatMessage(HTConsole:GetTitleBar(), "WHISPER", nil, sender)
  HTConsole:SendChatMessage(L["con-autoinforesponse-title-msg-01"] .. L["con-autoinforesponse-topics-msg-01"], "WHISPER", nil, sender)
  HTConsole:SendChatMessage(HTConsole:GetTitleBar(), "WHISPER", nil, sender)

end

-- ============================================================================
-- == SendAutoInfoResponse(sender)                                           ==
-- ==                                                                        ==
-- == This function sends the main topic list info to the sender.            ==
-- ============================================================================

function HTConsole:SendAutoInfoResponse(sender)

  HTConsole:SendInfoMessage(L["con-autoinforesponse-info-msg-01"], HTConfig:GetAirInfoMessage(nil), sender)

end

-- ============================================================================
-- == SendAutoInfoGuildResponse(sender)                                      ==
-- ==                                                                        ==
-- == This function sends the general guild info to the sender.              ==
-- ============================================================================

function HTConsole:SendAutoInfoGuildResponse(sender)

  HTConsole:SendInfoMessage(L["con-autoinforesponse-guild-msg-01"], HTConfig:GetAirGuildMessage(nil), sender)

end

-- ============================================================================
-- == SendAutoInfoOfficerListResponse(sender)                                ==
-- ==                                                                        ==
-- == This function sends officer list info to the sender.                   ==
-- ============================================================================

function HTConsole:SendAutoInfoOfficerListResponse(sender)

  local messageContent   = HTConfig:GetAirOfficerListMessage(nil)
  local guildOfficerList = HTCommon:GetGuildOfficerList()

  for i,v in ipairs(guildOfficerList) do

    if i > 1 then
      messageContent = messageContent .. ", "
    end

    messageContent = messageContent .. guildOfficerList[i]

  end

  HTConsole:SendInfoMessage(L["con-autoinforesponse-officerlist-msg-01"], messageContent, sender)

end

-- ============================================================================
-- == SendAutoInfoRaidTimesResponse(sender)                                  ==
-- ==                                                                        ==
-- == This function sends raid times info to the sender.                     ==
-- ============================================================================

function HTConsole:SendAutoInfoRaidTimesResponse(sender)

  HTConsole:SendInfoMessage(L["con-autoinforesponse-raidtimes-msg-01"], HTConfig:GetAirRaidTimesMessage(nil), sender)

end

-- ============================================================================
-- == SendAutoInfoRecruitmentResponse(sender)                                ==
-- ==                                                                        ==
-- == This function sends the recruitment info to the sender.                ==
-- ============================================================================

function HTConsole:SendAutoInfoRecruitmentResponse(sender)

  HTConsole:SendInfoMessage(L["con-autoinforesponse-recruitment-msg-01"], HTConfig:GetAirRecruitmentMessage(nil), sender)

end

-- ============================================================================
-- == SendAutoInfoContactUsResponse(sender)                                  ==
-- ==                                                                        ==
-- == This function sends the contact us info to the sender.                 ==
-- ============================================================================

function HTConsole:SendAutoInfoContactUsResponse(sender)

  HTConsole:SendInfoMessage(L["con-autoinforesponse-contactus-msg-01"], HTConfig:GetAirContactUsMessage(nil), sender)

end

-- ============================================================================
-- == SendAutoInfoZATResponse(sender)                                        ==
-- ==                                                                        ==
-- == This function sends the ZAT info to the sender.                        ==
-- ============================================================================

function HTConsole:SendAutoInfoZATResponse(sender)

  HTConsole:SendInfoMessage(L["con-autoinforesponse-zat-msg-01"], HTConfig:GetAirZatMessage(nil), sender)

end

-- ============================================================================
-- == MessageListenerRMS(prefix, msg, channel, sender)                       ==
-- ==                                                                        ==
-- == This function checks the supplied prefix value to determine whether    ==
-- == the addon-message was a recruitment message sending task notice.       ==
-- ==                                                                        ==
-- == The aim of this listener is to prevent multiple players from spamming  ==
-- == the same recruitment message too closely to each other. Therefore, if  ==
-- == the message came from another user in the same geographic location,    ==
-- == then this player's schedule timer should be restarted. If, for example,==
-- == all players had a timer of 15 mins, then this behaviour would force    ==
-- == each player's timer to begin to sync with their fellow members whilst  ==
-- == only allowing one person to be advertising within a zone.              ==
-- == As players who are recruiting logoff or move to another zone, other    ==
-- == players timers are permitted to expire and cause a new message to be   ==
-- == broadcast. At least... that's the plan.                                ==
-- ==                                                                        ==
-- == Prefix Code: HTRMS                                                     ==
-- == Description: HalonaTools Recruitment Message Sent                      ==
-- == Message fmt: "zoneText"                                                ==
-- ============================================================================

function HTConsole:MessageListenerRMS(prefix, msg, channel, sender)

  -- Check whether this addon message is a 'recruitment message sent' message.
  if prefix ~= L["con-addonmessage-prefix-htrms"] then
    return
  end

  if not HTCommon:IsMe(sender) then
    if msg == HTConsole:GetBroadcastZoneText() then
      self:CancelTimer(taskHandleRMS, true)
      HTConsole:ScheduleTaskRMS()
      -- HTConsole:Debug("HTConsole:MessageListenerRMS - Recruitment message broadcast by " .. sender .. " detected in the same zone you are currently in. Rescheduling your next broadcast to avoid over-spamming of channel.")
    end
  end

end

-- ============================================================================
-- == BroadcastMessageRMS()                                                  ==
-- ==                                                                        ==
-- == This function broadcasts a message over the addon channel. The message ==
-- == reports that a recruitment message has just been sent.                 ==
-- ============================================================================

function HTConsole:BroadcastMessageRMS()

  -- Invalidate the task-handle. (Protects "GetRMSTimer()" calls.)
  taskHandleRMS = L["con-rms-scheduled-timer-unset"]

  -- Advertising in party and raid zones is frowned upon therefore DO NOT
  -- broadcast if the player is currently in a party or raid; the one reliable
  -- requirement for entering ANY party or raid zone.
  if HTConsole:IsRMSBroadcastDisabled() then return end

  local rmsMessage   = HTConfig:GetRecruitmentMessage(nil)
  local addonMessage = HTConsole:GetBroadcastZoneText()
  local prefix       = L["con-addonmessage-prefix-htrms"]

  HTConsole:SendChannelMessage(rmsMessage, HTConsole:GetRMSChannelNumber())
  SendAddonMessage(prefix, addonMessage, "GUILD")
  HTConsole:ScheduleTaskRMS()

  HTConsole:Debug("[RMS] - [BroadcastMessageRMS] - Message broadcast.")

end

-- ============================================================================
-- == ForceBroadcastMessageRMS()                                             ==
-- ==                                                                        ==
-- == This function broadcasts a message over the addon channel. The message ==
-- == reports that a recruitment message has just been sent. Unlike the      ==
-- == similar function 'BroadcastMessageRMS' this function DOES NOT heed the ==
-- == protocols designed to prevent RMS messages being broadcast in certain  ==
-- == conditions. It is expected to be called via the user manually clicking ==
-- == on a "Forcibly send RMS message" type button, because sometimes the    ==
-- == user may wish to advertise whilst in a group etc knowing that to do so ==
-- == is not a problem.                                                      ==
-- ============================================================================

function HTConsole:ForceBroadcastMessageRMS()

  -- Invalidate the task-handle. (Protects "GetRMSTimer()" calls.)
  taskHandleRMS = L["con-rms-scheduled-timer-unset"]

  local rmsMessage   = HTConfig:GetRecruitmentMessage(nil)
  local addonMessage = HTConsole:GetBroadcastZoneText()
  local prefix       = L["con-addonmessage-prefix-htrms"]

  HTConsole:SendChannelMessage(rmsMessage, HTConsole:GetRMSChannelNumber())
  SendAddonMessage(prefix, addonMessage, "GUILD")
  HTConsole:ScheduleTaskRMS()

  HTConsole:Debug("[RMS] - [ForceBroadcastMessageRMS] - Message broadcast.")

end

-- ============================================================================
-- == ScheduleTaskRMS()                                                      ==
-- ==                                                                        ==
-- == This function schedules the BroadcastMessageRMS task.                  ==
-- ============================================================================

function HTConsole:ScheduleTaskRMS()

  -- Perform checks that might prevent this schedule from being set:
  -- 1: The feature has been disabled in the addon's config. settings.
  -- 2: The feature is 'guild locked' and the player is not currently in the
  --    preferred guild.
  if not HTConfig:GetIsEnabledRecruitmentMessageSender(nil) then return end
  if     HTConsole:IsLockedRMSGuildLock() then return end

  -- Okay, checks passed so schedule the next RMS broadcast.
  taskHandleRMS = self:ScheduleTimer("BroadcastMessageRMS", HTConfig:GetRecruitmentInterval(nil))

end

-- ============================================================================
-- == CancelTaskRMS()                                                        ==
-- ==                                                                        ==
-- == This function cancels the BroadcastMessageRMS task.                    ==
-- ============================================================================

function HTConsole:CancelTaskRMS()

  self:CancelTimer(taskHandleRMS, true)
  taskHandleRMS = L["con-rms-scheduled-timer-unset"]

end

-- ============================================================================
-- == JumpstartTaskRMS()                                                     ==
-- ==                                                                        ==
-- == When the player first logs into a server, it is possible that certain  ==
-- == Blizzard API calls will return incorrect responses. Example: A player  ==
-- == logs into WoW and an addon like this one calls the GetGuildName() API  ==
-- == function and receives the response "The player is not in a guild" when ==
-- == the player actually is in a guild.                                     ==
-- ==                                                                        ==
-- == This specific example, when it occurs, prevents the ScheduleTaskRMS()  ==
-- == function from being able to schedule the first broadcast of the guild  ==
-- == recruitment advert regardless of whether the player has enabled the    ==
-- == feature and met the requirements of the guild lock feature, if enabled.==
-- ==                                                                        ==
-- == This function will broadcast a recruitment message if the conditions   ==
-- == listed below are met. It can be called from the standard 'heartbeat'   ==
-- == function that is typically called every XX minutes for house-keeping   ==
-- == tasks such as this.                                                    ==
-- ==                                                                        ==
-- == 1: The RecruitmentMessageSender feature is enabled.                    ==
-- == 2: The Guild Lock feature is disabled OR is enabled and satisfied.     ==
-- == 3: The taskHandleRMS value is 'unset' indicating this error occurred.  ==
-- ============================================================================


function HTConsole:JumpstartTaskRMS()

  if HTConfig:GetIsEnabledRecruitmentMessageSender(nil) then
    if HTConsole:IsLockedRMSGuildLock() == false then
      if taskHandleRMS == L["con-rms-scheduled-timer-unset"] then
        HTConsole:BroadcastMessageRMS() -- Broadcasts message, then schedules next broadcast.
      end
    end
  end

end

-- ============================================================================
-- == GetRMSTimer()                                                          ==
-- ==                                                                        ==
-- == This function retrieves the current value of the RMS timer.            ==
-- ============================================================================

function HTConsole:GetRMSTimer()

  local timeInSeconds = "0.0"

  if HTConfig:GetIsEnabledRecruitmentMessageSender(nil) then
    if taskHandleRMS ~= L["con-rms-preferred-guild-unset"] then
      local timerValue = HTData:SafeNumber(self:TimeLeft(taskHandleRMS))
      local timerArgs  = HTData:StringSplit(timerValue, ".")
      timeInSeconds    = timerArgs[1]
    end
  end

  return timeInSeconds

end

-- ============================================================================
-- == ToggleRMSTimerHelper()                                                 ==
-- ==                                                                        ==
-- == This function ensures that the RMS timer obeys its current config.     ==
-- == setting.                                                               ==
-- ============================================================================

function HTConsole:ToggleRMSTimerHelper()

  if HTConfig:GetIsEnabledRecruitmentMessageSender(nil) then
    -- Timer is enabled, so we need to ensure it is activated.
    HTConsole:ScheduleTaskRMS()
  else
    HTConsole:CancelTaskRMS()
  end
end

-- ============================================================================
-- == UpdatePreferredRMSGuild()                                              ==
-- ==                                                                        ==
-- == This function updates the player's preferred RMS guild to their        ==
-- == current guild or to the default value if they are un-guilded.          ==
-- ============================================================================

function HTConsole:UpdatePreferredRMSGuild()

  local guildName     = HTCommon:GetGuildName()
  local preferredName = L["cfg-default-guild-name"]

  if guildName ~= L["cmn-guildname-unguilded"] then
    preferredName = guildName
  end

  HTConfig:SetPreferredRMSGuild(preferredName, preferredName)

end

-- ============================================================================
-- == IsRMSBroadcastDisabled()                                               ==
-- ==                                                                        ==
-- == This function performs checks to determine whether the broadcasting of ==
-- == RMS information should currently be disabled and returns true if       ==
-- == broadcasting should be disabled and false otherwise.                   ==
-- ==                                                                        ==
-- == Conditions that will cause broadcasting to be disabled:                ==
-- ==                                                                        ==
-- == - Player is in a group or raid. (Broadcasting inside party or raid     ==
-- ==   zones is frowned upon. Since being in a party or raid is a reliable  ==
-- ==   prerequisite for being in a party or raid zone, this is a simple way ==
-- ==   to prevent broadcasting that may annoy others. The false-positive of ==
-- ==   a player being in a party or raid but not in a party or raid zone is ==
-- ==   considered an acceptable and relatively limited consequence.)        ==
-- ============================================================================

function HTConsole:IsRMSBroadcastDisabled()

  if HTCommon:IsPlayerInParty() or HTCommon:IsPlayerInRaid() or HTConsole:IsLockedRMSGuildLock() == true then
    -- HTConsole:Debug(L["ldb-menu-item-debugfilter-rms-data-val"] .. " - IsRMSBroadcastDisabled() returns true.")
    return true
  end

  return false

end

-- ============================================================================
-- == IsLockedRMSGuildLock()                                                 ==
-- ==                                                                        ==
-- == This function determines whether the user has enabled the 'guild lock' ==
-- == feature which is intended to ensure that, when enabled, the addon will ==
-- == only send out recruitment messages when you are playing on a character ==
-- == that belongs to the guild you are advertising for. If the 'guild lock' ==
-- == is enabled, this function then checks whether the player's character   ==
-- == is in a guild that matches their preferred guild which is stored as a  ==
-- == config. value. NB: The player must at some point set their preferred   ==
-- == guild into the addon's config. before it will be possible for this     ==
-- == 'locking mechanism' to be able to unlock.                              ==
-- ============================================================================

function HTConsole:IsLockedRMSGuildLock()

  local isLocked = false

  if HTConfig:GetIsEnabledRMSGuildLocked(nil) then

    local guildName      = HTCommon:GetGuildName()
    local preferredGuild = HTConfig:GetPreferredRMSGuild(nil)

    -- Has the user EVER set a preferred guild. If not, the lock will be enabled.
    if preferredGuild == L["cfg-default-guild-name"] then
      isLocked = true
      HTConsole:Debug(L["con-rms-problem-notice-title"])
      HTConsole:Debug(L["con-rms-problem-guild-unset-msg"])
    end

    -- Is the user in the guild they wish to advertise for. If not, the lock will be enabled.
    if guildName ~= preferredGuild then
      isLocked = true
      HTConsole:Debug(L["con-rms-problem-notice-title"], "CHAT", nil, nil)
      HTConsole:Debug(string.gsub(L["con-rms-problem-wrong-guild-msg"], "PREFERRED_GUILD", preferredGuild))
    end

  end

  return isLocked

end

-- ============================================================================
-- == HTConsole:GetBroadcastZoneText()                                       ==
-- ==                                                                        ==
-- == This function returns the zone-text for the player's current location  ==
-- == but if the player is in a city, then a standard value is returned to   ==
-- == ensure that all city zones where the trade-channel is shared will be   ==
-- == considered to be the same effective zone for the purposes of RMS       ==
-- == broadcasting.                                                          ==
-- ============================================================================

function HTConsole:GetBroadcastZoneText()

  local tradeChannel   = HTConsole:GetTradeChannelNumber()
  local zoneText       = L["con-rms-zone-is-city"]

  -- If we are not in a city, then zoneText should be the actual zone text.
  if tonumber(tradeChannel) == tonumber(0) then
    zoneText = GetZoneText()
  end

  return zoneText

end

-- ============================================================================
-- == GetRMSChannelNumber()                                                  ==
-- ==                                                                        ==
-- == This function determines the number of the channel that should be used ==
-- == for sending 'Recruitment Message Sending' (aka: RMS) tasks. When       ==
-- == available, the Trade channel is preferred because it spans multiple    ==
-- == cities but if no trade channel is available, the local General channel ==
-- == is used instead.                                                       ==
-- ============================================================================

function HTConsole:GetRMSChannelNumber()

  local tradeChannel   = HTConsole:GetTradeChannelNumber()
  local generalChannel = HTConsole:GetGeneralChannelNumber()
  local rmsChannel     = generalChannel

  -- Set the rmsChannel to the tradeChannel if the tradeChannel is available.
  if tradeChannel ~= 0 then
    rmsChannel = tradeChannel
  end

  return rmsChannel

end

-- ============================================================================
-- == GetRMSChannelNameByNumber()                                            ==
-- ==                                                                        ==
-- == This function determines the of the name of the channel identified by  ==
-- == the channelNumber supplied. NB: This may not work if the Enumerate     ==
-- == function only indexes channels currently used (1,4,5,9 etc) instead of ==
-- == every channel regardless of assignment. (1,2,3,4,5... etc).            ==
-- ============================================================================

function HTConsole:GetRMSChannelNameByNumber(channel)

  local channelName = ""

  local allChannels   = { EnumerateServerChannels() }

  if allChannels[channel] then
    channelName = allChannels[channel]
  end

  return channelName

end

-- ============================================================================
-- == GetGeneralChannelNumber()                                              ==
-- ==                                                                        ==
-- == This function determines the number of a current 'General - XXX'       ==
-- == channel.                                                               ==
-- ============================================================================

function HTConsole:GetGeneralChannelNumber()

  local allChannels   = { EnumerateServerChannels() }
  local channelNumber = 0

  for i, v in ipairs(allChannels) do

    local channelNameParts = HTData:StringSplit(v, " ")
    local channelNameRoot  = channelNameParts[1]
    if channelNameRoot == L["con-channelname-root-general"] then
      channelNumber = i
    end
  end

  return channelNumber

end

-- ============================================================================
-- == GetTradeChannelNumber()                                                ==
-- ==                                                                        ==
-- == This function determines the number of a current 'Trade - XXX'         ==
-- == channel.                                                               ==
-- ============================================================================

function HTConsole:GetTradeChannelNumber()

  local allChannels   = { EnumerateServerChannels() }
  local channelNumber = 0

  for i, v in ipairs(allChannels) do

    local channelNameParts = HTData:StringSplit(v, " ")
    local channelNameRoot  = channelNameParts[1]
    if channelNameRoot == L["con-channelname-root-trade"] then
      channelNumber = i
    end
  end

  return channelNumber

end

-- ============================================================================
-- == GetChannelNumberByName(channelName)                                    ==
-- ==                                                                        ==
-- == This function determines the number of a chat channel specified by the ==
-- == supplied channel-name parameter.                                       ==
-- ============================================================================

function HTConsole:GetChannelNumberByName(channelName)

  local allChannels   = { EnumerateServerChannels() }
  local channelNumber = 0

  for i, v in ipairs(allChannels) do

    if v == channelName then
      channelNumber = i
    end
  end

  return channelNumber

end

-- ============================================================================
-- == MessageListenerBusyResponder(prefix, msg, channel, sender)             ==
-- ==                                                                        ==
-- == This function checks the supplied prefix value to determine whether    ==
-- == the received whisper-message was something HT needs to respond to on   ==
-- == behalf of the user via the busy responder functions.                   ==
-- ============================================================================

function HTConsole:MessageListenerBusyResponder(msg, sender)

  -- Return immediately if the busy responder is not currently enabled.
  if not HTConfig:GetIsEnabledBusyResponder(nil) then return end

  -- Return immediately if the message belongs to another HT function.
  if HTConsole:IsBRExemptByContent(msg, sender) then return end

  -- Return immediately if the busy responder config. exempts this sender.
  if HTConsole:IsBRExemptBySender(msg, sender) then return end

  -- Cool, no reason to delay further. Save the message.
  HTConsole:BusyResponderAddMessage(msg, sender)

end

-- ============================================================================
-- == BusyResponderAddMessage(msg, sender)                                   ==
-- ==                                                                        ==
-- == This function adds the details of the sender's message to the table    ==
-- == for later retrieval and reading.                                       ==
-- ============================================================================

function HTConsole:BusyResponderAddMessage(msg, sender)

  -- Build the record string. Each field is separated by "" so we replace ""
  -- by "-" in the actual message text to prevent issues later. (It is a rarely
  -- used character so should not cause undue problems in the context of
  -- whispered messages.)
  local messageText = HTData:GetTimeString() .. "" .. sender .. "" .. string.gsub(msg, "-", "")

  table.insert(messages, messageText)

  HTConsole:BusyResponderAddSender(sender)

  -- Update the text-label that other addons may display.
  HTBrokerSupport:BuildTextLabel()

end

-- ============================================================================
-- == BusyResponderAddSender(sender)                                         ==
-- ==                                                                        ==
-- == This function adds to the existing list of senders to determine        ==
-- == whether the sender had prviously been in contact and had therefore     ==
-- == already received the nominated response message.                       ==
-- ============================================================================

function HTConsole:BusyResponderAddSender(sender)

  local isAlreadyListed = false

  -- Examine the list of existing senders.
  for i,v in ipairs(senders) do

    if v == sender then

      isAlreadyListed = true

    end

  end

  -- If this sender is going to be new to the list then..
  if not isAlreadyListed then

    table.insert(senders, sender)

    HTConsole:SendChatMessage(HTConsole:GetBusyResponderMessage(), "WHISPER", nil, sender)

  end

end

-- ============================================================================
-- == GetBusyResponderMessage()                                              ==
-- ==                                                                        ==
-- == This function retrieves the out-going busy responder message.          ==
-- ============================================================================

function HTConsole:GetBusyResponderMessage()

    local outGoingMessage = HTConfig:GetBRMessageOutgoing(nil)
    outGoingMessage = string.gsub(outGoingMessage, "PLAYER_NAME", UnitName("player"))

    return outGoingMessage

end

-- ============================================================================
-- == IsBRExemptByContent(msg, sender)                                       ==
-- ==                                                                        ==
-- == This function performs a series of checks, seeking to detemine whether ==
-- == the supplied message is to be considered exempt from further BR        ==
-- == processing due to the message content.                                 ==
-- ============================================================================

function HTConsole:IsBRExemptByContent(msg, sender)

  -- Message matches the profile of an invitation request.
  if HTConsole:IsInvitationKeyword(msg) then return true end

  -- Message matches the profile of an information request enquiry.
  if HTConsole:IsInfoKeyword(string.lower(msg)) then return true end

  -- Message matches the profile of a "HalonaTools" message.
  if HTConsole:IsHTMessage(msg) then return true end

  -- Message is not exempt.
  return false

end

-- ============================================================================
-- == IsHTMessage(msg)                                                       ==
-- ==                                                                        ==
-- == This function determines whether the supplied message matches the form ==
-- == of a HalonaTools message.                                              ==
-- ============================================================================

function HTConsole:IsHTMessage(msg)

  if string.len(msg) > 4 then
    if string.sub(msg, 1, 4) == "[HT]" then
      return true
    end
  end

  return false

end

-- ============================================================================
-- == IsBRExemptBySender(msg, sender)                                        ==
-- ==                                                                        ==
-- == This function performs a series of checks, seeking to detemine whether ==
-- == the supplied message is to be considered exempt from further BR        ==
-- == processing due to the relationship of the sender to the player.        ==
-- ============================================================================

function HTConsole:IsBRExemptBySender(msg, sender)

  -- Guild Members allowed, sender is guild member.
  if HTConfig:GetIsGuildMemberAllowed(nil) and HTCommon:IsCharacterInGuild(sender) then return true end

  -- Guild Officers allowed, sender is guild officer.
  if HTConfig:GetIsGuildOfficerAllowed(nil) and HTCommon:IsOfficer(sender) then return true end

  -- Raid Members allowed, sender is raid member.
  if HTConfig:GetIsRaidMemberAllowed(nil) and HTCommon:IsCharacterInRaid(sender) then return true end

  -- Party Members allowed, sender is party member.
  if HTConfig:GetIsPartyMemberAllowed(nil) and HTCommon:IsCharacterInParty(sender) then return true end

  -- Friend allowed, sender is friend.
  if HTConfig:GetIsFriendAllowed(nil) and HTCommon:IsCharacterAFriend(sender) then return true end

  -- Real-ID friend allowed, sender is Real-ID friend.
  if HTConfig:GetIsRealIDFriendAllowed(nil) and HTCommon:IsCharacterARealIDFriend(sender) then return true end

  return false

end

-- ============================================================================
-- == BusyResponderShowMessages()                                            ==
-- ==                                                                        ==
-- == This function displays the messages stored since the BusyResponder     ==
-- == feature was activated.                                                 ==
-- ============================================================================

function HTConsole:BusyResponderShowMessages()

  if #messages < 1 then

    HTConsole:SendChatMessage(L["con-busy-responder-nosaved-msgs-title"], "CHAT", nil, nil)

  else

    HTConsole:SendChatMessage(L["con-busy-responder-saved-msgs-title"], "CHAT", nil, nil)

    -- Examine the list of existing senders.
    for i,v in ipairs(messages) do

      -- HTConsole:Debug("RawMessage=[" .. v .. "]")

      local msgArgs = HTData:StringSplit(v, "")
      local msgTime = msgArgs[1]
      local msgFrom = msgArgs[2]
      local msgText = msgArgs[3]

      -- HTConsole:Debug("msgTime=[" .. msgTime .. "]")
      -- HTConsole:Debug("msgFrom=[" .. msgFrom .. "]")
      -- HTConsole:Debug("msgText=[" .. msgText .. "]")

      local messageText = "|cffffff00[" .. msgTime .. "]|r "
      messageText = messageText .. "|cffff80ff[" .. msgFrom .. "]|r "
      messageText = messageText .. "|cffff80ff"  .. msgText .. "|r"

      HTConsole:SendChatMessage(messageText, "CHAT", nil, nil)

    end

    HTConsole:SendChatMessage(L["con-busy-responder-saved-msgs-end"], "CHAT", nil, nil)

  end

end

-- ============================================================================
-- == BusyResponderGetNumberOfMessagesStored()                               ==
-- ==                                                                        ==
-- == This function returns the number of messages that are currently stored ==
-- == by the busy responder.                                                 ==
-- ============================================================================

function HTConsole:BusyResponderGetNumberOfMessagesStored()

  local messagesStored = 0

  if messages then
    messagesStored = HTData:SafeNumber(#messages)
  end

  return messagesStored

end

-- ============================================================================
-- == BusyResponderClearMessages()                                           ==
-- ==                                                                        ==
-- == This function deletes all the messages stored since the BusyResponder  ==
-- == feature was activated.                                                 ==
-- ============================================================================

function HTConsole:BusyResponderClearMessages()

  HTConsole:SendChatMessage(L["con-busy-responder-clear-msgs-title"], "CHAT", nil, nil)

  messages = {}
  senders  = {}

  -- Update the text-label that other addons may display.
  HTBrokerSupport:BuildTextLabel()

end

-- ============================================================================
-- == BusyResponderAutoSelectProfile()                                       ==
-- ==                                                                        ==
-- == This function automatically selects the BR profile according to the    ==
-- == user's current activity status, if the auto-profile selection feature  ==
-- == is enabled.                                                            ==
-- ==                                                                        ==
-- == Selection conditions MAY override previous choices as the function is  ==
-- == processed. Thus, a DND user would be set to 'Busy' but if they are in  ==
-- == a raid then the 'Raiding' profile takes precedence. If during the raid ==
-- == the user goes AFK, then the 'Away' profile takes precedence over the   ==
-- == previous two states.                                                   ==
-- ============================================================================

function HTConsole:BusyResponderAutoSelectProfile()

  if HTConfig:GetIsEnabledBRAutoProfileSelect(nil) == true then

    -- Check 1: User is DND, should be in 'Busy' profile.
    if HTCommon:IsGuildMemberDND(UnitName("player")) == true then
      if HTConfig:GetBRProfileName(nil) ~= L["con-busy-responder-profile-name-busy"] then
        HTConsole:SendChatMessage(L["con-busy-responder-profile-autoselect"], "CHAT", nil, nil)
        HTConsole:BusyResponderSelectProfileBusy()
      end
    end

    -- Check 2: User is in raid, should be in 'Raiding' profile.
    if HTCommon:IsPlayerInRaid() == true then
      if not (HTConfig:GetBRProfileName(nil) == L["con-busy-responder-profile-name-raiding"]) then
        HTConsole:SendChatMessage(L["con-busy-responder-profile-autoselect"], "CHAT", nil, nil)
        HTConsole:BusyResponderSelectProfileRaiding()
      end
    end

    -- Check 3: User is AFK, should be in 'Away' profile.
    if HTCommon:IsGuildMemberAFK(UnitName("player")) == true then
      if not (HTConfig:GetBRProfileName(nil) == L["con-busy-responder-profile-name-away"]) then
        HTConsole:SendChatMessage(L["con-busy-responder-profile-autoselect"], "CHAT", nil, nil)
        HTConsole:BusyResponderSelectProfileAway()
      end
    end

  end

end

-- ============================================================================
-- == BusyResponderSelectProfileBusy()                                       ==
-- ==                                                                        ==
-- == This function selects the BR profile that indicates the user is busy.  ==
-- ============================================================================

function HTConsole:BusyResponderSelectProfileBusy()

  HTConsole:BusyResponderApplyProfile(HTConfig:GetBRProfileBusy(nil), L["con-busy-responder-profile-name-busy"])
  HTConfig:SetBRMessageOutgoing(L["con-busy-responder-out-msg-busy-01"], L["con-busy-responder-out-msg-busy-01"])
  HTConsole:SendChatMessage(HTConfig:GetBRMessageOutgoing(nil), "CHAT", nil, nil)
end

-- ============================================================================
-- == BusyResponderSelectProfileRaiding()                                    ==
-- ==                                                                        ==
-- == This function selects the BR profile that indicates the user is        ==
-- == raiding.                                                               ==
-- ============================================================================

function HTConsole:BusyResponderSelectProfileRaiding()

  HTConsole:BusyResponderApplyProfile(HTConfig:GetBRProfileRaiding(nil), L["con-busy-responder-profile-name-raiding"])
  HTConfig:SetBRMessageOutgoing(L["con-busy-responder-out-msg-raiding-01"], L["con-busy-responder-out-msg-raiding-01"])
  HTConsole:SendChatMessage(HTConfig:GetBRMessageOutgoing(nil), "CHAT", nil, nil)
end

-- ============================================================================
-- == BusyResponderSelectProfileAway()                                       ==
-- ==                                                                        ==
-- == This function selects the BR profile that indicates the user is away.  ==
-- ============================================================================

function HTConsole:BusyResponderSelectProfileAway()

  HTConsole:BusyResponderApplyProfile(HTConfig:GetBRProfileAway(nil), L["con-busy-responder-profile-name-away"])
  HTConfig:SetBRMessageOutgoing(L["con-busy-responder-out-msg-break-01"], L["con-busy-responder-out-msg-break-01"])
  HTConsole:SendChatMessage(HTConfig:GetBRMessageOutgoing(nil), "CHAT", nil, nil)
end

-- ============================================================================
-- == BusyResponderSelectProfileRecruiting()                                 ==
-- ==                                                                        ==
-- == This function selects the BR profile that indicates the user is away.  ==
-- ============================================================================

function HTConsole:BusyResponderSelectProfileRecruiting()

  HTConsole:BusyResponderApplyProfile(HTConfig:GetBRProfileRecruiting(nil), L["con-busy-responder-profile-name-recruiting"])
  HTConfig:SetBRMessageOutgoing(L["con-busy-responder-out-msg-recruiting-01"], L["con-busy-responder-out-msg-recruiting-01"])
  HTConsole:SendChatMessage(HTConfig:GetBRMessageOutgoing(nil), "CHAT", nil, nil)
end

-- ============================================================================
-- == BusyResponderSelectProfileCustom()                                     ==
-- ==                                                                        ==
-- == This function selects the BR profile that indicates the user is away.  ==
-- ============================================================================

function HTConsole:BusyResponderSelectProfileCustom()

  HTConsole:BusyResponderApplyProfile(HTConfig:GetBRProfileCustom(nil), L["con-busy-responder-profile-name-custom"])
  HTConfig:SetBRMessageOutgoing(HTConfig:GetBRMessageCustom(nil), HTConfig:GetBRMessageCustom(nil))
  HTConsole:SendChatMessage(HTConfig:GetBRMessageCustom(nil), "CHAT", nil, nil)
end

-- ============================================================================
-- == BusyResponderApplyProfile(profileFlags, profileName)                   ==
-- ==                                                                        ==
-- == This function unpacks the supplied profileFlags parameter and uses the ==
-- == data within it to set the profile options for the BR tool.             ==
-- ==                                                                        ==
-- == The profileFlags parameter should be an encoded string in the          ==
-- == format "XXXXXX" where "X" = 1 (enabled) or 0 (disabled).               ==
-- ==                                                                        ==
-- == The 'X' values represent, in the following order, the flags listed     ==
-- == below:                                                                 ==
-- ==                                                                        ==
-- ==     isGuildMemberAllowed                                               ==
-- ==     isGuildOfficerAllowed                                              ==
-- ==     isRaidMemberAllowed                                                ==
-- ==     isPartyMemberAllowed                                               ==
-- ==     isFriendAllowed                                                    ==
-- ==     isRealIDFriendAllowed                                              ==
-- ==                                                                        ==
-- ============================================================================

function HTConsole:BusyResponderApplyProfile(profileFlags, profileName)

  -- Unencode the profile properties.
  local isGuildMemberAllowed  = HTData:SafeNumericAsBoolean(string.sub(profileFlags, 1, 1))
  local isGuildOfficerAllowed = HTData:SafeNumericAsBoolean(string.sub(profileFlags, 2, 2))
  local isRaidMemberAllowed   = HTData:SafeNumericAsBoolean(string.sub(profileFlags, 3, 3))
  local isPartyMemberAllowed  = HTData:SafeNumericAsBoolean(string.sub(profileFlags, 4, 4))
  local isFriendAllowed       = HTData:SafeNumericAsBoolean(string.sub(profileFlags, 5, 5))
  local isRealIDFriendAllowed = HTData:SafeNumericAsBoolean(string.sub(profileFlags, 6, 6))

  -- Set the profile properties.
  HTConfig:SetIsGuildMemberAllowed(isGuildMemberAllowed, isGuildMemberAllowed)
  HTConfig:SetIsGuildOfficerAllowed(isGuildOfficerAllowed, isGuildOfficerAllowed)
  HTConfig:SetIsRaidMemberAllowed(isRaidMemberAllowed, isRaidMemberAllowed)
  HTConfig:SetIsPartyMemberAllowed(isPartyMemberAllowed, isPartyMemberAllowed)
  HTConfig:SetIsFriendAllowed(isFriendAllowed, isFriendAllowed)
  HTConfig:SetIsRealIDFriendAllowed(isRealIDFriendAllowed, isRealIDFriendAllowed)

  HTConfig:SetBRProfileName(profileName, profileName)

  -- Acknowledge the profile has changed.
  HTConsole:SendChatMessage(string.gsub(L["con-busy-responder-profile-selected"], "PROFILE_NAME", profileName), "CHAT", nil, nil)

end

-- ============================================================================
-- == BusyResponderSaveProfile()                                             ==
-- ==                                                                        ==
-- == This function packs the current Busy Responder settings to create an   ==
-- == encoded string of profile flags that may be stored against the         ==
-- == currently selected profile.                                            ==
-- ==                                                                        ==
-- == The profileFlags parameter should be an encoded string in the          ==
-- == format "XXXXXX" where "X" = 1 (enabled) or 0 (disabled).               ==
-- ==                                                                        ==
-- == The 'X' values represent, in the following order, the flags listed     ==
-- == below:                                                                 ==
-- ==                                                                        ==
-- ==     isGuildMemberAllowed                                               ==
-- ==     isGuildOfficerAllowed                                              ==
-- ==     isRaidMemberAllowed                                                ==
-- ==     isPartyMemberAllowed                                               ==
-- ==     isFriendAllowed                                                    ==
-- ==     isRealIDFriendAllowed                                              ==
-- ==                                                                        ==
-- ============================================================================

function HTConsole:BusyResponderSaveProfile()

  -- Encode the profile properties.
  local isGuildMemberAllowed  = HTData:SafeBooleanAsNumeric(HTConfig:GetIsGuildMemberAllowed(nil))
  local isGuildOfficerAllowed = HTData:SafeBooleanAsNumeric(HTConfig:GetIsGuildOfficerAllowed(nil))
  local isRaidMemberAllowed   = HTData:SafeBooleanAsNumeric(HTConfig:GetIsRaidMemberAllowed(nil))
  local isPartyMemberAllowed  = HTData:SafeBooleanAsNumeric(HTConfig:GetIsPartyMemberAllowed(nil))
  local isFriendAllowed       = HTData:SafeBooleanAsNumeric(HTConfig:GetIsFriendAllowed(nil))
  local isRealIDFriendAllowed = HTData:SafeBooleanAsNumeric(HTConfig:GetIsRealIDFriendAllowed(nil))
  local profileName           = HTConfig:GetBRProfileName(nil)
  local profileFlags          = isGuildMemberAllowed .. isGuildOfficerAllowed .. isRaidMemberAllowed .. isPartyMemberAllowed .. isFriendAllowed .. isRealIDFriendAllowed

  -- Attempt to save the profile properties against the correct profile name.
  if profileName == L["con-busy-responder-profile-name-busy"] then
    HTConfig:SetBRProfileBusy(profileFlags, profileFlags)
    HTConsole:SendChatMessage(string.gsub(L["con-busy-responder-profile-saved"], "PROFILE_NAME", profileName), "CHAT", nil, nil)
  elseif profileName == L["con-busy-responder-profile-name-raiding"] then
    HTConfig:SetBRProfileRaiding(profileFlags, profileFlags)
    HTConsole:SendChatMessage(string.gsub(L["con-busy-responder-profile-saved"], "PROFILE_NAME", profileName), "CHAT", nil, nil)
  elseif profileName == L["con-busy-responder-profile-name-away"] then
    HTConfig:SetBRProfileAway(profileFlags, profileFlags)
    HTConsole:SendChatMessage(string.gsub(L["con-busy-responder-profile-saved"], "PROFILE_NAME", profileName), "CHAT", nil, nil)
  else
    HTConsole:SendChatMessage(L["con-busy-responder-profile-cannot-save"], "CHAT", nil, nil)
  end

end
